// Copyright (c) 2012, the Dart project authors.  Please see the AUTHORS file
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.

/**
 * Date/time formatting symbols for all locales.
 *
 * DO NOT EDIT. This file is autogenerated by script.  See
 * 'http://go/generate_datetime_constants.py' using the --for_dart flag.
 *
 * Before checkin, this file could have been manually edited. This is
 * to incorporate changes before we could correct CLDR. All manual
 * modification must be documented in this section, and should be
 * removed after those changes land to CLDR.
 */

library date_symbol_data;

import 'dart:async';

import "date_symbols.dart";
import "src/date_format_internal.dart";
import "date_time_patterns.dart";

/**
 * This should be called for at least one [locale] before any date
 * formatting methods are called. It sets up the lookup for date
 * symbols. Both the [locale] and [ignored] parameter are ignored, as
 * the data for all locales is directly available.
 */
Future initializeDateFormatting(String locale, String ignored) {
  initializeDateSymbols(dateTimeSymbolMap);
  initializeDatePatterns(dateTimePatternMap);
  return new Future.value();
}

/**
 * Returns a Map from locale names to the DateSymbols instance for
 * that locale. Internal use only. Call initializeDateFormatting
 * instead.
 */
Map dateTimeSymbolMap() => {
  /**
   * Date/time formatting symbols for locale en_ISO.
   */
  "en_ISO" : new DateSymbols(
      NAME: 'en_ISO',
      ERAS: const ['BC', 'AD'],
      ERANAMES: const ['Before Christ', 'Anno Domini'],
      NARROWMONTHS: const ['J', 'F', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O',
          'N', 'D'],
      STANDALONENARROWMONTHS: const ['J', 'F', 'M', 'A', 'M', 'J', 'J', 'A',
          'S', 'O', 'N', 'D'],
      MONTHS: const ['January', 'February', 'March', 'April', 'May', 'June',
          'July', 'August', 'September', 'October', 'November', 'December'],
      STANDALONEMONTHS: const ['January', 'February', 'March', 'April', 'May',
          'June', 'July', 'August', 'September', 'October', 'November',
          'December'],
      SHORTMONTHS: const ['Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul',
          'Aug', 'Sep', 'Oct', 'Nov', 'Dec'],
      STANDALONESHORTMONTHS: const ['Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun',
          'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec'],
      WEEKDAYS: const ['Sunday', 'Monday', 'Tuesday', 'Wednesday', 'Thursday',
          'Friday', 'Saturday'],
      STANDALONEWEEKDAYS: const ['Sunday', 'Monday', 'Tuesday', 'Wednesday',
          'Thursday', 'Friday', 'Saturday'],
      SHORTWEEKDAYS: const ['Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat'],
      STANDALONESHORTWEEKDAYS: const ['Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri',
          'Sat'],
      NARROWWEEKDAYS: const ['S', 'M', 'T', 'W', 'T', 'F', 'S'],
      STANDALONENARROWWEEKDAYS: const ['S', 'M', 'T', 'W', 'T',
          'F', 'S'],
      SHORTQUARTERS: const ['Q1', 'Q2', 'Q3', 'Q4'],
      QUARTERS: const ['1st quarter', '2nd quarter', '3rd quarter',
          '4th quarter'],
      AMPMS: const ['AM', 'PM'],
      DATEFORMATS: const ['EEEE, y MMMM dd', 'y MMMM d', 'y MMM d',
          'yyyy-MM-dd'],
      TIMEFORMATS: const ['HH:mm:ss v', 'HH:mm:ss z', 'HH:mm:ss', 'HH:mm'],
      AVAILABLEFORMATS: const {'Md': 'M/d', 'MMMMd': 'MMMM d', 'MMMd': 'MMM d'},
      FIRSTDAYOFWEEK: 0,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 3),

  /**
   * Date/time formatting symbols for locale af.
   */
  "af" : new DateSymbols(
      NAME: "af",
      ERAS: const [ 'v.C.', 'n.C.'],
      ERANAMES: const [ 'voor Christus', 'na Christus'],
      NARROWMONTHS: const [ 'J', 'F', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O',
           'N', 'D'],
      STANDALONENARROWMONTHS: const [ 'J', 'F', 'M', 'A', 'M', 'J', 'J', 'A',
           'S', 'O', 'N', 'D'],
      MONTHS: const [ 'Januarie', 'Februarie', 'Maart', 'April', 'Mei', 'Junie',
           'Julie', 'Augustus', 'September', 'Oktober', 'November', 'Desember'],
      STANDALONEMONTHS: const [ 'Januarie', 'Februarie', 'Maart', 'April',
           'Mei', 'Junie', 'Julie', 'Augustus', 'September', 'Oktober',
           'November', 'Desember'],
      SHORTMONTHS: const [ 'Jan', 'Feb', 'Mar', 'Apr', 'Mei', 'Jun', 'Jul',
           'Aug', 'Sep', 'Okt', 'Nov', 'Des'],
      STANDALONESHORTMONTHS: const [ 'Jan', 'Feb', 'Mar', 'Apr', 'Mei', 'Jun',
           'Jul', 'Aug', 'Sep', 'Okt', 'Nov', 'Des'],
      WEEKDAYS: const [ 'Sondag', 'Maandag', 'Dinsdag', 'Woensdag', 'Donderdag',
           'Vrydag', 'Saterdag'],
      STANDALONEWEEKDAYS: const [ 'Sondag', 'Maandag', 'Dinsdag', 'Woensdag',
           'Donderdag', 'Vrydag', 'Saterdag'],
      SHORTWEEKDAYS: const [ 'So', 'Ma', 'Di', 'Wo', 'Do', 'Vr', 'Sa'],
      STANDALONESHORTWEEKDAYS: const [ 'So', 'Ma', 'Di', 'Wo', 'Do', 'Vr',
           'Sa'],
      NARROWWEEKDAYS: const [ 'S', 'M', 'D', 'W', 'D', 'V', 'S'],
      STANDALONENARROWWEEKDAYS: const [ 'S', 'M', 'D', 'W', 'D', 'V', 'S'],
      SHORTQUARTERS: const [ 'K1', 'K2', 'K3', 'K4'],
      QUARTERS: const [ '1ste kwartaal', '2de kwartaal', '3de kwartaal',
           '4de kwartaal'],
      AMPMS: const [ 'vm.', 'nm.'],
      DATEFORMATS: const [ 'EEEE dd MMMM y', 'dd MMMM y', 'dd MMM y',
           'yyyy-MM-dd'],
      TIMEFORMATS: const [ 'h:mm:ss a zzzz', 'h:mm:ss a z', 'h:mm:ss a',
           'h:mm a'],
      FIRSTDAYOFWEEK: 6,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 5),
  /**
   * Date/time formatting symbols for locale am.
   */
  "am" : new DateSymbols(
      NAME: "am",
      ERAS: const [ 'ዓ/ዓ', 'ዓ/ም'],
      ERANAMES: const [ 'ዓመተ ዓለም', 'ዓመተ ምሕረት'],
      NARROWMONTHS: const [ 'ጃ', 'ፌ', 'ማ', 'ኤ', 'ሜ', 'ጁ', 'ጁ',
           'ኦ', 'ሴ', 'ኦ', 'ኖ', 'ዲ'],
      STANDALONENARROWMONTHS: const [ 'ጃ', 'ፌ', 'ማ', 'ኤ', 'ሜ', 'ጁ',
           'ጁ', 'ኦ', 'ሴ', 'ኦ', 'ኖ', 'ዲ'],
      MONTHS: const [ 'ጃንዩወሪ', 'ፌብሩወሪ', 'ማርች',
           'ኤፕረል', 'ሜይ', 'ጁን', 'ጁላይ', 'ኦገስት',
           'ሴፕቴምበር', 'ኦክተውበር', 'ኖቬምበር',
           'ዲሴምበር'],
      STANDALONEMONTHS: const [ 'ጃንዩወሪ', 'ፌብሩወሪ',
           'ማርች', 'ኤፕረል', 'ሜይ', 'ጁን', 'ጁላይ',
           'ኦገስት', 'ሴፕቴምበር', 'ኦክተውበር',
           'ኖቬምበር', 'ዲሴምበር'],
      SHORTMONTHS: const [ 'ጃንዩ', 'ፌብሩ', 'ማርች', 'ኤፕረ',
           'ሜይ', 'ጁን', 'ጁላይ', 'ኦገስ', 'ሴፕቴ',
           'ኦክተ', 'ኖቬም', 'ዲሴም'],
      STANDALONESHORTMONTHS: const [ 'ጃንዩ', 'ፌብሩ', 'ማርች',
           'ኤፕረ', 'ሜይ', 'ጁን', 'ጁላይ', 'ኦገስ',
           'ሴፕቴ', 'ኦክተ', 'ኖቬም', 'ዲሴም'],
      WEEKDAYS: const [ 'እሑድ', 'ሰኞ', 'ማክሰኞ', 'ረቡዕ',
           'ሐሙስ', 'ዓርብ', 'ቅዳሜ'],
      STANDALONEWEEKDAYS: const [ 'እሑድ', 'ሰኞ', 'ማክሰኞ',
           'ረቡዕ', 'ሐሙስ', 'ዓርብ', 'ቅዳሜ'],
      SHORTWEEKDAYS: const [ 'እሑድ', 'ሰኞ', 'ማክሰ', 'ረቡዕ',
           'ሐሙስ', 'ዓርብ', 'ቅዳሜ'],
      STANDALONESHORTWEEKDAYS: const [ 'እሑድ', 'ሰኞ', 'ማክሰ',
           'ረቡዕ', 'ሐሙስ', 'ዓርብ', 'ቅዳሜ'],
      NARROWWEEKDAYS: const [ 'እ', 'ሰ', 'ማ', 'ረ', 'ሐ', 'ዓ', 'ቅ'],
      STANDALONENARROWWEEKDAYS: const [ 'እ', 'ሰ', 'ማ', 'ረ', 'ሐ',
           'ዓ', 'ቅ'],
      SHORTQUARTERS: const [ 'Q1', 'Q2', 'Q3', 'Q4'],
      QUARTERS: const [ '1ኛው ሩብ', 'ሁለተኛው ሩብ',
           '3ኛው ሩብ', '4ኛው ሩብ'],
      AMPMS: const [ 'ጡዋት', 'ከሳዓት'],
      DATEFORMATS: const [ 'EEEE, d MMMM y', 'd MMMM y', 'd MMM y',
           'dd/MM/yyyy'],
      TIMEFORMATS: const [ 'h:mm:ss a zzzz', 'h:mm:ss a z', 'h:mm:ss a',
           'h:mm a'],
      FIRSTDAYOFWEEK: 6,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 5),
  /**
   * Date/time formatting symbols for locale ar.
   */
  "ar" : new DateSymbols(
      NAME: "ar",
      ERAS: const [ 'ق.م', 'م'],
      ERANAMES: const [ 'قبل الميلاد', 'ميلادي'],
      NARROWMONTHS: const [ 'ي', 'ف', 'م', 'أ', 'و', 'ن', 'ل', 'غ',
           'س', 'ك', 'ب', 'د'],
      STANDALONENARROWMONTHS: const [ 'ي', 'ف', 'م', 'أ', 'و', 'ن', 'ل',
           'غ', 'س', 'ك', 'ب', 'د'],
      MONTHS: const [ 'يناير', 'فبراير', 'مارس', 'أبريل',
           'مايو', 'يونيو', 'يوليو', 'أغسطس', 'سبتمبر',
           'أكتوبر', 'نوفمبر', 'ديسمبر'],
      STANDALONEMONTHS: const [ 'يناير', 'فبراير', 'مارس',
           'أبريل', 'مايو', 'يونيو', 'يوليو', 'أغسطس',
           'سبتمبر', 'أكتوبر', 'نوفمبر', 'ديسمبر'],
      SHORTMONTHS: const [ 'يناير', 'فبراير', 'مارس',
           'أبريل', 'مايو', 'يونيو', 'يوليو', 'أغسطس',
           'سبتمبر', 'أكتوبر', 'نوفمبر', 'ديسمبر'],
      STANDALONESHORTMONTHS: const [ 'يناير', 'فبراير', 'مارس',
           'أبريل', 'مايو', 'يونيو', 'يوليو', 'أغسطس',
           'سبتمبر', 'أكتوبر', 'نوفمبر', 'ديسمبر'],
      WEEKDAYS: const [ 'الأحد', 'الاثنين', 'الثلاثاء',
           'الأربعاء', 'الخميس', 'الجمعة', 'السبت'],
      STANDALONEWEEKDAYS: const [ 'الأحد', 'الاثنين',
           'الثلاثاء', 'الأربعاء', 'الخميس',
           'الجمعة', 'السبت'],
      SHORTWEEKDAYS: const [ 'الأحد', 'الاثنين', 'الثلاثاء',
           'الأربعاء', 'الخميس', 'الجمعة', 'السبت'],
      STANDALONESHORTWEEKDAYS: const [ 'الأحد', 'الاثنين',
           'الثلاثاء', 'الأربعاء', 'الخميس',
           'الجمعة', 'السبت'],
      NARROWWEEKDAYS: const [ 'ح', 'ن', 'ث', 'ر', 'خ', 'ج', 'س'],
      STANDALONENARROWWEEKDAYS: const [ 'ح', 'ن', 'ث', 'ر', 'خ', 'ج',
           'س'],
      SHORTQUARTERS: const [ 'الربع الأول', 'الربع الثاني',
           'الربع الثالث', 'الربع الرابع'],
      QUARTERS: const [ 'الربع الأول', 'الربع الثاني',
           'الربع الثالث', 'الربع الرابع'],
      AMPMS: const [ 'ص', 'م'],
      DATEFORMATS: const [ 'EEEE، d MMMM، y', 'd MMMM، y',
           'dd‏/MM‏/yyyy', 'd‏/M‏/yyyy'],
      TIMEFORMATS: const [ 'zzzz h:mm:ss a', 'z h:mm:ss a', 'h:mm:ss a',
           'h:mm a'],
      FIRSTDAYOFWEEK: 5,
      WEEKENDRANGE: const [4, 5],
      FIRSTWEEKCUTOFFDAY: 4),
  /**
   * Date/time formatting symbols for locale bg.
   */
  "bg" : new DateSymbols(
      NAME: "bg",
      ERAS: const [ 'пр. н. е.', 'от н. е.'],
      ERANAMES: const [ 'пр.Хр.', 'сл.Хр.'],
      NARROWMONTHS: const [ 'я', 'ф', 'м', 'а', 'м', 'ю', 'ю', 'а',
           'с', 'о', 'н', 'д'],
      STANDALONENARROWMONTHS: const [ 'я', 'ф', 'м', 'а', 'м', 'ю', 'ю',
           'а', 'с', 'о', 'н', 'д'],
      MONTHS: const [ 'януари', 'февруари', 'март',
           'април', 'май', 'юни', 'юли', 'август',
           'септември', 'октомври', 'ноември',
           'декември'],
      STANDALONEMONTHS: const [ 'януари', 'февруари', 'март',
           'април', 'май', 'юни', 'юли', 'август',
           'септември', 'октомври', 'ноември',
           'декември'],
      SHORTMONTHS: const [ 'ян.', 'февр.', 'март', 'апр.',
           'май', 'юни', 'юли', 'авг.', 'септ.', 'окт.',
           'ноем.', 'дек.'],
      STANDALONESHORTMONTHS: const [ 'ян.', 'февр.', 'март',
           'апр.', 'май', 'юни', 'юли', 'авг.', 'септ.',
           'окт.', 'ноем.', 'дек.'],
      WEEKDAYS: const [ 'неделя', 'понеделник',
           'вторник', 'сряда', 'четвъртък', 'петък',
           'събота'],
      STANDALONEWEEKDAYS: const [ 'неделя', 'понеделник',
           'вторник', 'сряда', 'четвъртък', 'петък',
           'събота'],
      SHORTWEEKDAYS: const [ 'нд', 'пн', 'вт', 'ср', 'чт', 'пт',
           'сб'],
      STANDALONESHORTWEEKDAYS: const [ 'нд', 'пн', 'вт', 'ср', 'чт',
           'пт', 'сб'],
      NARROWWEEKDAYS: const [ 'н', 'п', 'в', 'с', 'ч', 'п', 'с'],
      STANDALONENARROWWEEKDAYS: const [ 'н', 'п', 'в', 'с', 'ч', 'п',
           'с'],
      SHORTQUARTERS: const [ 'I трим.', 'II трим.', 'III трим.',
           'IV трим.'],
      QUARTERS: const [ '1-во тримесечие',
           '2-ро тримесечие', '3-то тримесечие',
           '4-то тримесечие'],
      AMPMS: const [ 'пр. об.', 'сл. об.'],
      DATEFORMATS: const [ 'dd MMMM y, EEEE', 'dd MMMM y', 'dd.MM.yyyy',
           'dd.MM.yy'],
      TIMEFORMATS: const [ 'HH:mm:ss zzzz', 'HH:mm:ss z', 'HH:mm:ss', 'HH:mm'],
      FIRSTDAYOFWEEK: 0,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 3),
  /**
   * Date/time formatting symbols for locale bn.
   */
  "bn" : new DateSymbols(
      NAME: "bn",
      ERAS: const [ 'খৃষ্টপূর্ব',
           'খৃষ্টাব্দ'],
      ERANAMES: const [ 'খৃষ্টপূর্ব',
           'খৃষ্টাব্দ'],
      NARROWMONTHS: const [ 'জা', 'ফে', 'মা', 'এ', 'মে',
           'জুন', 'জু', 'আ', 'সে', 'অ', 'ন', 'ডি'],
      STANDALONENARROWMONTHS: const [ 'জা', 'ফে', 'মা', 'এ',
           'মে', 'জুন', 'জু', 'আ', 'সে', 'অ', 'ন',
           'ডি'],
      MONTHS: const [ 'জানুয়ারী',
           'ফেব্রুয়ারী', 'মার্চ',
           'এপ্রিল', 'মে', 'জুন', 'জুলাই',
           'আগস্ট', 'সেপ্টেম্বর',
           'অক্টোবর', 'নভেম্বর',
           'ডিসেম্বর'],
      STANDALONEMONTHS: const [ 'জানুয়ারী',
           'ফেব্রুয়ারী', 'মার্চ',
           'এপ্রিল', 'মে', 'জুন', 'জুলাই',
           'আগস্ট', 'সেপ্টেম্বর',
           'অক্টোবর', 'নভেম্বর',
           'ডিসেম্বর'],
      SHORTMONTHS: const [ 'জানুয়ারী',
           'ফেব্রুয়ারী', 'মার্চ',
           'এপ্রিল', 'মে', 'জুন', 'জুলাই',
           'আগস্ট', 'সেপ্টেম্বর',
           'অক্টোবর', 'নভেম্বর',
           'ডিসেম্বর'],
      STANDALONESHORTMONTHS: const [ 'জানুয়ারী',
           'ফেব্রুয়ারী', 'মার্চ',
           'এপ্রিল', 'মে', 'জুন', 'জুলাই',
           'আগস্ট', 'সেপ্টেম্বর',
           'অক্টোবর', 'নভেম্বর',
           'ডিসেম্বর'],
      WEEKDAYS: const [ 'রবিবার', 'সোমবার',
           'মঙ্গলবার', 'বুধবার',
           'বৃহষ্পতিবার', 'শুক্রবার',
           'শনিবার'],
      STANDALONEWEEKDAYS: const [ 'রবিবার', 'সোমবার',
           'মঙ্গলবার', 'বুধবার',
           'বৃহষ্পতিবার', 'শুক্রবার',
           'শনিবার'],
      SHORTWEEKDAYS: const [ 'রবি', 'সোম', 'মঙ্গল',
           'বুধ', 'বৃহস্পতি', 'শুক্র',
           'শনি'],
      STANDALONESHORTWEEKDAYS: const [ 'রবি', 'সোম',
           'মঙ্গল', 'বুধ', 'বৃহস্পতি',
           'শুক্র', 'শনি'],
      NARROWWEEKDAYS: const [ 'র', 'সো', 'ম', 'বু', 'বৃ',
           'শু', 'শ'],
      STANDALONENARROWWEEKDAYS: const [ 'র', 'সো', 'ম', 'বু',
           'বৃ', 'শু', 'শ'],
      SHORTQUARTERS: const [ 'চতুর্থাংশ ১',
           'চতুর্থাংশ ২', 'চতুর্থাংশ ৩',
           'চতুর্থাংশ ৪'],
      QUARTERS: const [ 'প্রথম চতুর্থাংশ',
           'দ্বিতীয় চতুর্থাংশ',
           'তৃতীয় চতুর্থাংশ',
           'চতুর্থ চতুর্থাংশ'],
      AMPMS: const [ 'am', 'pm'],
      DATEFORMATS: const [ 'EEEE, d MMMM, y', 'd MMMM, y', 'd MMM, y',
           'd/M/yy'],
      TIMEFORMATS: const [ 'h:mm:ss a zzzz', 'h:mm:ss a z', 'h:mm:ss a',
           'h:mm a'],
      FIRSTDAYOFWEEK: 4,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 3),
  /**
   * Date/time formatting symbols for locale ca.
   */
  "ca" : new DateSymbols(
      NAME: "ca",
      ERAS: const [ 'aC', 'dC'],
      ERANAMES: const [ 'abans de Crist', 'després de Crist'],
      NARROWMONTHS: const [ 'G', 'F', 'M', 'A', 'M', 'J', 'G', 'A', 'S', 'O',
           'N', 'D'],
      STANDALONENARROWMONTHS: const [ 'g', 'f', 'm', 'a', 'm', 'j', 'j', 'a',
           's', 'o', 'n', 'd'],
      MONTHS: const [ 'de gener', 'de febrer', 'de març', 'd’abril',
           'de maig', 'de juny', 'de juliol', 'd’agost', 'de setembre',
           'd’octubre', 'de novembre', 'de desembre'],
      STANDALONEMONTHS: const [ 'gener', 'febrer', 'març', 'abril', 'maig',
           'juny', 'juliol', 'agost', 'setembre', 'octubre', 'novembre',
           'desembre'],
      SHORTMONTHS: const [ 'de gen.', 'de febr.', 'de març', 'd’abr.',
           'de maig', 'de juny', 'de jul.', 'd’ag.', 'de set.', 'd’oct.',
           'de nov.', 'de des.'],
      STANDALONESHORTMONTHS: const [ 'gen.', 'febr.', 'març', 'abr.', 'maig',
           'juny', 'jul.', 'ag.', 'set.', 'oct.', 'nov.', 'des.'],
      WEEKDAYS: const [ 'diumenge', 'dilluns', 'dimarts', 'dimecres', 'dijous',
           'divendres', 'dissabte'],
      STANDALONEWEEKDAYS: const [ 'Diumenge', 'Dilluns', 'Dimarts', 'Dimecres',
           'Dijous', 'Divendres', 'Dissabte'],
      SHORTWEEKDAYS: const [ 'dg.', 'dl.', 'dt.', 'dc.', 'dj.', 'dv.', 'ds.'],
      STANDALONESHORTWEEKDAYS: const [ 'dg', 'dl', 'dt', 'dc', 'dj', 'dv',
           'ds'],
      NARROWWEEKDAYS: const [ 'G', 'l', 'T', 'C', 'J', 'V', 'S'],
      STANDALONENARROWWEEKDAYS: const [ 'g', 'l', 't', 'c', 'j', 'v', 's'],
      SHORTQUARTERS: const [ '1T', '2T', '3T', '4T'],
      QUARTERS: const [ '1r trimestre', '2n trimestre', '3r trimestre',
           '4t trimestre'],
      AMPMS: const [ 'a.m.', 'p.m.'],
      DATEFORMATS: const [ 'EEEE d MMMM \'de\' y', 'd MMMM \'de\' y',
           'dd/MM/yyyy', 'dd/MM/yy'],
      TIMEFORMATS: const [ 'H:mm:ss zzzz', 'H:mm:ss z', 'H:mm:ss', 'H:mm'],
      FIRSTDAYOFWEEK: 0,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 3),
  /**
   * Date/time formatting symbols for locale cs.
   */
  "cs" : new DateSymbols(
      NAME: "cs",
      ERAS: const [ 'př. n. l.', 'n. l.'],
      ERANAMES: const [ 'př. n. l.', 'n. l.'],
      NARROWMONTHS: const [ '1', '2', '3', '4', '5', '6', '7', '8', '9', '10',
           '11', '12'],
      STANDALONENARROWMONTHS: const [ 'l', 'ú', 'b', 'd', 'k', 'č', 'č', 's',
           'z', 'ř', 'l', 'p'],
      MONTHS: const [ 'ledna', 'února', 'března', 'dubna', 'května',
           'června', 'července', 'srpna', 'září', 'října', 'listopadu',
           'prosince'],
      STANDALONEMONTHS: const [ 'leden', 'únor', 'březen', 'duben', 'květen',
           'červen', 'červenec', 'srpen', 'září', 'říjen', 'listopad',
           'prosinec'],
      SHORTMONTHS: const [ 'Led', 'Úno', 'Bře', 'Dub', 'Kvě', 'Čer', 'Čvc',
           'Srp', 'Zář', 'Říj', 'Lis', 'Pro'],
      STANDALONESHORTMONTHS: const [ '1.', '2.', '3.', '4.', '5.', '6.', '7.',
           '8.', '9.', '10.', '11.', '12.'],
      WEEKDAYS: const [ 'neděle', 'pondělí', 'úterý', 'středa',
           'čtvrtek', 'pátek', 'sobota'],
      STANDALONEWEEKDAYS: const [ 'neděle', 'pondělí', 'úterý', 'středa',
           'čtvrtek', 'pátek', 'sobota'],
      SHORTWEEKDAYS: const [ 'ne', 'po', 'út', 'st', 'čt', 'pá', 'so'],
      STANDALONESHORTWEEKDAYS: const [ 'ne', 'po', 'út', 'st', 'čt', 'pá',
           'so'],
      NARROWWEEKDAYS: const [ 'N', 'P', 'Ú', 'S', 'Č', 'P', 'S'],
      STANDALONENARROWWEEKDAYS: const [ 'N', 'P', 'Ú', 'S', 'Č', 'P', 'S'],
      SHORTQUARTERS: const [ 'Q1', 'Q2', 'Q3', 'Q4'],
      QUARTERS: const [ '1. čtvrtletí', '2. čtvrtletí', '3. čtvrtletí',
           '4. čtvrtletí'],
      AMPMS: const [ 'dop.', 'odp.'],
      DATEFORMATS: const [ 'EEEE, d. MMMM y', 'd. MMMM y', 'd. M. yyyy',
           'dd.MM.yy'],
      TIMEFORMATS: const [ 'H:mm:ss zzzz', 'H:mm:ss z', 'H:mm:ss', 'H:mm'],
      FIRSTDAYOFWEEK: 0,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 3),
  /**
   * Date/time formatting symbols for locale da.
   */
  "da" : new DateSymbols(
      NAME: "da",
      ERAS: const [ 'f.Kr.', 'e.Kr.'],
      ERANAMES: const [ 'f.Kr.', 'e.Kr.'],
      NARROWMONTHS: const [ 'J', 'F', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O',
           'N', 'D'],
      STANDALONENARROWMONTHS: const [ 'J', 'F', 'M', 'A', 'M', 'J', 'J', 'A',
           'S', 'O', 'N', 'D'],
      MONTHS: const [ 'januar', 'februar', 'marts', 'april', 'maj', 'juni',
           'juli', 'august', 'september', 'oktober', 'november', 'december'],
      STANDALONEMONTHS: const [ 'januar', 'februar', 'marts', 'april', 'maj',
           'juni', 'juli', 'august', 'september', 'oktober', 'november',
           'december'],
      SHORTMONTHS: const [ 'jan.', 'feb.', 'mar.', 'apr.', 'maj', 'jun.',
           'jul.', 'aug.', 'sep.', 'okt.', 'nov.', 'dec.'],
      STANDALONESHORTMONTHS: const [ 'jan', 'feb', 'mar', 'apr', 'maj', 'jun',
           'jul', 'aug', 'sep', 'okt', 'nov', 'dec'],
      WEEKDAYS: const [ 'søndag', 'mandag', 'tirsdag', 'onsdag', 'torsdag',
           'fredag', 'lørdag'],
      STANDALONEWEEKDAYS: const [ 'søndag', 'mandag', 'tirsdag', 'onsdag',
           'torsdag', 'fredag', 'lørdag'],
      SHORTWEEKDAYS: const [ 'søn', 'man', 'tir', 'ons', 'tor', 'fre', 'lør'],
      STANDALONESHORTWEEKDAYS: const [ 'søn', 'man', 'tir', 'ons', 'tor',
           'fre', 'lør'],
      NARROWWEEKDAYS: const [ 'S', 'M', 'T', 'O', 'T', 'F', 'L'],
      STANDALONENARROWWEEKDAYS: const [ 'S', 'M', 'T', 'O', 'T', 'F', 'L'],
      SHORTQUARTERS: const [ 'K1', 'K2', 'K3', 'K4'],
      QUARTERS: const [ '1. kvartal', '2. kvartal', '3. kvartal', '4. kvartal'],
      AMPMS: const [ 'f.m.', 'e.m.'],
      DATEFORMATS: const [ 'EEEE \'den\' d. MMMM y', 'd. MMM y', 'dd/MM/yyyy',
           'dd/MM/yy'],
      TIMEFORMATS: const [ 'HH.mm.ss zzzz', 'HH.mm.ss z', 'HH.mm.ss', 'HH.mm'],
      FIRSTDAYOFWEEK: 0,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 3),
  /**
   * Date/time formatting symbols for locale de.
   */
  "de" : new DateSymbols(
      NAME: "de",
      ERAS: const [ 'v. Chr.', 'n. Chr.'],
      ERANAMES: const [ 'v. Chr.', 'n. Chr.'],
      NARROWMONTHS: const [ 'J', 'F', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O',
           'N', 'D'],
      STANDALONENARROWMONTHS: const [ 'J', 'F', 'M', 'A', 'M', 'J', 'J', 'A',
           'S', 'O', 'N', 'D'],
      MONTHS: const [ 'Januar', 'Februar', 'März', 'April', 'Mai', 'Juni',
           'Juli', 'August', 'September', 'Oktober', 'November', 'Dezember'],
      STANDALONEMONTHS: const [ 'Januar', 'Februar', 'März', 'April', 'Mai',
           'Juni', 'Juli', 'August', 'September', 'Oktober', 'November',
           'Dezember'],
      SHORTMONTHS: const [ 'Jan', 'Feb', 'Mär', 'Apr', 'Mai', 'Jun', 'Jul',
           'Aug', 'Sep', 'Okt', 'Nov', 'Dez'],
      STANDALONESHORTMONTHS: const [ 'Jan', 'Feb', 'Mär', 'Apr', 'Mai', 'Jun',
           'Jul', 'Aug', 'Sep', 'Okt', 'Nov', 'Dez'],
      WEEKDAYS: const [ 'Sonntag', 'Montag', 'Dienstag', 'Mittwoch',
           'Donnerstag', 'Freitag', 'Samstag'],
      STANDALONEWEEKDAYS: const [ 'Sonntag', 'Montag', 'Dienstag', 'Mittwoch',
           'Donnerstag', 'Freitag', 'Samstag'],
      SHORTWEEKDAYS: const [ 'So.', 'Mo.', 'Di.', 'Mi.', 'Do.', 'Fr.', 'Sa.'],
      STANDALONESHORTWEEKDAYS: const [ 'So', 'Mo', 'Di', 'Mi', 'Do', 'Fr',
           'Sa'],
      NARROWWEEKDAYS: const [ 'S', 'M', 'D', 'M', 'D', 'F', 'S'],
      STANDALONENARROWWEEKDAYS: const [ 'S', 'M', 'D', 'M', 'D', 'F', 'S'],
      SHORTQUARTERS: const [ 'Q1', 'Q2', 'Q3', 'Q4'],
      QUARTERS: const [ '1. Quartal', '2. Quartal', '3. Quartal', '4. Quartal'],
      AMPMS: const [ 'vorm.', 'nachm.'],
      DATEFORMATS: const [ 'EEEE, d. MMMM y', 'd. MMMM y', 'dd.MM.yyyy',
           'dd.MM.yy'],
      TIMEFORMATS: const [ 'HH:mm:ss zzzz', 'HH:mm:ss z', 'HH:mm:ss', 'HH:mm'],
      FIRSTDAYOFWEEK: 0,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 3),
  /**
   * Date/time formatting symbols for locale de_AT.
   */
  "de_AT" : new DateSymbols(
      NAME: "de_AT",
      ERAS: const [ 'v. Chr.', 'n. Chr.'],
      ERANAMES: const [ 'v. Chr.', 'n. Chr.'],
      NARROWMONTHS: const [ 'J', 'F', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O',
           'N', 'D'],
      STANDALONENARROWMONTHS: const [ 'J', 'F', 'M', 'A', 'M', 'J', 'J', 'A',
           'S', 'O', 'N', 'D'],
      MONTHS: const [ 'Jänner', 'Februar', 'März', 'April', 'Mai', 'Juni',
           'Juli', 'August', 'September', 'Oktober', 'November', 'Dezember'],
      STANDALONEMONTHS: const [ 'Jänner', 'Februar', 'März', 'April', 'Mai',
           'Juni', 'Juli', 'August', 'September', 'Oktober', 'November',
           'Dezember'],
      SHORTMONTHS: const [ 'Jän', 'Feb', 'Mär', 'Apr', 'Mai', 'Jun', 'Jul',
           'Aug', 'Sep', 'Okt', 'Nov', 'Dez'],
      STANDALONESHORTMONTHS: const [ 'Jän', 'Feb', 'Mär', 'Apr', 'Mai', 'Jun',
           'Jul', 'Aug', 'Sep', 'Okt', 'Nov', 'Dez'],
      WEEKDAYS: const [ 'Sonntag', 'Montag', 'Dienstag', 'Mittwoch',
           'Donnerstag', 'Freitag', 'Samstag'],
      STANDALONEWEEKDAYS: const [ 'Sonntag', 'Montag', 'Dienstag', 'Mittwoch',
           'Donnerstag', 'Freitag', 'Samstag'],
      SHORTWEEKDAYS: const [ 'So.', 'Mo.', 'Di.', 'Mi.', 'Do.', 'Fr.', 'Sa.'],
      STANDALONESHORTWEEKDAYS: const [ 'So', 'Mo', 'Di', 'Mi', 'Do', 'Fr',
           'Sa'],
      NARROWWEEKDAYS: const [ 'S', 'M', 'D', 'M', 'D', 'F', 'S'],
      STANDALONENARROWWEEKDAYS: const [ 'S', 'M', 'D', 'M', 'D', 'F', 'S'],
      SHORTQUARTERS: const [ 'Q1', 'Q2', 'Q3', 'Q4'],
      QUARTERS: const [ '1. Quartal', '2. Quartal', '3. Quartal', '4. Quartal'],
      AMPMS: const [ 'vorm.', 'nachm.'],
      DATEFORMATS: const [ 'EEEE, dd. MMMM y', 'dd. MMMM y', 'dd.MM.yyyy',
           'dd.MM.yy'],
      TIMEFORMATS: const [ 'HH:mm:ss zzzz', 'HH:mm:ss z', 'HH:mm:ss', 'HH:mm'],
      FIRSTDAYOFWEEK: 0,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 3),
  /**
   * Date/time formatting symbols for locale de_CH.
   */
  /**
   * Date/time formatting symbols for locale de_CH.
   */
  "de_CH" : new DateSymbols(
      NAME: "de_CH",
      ERAS: const [ 'v. Chr.', 'n. Chr.'],
      ERANAMES: const [ 'v. Chr.', 'n. Chr.'],
      NARROWMONTHS: const [ 'J', 'F', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O',
           'N', 'D'],
      STANDALONENARROWMONTHS: const [ 'J', 'F', 'M', 'A', 'M', 'J', 'J', 'A',
           'S', 'O', 'N', 'D'],
      MONTHS: const [ 'Januar', 'Februar', 'März', 'April', 'Mai', 'Juni',
           'Juli', 'August', 'September', 'Oktober', 'November', 'Dezember'],
      STANDALONEMONTHS: const [ 'Januar', 'Februar', 'März', 'April', 'Mai',
           'Juni', 'Juli', 'August', 'September', 'Oktober', 'November',
           'Dezember'],
      SHORTMONTHS: const [ 'Jan', 'Feb', 'Mär', 'Apr', 'Mai', 'Jun', 'Jul',
           'Aug', 'Sep', 'Okt', 'Nov', 'Dez'],
      STANDALONESHORTMONTHS: const [ 'Jan', 'Feb', 'Mär', 'Apr', 'Mai', 'Jun',
           'Jul', 'Aug', 'Sep', 'Okt', 'Nov', 'Dez'],
      WEEKDAYS: const [ 'Sonntag', 'Montag', 'Dienstag', 'Mittwoch',
           'Donnerstag', 'Freitag', 'Samstag'],
      STANDALONEWEEKDAYS: const [ 'Sonntag', 'Montag', 'Dienstag', 'Mittwoch',
           'Donnerstag', 'Freitag', 'Samstag'],
      SHORTWEEKDAYS: const [ 'So.', 'Mo.', 'Di.', 'Mi.', 'Do.', 'Fr.', 'Sa.'],
      STANDALONESHORTWEEKDAYS: const [ 'So', 'Mo', 'Di', 'Mi', 'Do', 'Fr',
           'Sa'],
      NARROWWEEKDAYS: const [ 'S', 'M', 'D', 'M', 'D', 'F', 'S'],
      STANDALONENARROWWEEKDAYS: const [ 'S', 'M', 'D', 'M', 'D', 'F', 'S'],
      SHORTQUARTERS: const [ 'Q1', 'Q2', 'Q3', 'Q4'],
      QUARTERS: const [ '1. Quartal', '2. Quartal', '3. Quartal', '4. Quartal'],
      AMPMS: const [ 'vorm.', 'nachm.'],
      DATEFORMATS: const [ 'EEEE, d. MMMM y', 'd. MMMM y', 'dd.MM.yyyy',
           'dd.MM.yy'],
      TIMEFORMATS: const [ 'HH:mm:ss zzzz', 'HH:mm:ss z', 'HH:mm:ss', 'HH:mm'],
      FIRSTDAYOFWEEK: 0,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 3),
  /**
   * Date/time formatting symbols for locale el.
   */
  "el" : new DateSymbols(
      NAME: "el",
      ERAS: const [ 'π.Χ.', 'μ.Χ.'],
      ERANAMES: const [ 'π.Χ.', 'μ.Χ.'],
      NARROWMONTHS: const [ 'Ι', 'Φ', 'Μ', 'Α', 'Μ', 'Ι', 'Ι', 'Α',
           'Σ', 'Ο', 'Ν', 'Δ'],
      STANDALONENARROWMONTHS: const [ 'Ι', 'Φ', 'Μ', 'Α', 'Μ', 'Ι', 'Ι',
           'Α', 'Σ', 'Ο', 'Ν', 'Δ'],
      MONTHS: const [ 'Ιανουαρίου', 'Φεβρουαρίου',
           'Μαρτίου', 'Απριλίου', 'Μαΐου', 'Ιουνίου',
           'Ιουλίου', 'Αυγούστου', 'Σεπτεμβρίου',
           'Οκτωβρίου', 'Νοεμβρίου', 'Δεκεμβρίου'],
      STANDALONEMONTHS: const [ 'Ιανουάριος',
           'Φεβρουάριος', 'Μάρτιος', 'Απρίλιος',
           'Μάιος', 'Ιούνιος', 'Ιούλιος',
           'Αύγουστος', 'Σεπτέμβριος', 'Οκτώβριος',
           'Νοέμβριος', 'Δεκέμβριος'],
      SHORTMONTHS: const [ 'Ιαν', 'Φεβ', 'Μαρ', 'Απρ', 'Μαϊ',
           'Ιουν', 'Ιουλ', 'Αυγ', 'Σεπ', 'Οκτ', 'Νοε',
           'Δεκ'],
      STANDALONESHORTMONTHS: const [ 'Ιαν', 'Φεβ', 'Μάρ', 'Απρ',
           'Μάι', 'Ιούν', 'Ιούλ', 'Αυγ', 'Σεπ', 'Οκτ',
           'Νοέ', 'Δεκ'],
      WEEKDAYS: const [ 'Κυριακή', 'Δευτέρα', 'Τρίτη',
           'Τετάρτη', 'Πέμπτη', 'Παρασκευή',
           'Σάββατο'],
      STANDALONEWEEKDAYS: const [ 'Κυριακή', 'Δευτέρα',
           'Τρίτη', 'Τετάρτη', 'Πέμπτη', 'Παρασκευή',
           'Σάββατο'],
      SHORTWEEKDAYS: const [ 'Κυρ', 'Δευ', 'Τρι', 'Τετ', 'Πεμ',
           'Παρ', 'Σαβ'],
      STANDALONESHORTWEEKDAYS: const [ 'Κυρ', 'Δευ', 'Τρί', 'Τετ',
           'Πέμ', 'Παρ', 'Σάβ'],
      NARROWWEEKDAYS: const [ 'Κ', 'Δ', 'Τ', 'Τ', 'Π', 'Π', 'Σ'],
      STANDALONENARROWWEEKDAYS: const [ 'Κ', 'Δ', 'Τ', 'Τ', 'Π', 'Π',
           'Σ'],
      SHORTQUARTERS: const [ 'Τ1', 'Τ2', 'Τ3', 'Τ4'],
      QUARTERS: const [ '1ο τρίμηνο', '2ο τρίμηνο',
           '3ο τρίμηνο', '4ο τρίμηνο'],
      AMPMS: const [ 'π.μ.', 'μ.μ.'],
      DATEFORMATS: const [ 'EEEE, d MMMM y', 'd MMMM y', 'd MMM y', 'd/M/yy'],
      TIMEFORMATS: const [ 'h:mm:ss a zzzz', 'h:mm:ss a z', 'h:mm:ss a',
           'h:mm a'],
      FIRSTDAYOFWEEK: 0,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 3),
  /**
   * Date/time formatting symbols for locale en.
   */
  "en" : new DateSymbols(
      NAME: "en",
      ERAS: const [ 'BC', 'AD'],
      ERANAMES: const [ 'Before Christ', 'Anno Domini'],
      NARROWMONTHS: const [ 'J', 'F', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O',
           'N', 'D'],
      STANDALONENARROWMONTHS: const [ 'J', 'F', 'M', 'A', 'M', 'J', 'J', 'A',
           'S', 'O', 'N', 'D'],
      MONTHS: const [ 'January', 'February', 'March', 'April', 'May', 'June',
           'July', 'August', 'September', 'October', 'November', 'December'],
      STANDALONEMONTHS: const [ 'January', 'February', 'March', 'April', 'May',
           'June', 'July', 'August', 'September', 'October', 'November',
           'December'],
      SHORTMONTHS: const [ 'Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul',
           'Aug', 'Sep', 'Oct', 'Nov', 'Dec'],
      STANDALONESHORTMONTHS: const [ 'Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun',
           'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec'],
      WEEKDAYS: const [ 'Sunday', 'Monday', 'Tuesday', 'Wednesday', 'Thursday',
           'Friday', 'Saturday'],
      STANDALONEWEEKDAYS: const [ 'Sunday', 'Monday', 'Tuesday', 'Wednesday',
           'Thursday', 'Friday', 'Saturday'],
      SHORTWEEKDAYS: const [ 'Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat'],
      STANDALONESHORTWEEKDAYS: const [ 'Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri',
           'Sat'],
      NARROWWEEKDAYS: const [ 'S', 'M', 'T', 'W', 'T', 'F', 'S'],
      STANDALONENARROWWEEKDAYS: const [ 'S', 'M', 'T', 'W', 'T', 'F', 'S'],
      SHORTQUARTERS: const [ 'Q1', 'Q2', 'Q3', 'Q4'],
      QUARTERS: const [ '1st quarter', '2nd quarter', '3rd quarter',
           '4th quarter'],
      AMPMS: const [ 'AM', 'PM'],
      DATEFORMATS: const [ 'EEEE, MMMM d, y', 'MMMM d, y', 'MMM d, y',
           'M/d/yy'],
      TIMEFORMATS: const [ 'h:mm:ss a zzzz', 'h:mm:ss a z', 'h:mm:ss a',
           'h:mm a'],
      FIRSTDAYOFWEEK: 6,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 5),
  /**
   * Date/time formatting symbols for locale en_AU.
   */
  "en_AU" : new DateSymbols(
      NAME: "en_AU",
      ERAS: const [ 'BC', 'AD'],
      ERANAMES: const [ 'Before Christ', 'Anno Domini'],
      NARROWMONTHS: const [ 'J', 'F', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O',
           'N', 'D'],
      STANDALONENARROWMONTHS: const [ 'J', 'F', 'M', 'A', 'M', 'J', 'J', 'A',
           'S', 'O', 'N', 'D'],
      MONTHS: const [ 'January', 'February', 'March', 'April', 'May', 'June',
           'July', 'August', 'September', 'October', 'November', 'December'],
      STANDALONEMONTHS: const [ 'January', 'February', 'March', 'April', 'May',
           'June', 'July', 'August', 'September', 'October', 'November',
           'December'],
      SHORTMONTHS: const [ 'Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul',
           'Aug', 'Sep', 'Oct', 'Nov', 'Dec'],
      STANDALONESHORTMONTHS: const [ 'Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun',
           'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec'],
      WEEKDAYS: const [ 'Sunday', 'Monday', 'Tuesday', 'Wednesday', 'Thursday',
           'Friday', 'Saturday'],
      STANDALONEWEEKDAYS: const [ 'Sunday', 'Monday', 'Tuesday', 'Wednesday',
           'Thursday', 'Friday', 'Saturday'],
      SHORTWEEKDAYS: const [ 'Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat'],
      STANDALONESHORTWEEKDAYS: const [ 'Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri',
           'Sat'],
      NARROWWEEKDAYS: const [ 'S', 'M', 'T', 'W', 'T', 'F', 'S'],
      STANDALONENARROWWEEKDAYS: const [ 'S', 'M', 'T', 'W', 'T', 'F', 'S'],
      SHORTQUARTERS: const [ 'Q1', 'Q2', 'Q3', 'Q4'],
      QUARTERS: const [ '1st quarter', '2nd quarter', '3rd quarter',
           '4th quarter'],
      AMPMS: const [ 'AM', 'PM'],
      DATEFORMATS: const [ 'EEEE, d MMMM y', 'd MMMM y', 'dd/MM/yyyy',
           'd/MM/yy'],
      TIMEFORMATS: const [ 'h:mm:ss a zzzz', 'h:mm:ss a z', 'h:mm:ss a',
           'h:mm a'],
      FIRSTDAYOFWEEK: 6,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 5),
  /**
   * Date/time formatting symbols for locale en_GB.
   */
  "en_GB" : new DateSymbols(
      NAME: "en_GB",
      ERAS: const [ 'BC', 'AD'],
      ERANAMES: const [ 'Before Christ', 'Anno Domini'],
      NARROWMONTHS: const [ 'J', 'F', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O',
           'N', 'D'],
      STANDALONENARROWMONTHS: const [ 'J', 'F', 'M', 'A', 'M', 'J', 'J', 'A',
           'S', 'O', 'N', 'D'],
      MONTHS: const [ 'January', 'February', 'March', 'April', 'May', 'June',
           'July', 'August', 'September', 'October', 'November', 'December'],
      STANDALONEMONTHS: const [ 'January', 'February', 'March', 'April', 'May',
           'June', 'July', 'August', 'September', 'October', 'November',
           'December'],
      SHORTMONTHS: const [ 'Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul',
           'Aug', 'Sep', 'Oct', 'Nov', 'Dec'],
      STANDALONESHORTMONTHS: const [ 'Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun',
           'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec'],
      WEEKDAYS: const [ 'Sunday', 'Monday', 'Tuesday', 'Wednesday', 'Thursday',
           'Friday', 'Saturday'],
      STANDALONEWEEKDAYS: const [ 'Sunday', 'Monday', 'Tuesday', 'Wednesday',
           'Thursday', 'Friday', 'Saturday'],
      SHORTWEEKDAYS: const [ 'Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat'],
      STANDALONESHORTWEEKDAYS: const [ 'Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri',
           'Sat'],
      NARROWWEEKDAYS: const [ 'S', 'M', 'T', 'W', 'T', 'F', 'S'],
      STANDALONENARROWWEEKDAYS: const [ 'S', 'M', 'T', 'W', 'T', 'F', 'S'],
      SHORTQUARTERS: const [ 'Q1', 'Q2', 'Q3', 'Q4'],
      QUARTERS: const [ '1st quarter', '2nd quarter', '3rd quarter',
           '4th quarter'],
      AMPMS: const [ 'AM', 'PM'],
      DATEFORMATS: const [ 'EEEE, d MMMM y', 'd MMMM y', 'd MMM y',
           'dd/MM/yyyy'],
      TIMEFORMATS: const [ 'HH:mm:ss zzzz', 'HH:mm:ss z', 'HH:mm:ss', 'HH:mm'],
      FIRSTDAYOFWEEK: 0,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 3),
  /**
   * Date/time formatting symbols for locale en_IE.
   */
  "en_IE" : new DateSymbols(
      NAME: "en_IE",
      ERAS: const [ 'BC', 'AD'],
      ERANAMES: const [ 'Before Christ', 'Anno Domini'],
      NARROWMONTHS: const [ 'J', 'F', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O',
           'N', 'D'],
      STANDALONENARROWMONTHS: const [ 'J', 'F', 'M', 'A', 'M', 'J', 'J', 'A',
           'S', 'O', 'N', 'D'],
      MONTHS: const [ 'January', 'February', 'March', 'April', 'May', 'June',
           'July', 'August', 'September', 'October', 'November', 'December'],
      STANDALONEMONTHS: const [ 'January', 'February', 'March', 'April', 'May',
           'June', 'July', 'August', 'September', 'October', 'November',
           'December'],
      SHORTMONTHS: const [ 'Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul',
           'Aug', 'Sep', 'Oct', 'Nov', 'Dec'],
      STANDALONESHORTMONTHS: const [ 'Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun',
           'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec'],
      WEEKDAYS: const [ 'Sunday', 'Monday', 'Tuesday', 'Wednesday', 'Thursday',
           'Friday', 'Saturday'],
      STANDALONEWEEKDAYS: const [ 'Sunday', 'Monday', 'Tuesday', 'Wednesday',
           'Thursday', 'Friday', 'Saturday'],
      SHORTWEEKDAYS: const [ 'Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat'],
      STANDALONESHORTWEEKDAYS: const [ 'Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri',
           'Sat'],
      NARROWWEEKDAYS: const [ 'S', 'M', 'T', 'W', 'T', 'F', 'S'],
      STANDALONENARROWWEEKDAYS: const [ 'S', 'M', 'T', 'W', 'T', 'F', 'S'],
      SHORTQUARTERS: const [ 'Q1', 'Q2', 'Q3', 'Q4'],
      QUARTERS: const [ '1st quarter', '2nd quarter', '3rd quarter',
           '4th quarter'],
      AMPMS: const [ 'a.m.', 'p.m.'],
      DATEFORMATS: const [ 'EEEE d MMMM y', 'd MMMM y', 'd MMM y',
           'dd/MM/yyyy'],
      TIMEFORMATS: const [ 'h:mm:ss a zzzz', 'h:mm:ss a z', 'h:mm:ss a',
           'h:mm a'],
      FIRSTDAYOFWEEK: 0,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 3),
  /**
   * Date/time formatting symbols for locale en_IN.
   */
  "en_IN" : new DateSymbols(
      NAME: "en_IN",
      ERAS: const [ 'BC', 'AD'],
      ERANAMES: const [ 'Before Christ', 'Anno Domini'],
      NARROWMONTHS: const [ 'J', 'F', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O',
           'N', 'D'],
      STANDALONENARROWMONTHS: const [ 'J', 'F', 'M', 'A', 'M', 'J', 'J', 'A',
           'S', 'O', 'N', 'D'],
      MONTHS: const [ 'January', 'February', 'March', 'April', 'May', 'June',
           'July', 'August', 'September', 'October', 'November', 'December'],
      STANDALONEMONTHS: const [ 'January', 'February', 'March', 'April', 'May',
           'June', 'July', 'August', 'September', 'October', 'November',
           'December'],
      SHORTMONTHS: const [ 'Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul',
           'Aug', 'Sep', 'Oct', 'Nov', 'Dec'],
      STANDALONESHORTMONTHS: const [ 'Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun',
           'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec'],
      WEEKDAYS: const [ 'Sunday', 'Monday', 'Tuesday', 'Wednesday', 'Thursday',
           'Friday', 'Saturday'],
      STANDALONEWEEKDAYS: const [ 'Sunday', 'Monday', 'Tuesday', 'Wednesday',
           'Thursday', 'Friday', 'Saturday'],
      SHORTWEEKDAYS: const [ 'Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat'],
      STANDALONESHORTWEEKDAYS: const [ 'Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri',
           'Sat'],
      NARROWWEEKDAYS: const [ 'S', 'M', 'T', 'W', 'T', 'F', 'S'],
      STANDALONENARROWWEEKDAYS: const [ 'S', 'M', 'T', 'W', 'T', 'F', 'S'],
      SHORTQUARTERS: const [ 'Q1', 'Q2', 'Q3', 'Q4'],
      QUARTERS: const [ '1st quarter', '2nd quarter', '3rd quarter',
           '4th quarter'],
      AMPMS: const [ 'AM', 'PM'],
      DATEFORMATS: const [ 'EEEE d MMMM y', 'd MMMM y', 'dd-MMM-y', 'dd/MM/yy'],
      TIMEFORMATS: const [ 'h:mm:ss a zzzz', 'h:mm:ss a z', 'h:mm:ss a',
           'h:mm a'],
      FIRSTDAYOFWEEK: 6,
      WEEKENDRANGE: const [6, 6],
      FIRSTWEEKCUTOFFDAY: 5),
  /**
   * Date/time formatting symbols for locale en_SG.
   */
  "en_SG" : new DateSymbols(
      NAME: "en_SG",
      ERAS: const [ 'BC', 'AD'],
      ERANAMES: const [ 'Before Christ', 'Anno Domini'],
      NARROWMONTHS: const [ 'J', 'F', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O',
           'N', 'D'],
      STANDALONENARROWMONTHS: const [ 'J', 'F', 'M', 'A', 'M', 'J', 'J', 'A',
           'S', 'O', 'N', 'D'],
      MONTHS: const [ 'January', 'February', 'March', 'April', 'May', 'June',
           'July', 'August', 'September', 'October', 'November', 'December'],
      STANDALONEMONTHS: const [ 'January', 'February', 'March', 'April', 'May',
           'June', 'July', 'August', 'September', 'October', 'November',
           'December'],
      SHORTMONTHS: const [ 'Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul',
           'Aug', 'Sep', 'Oct', 'Nov', 'Dec'],
      STANDALONESHORTMONTHS: const [ 'Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun',
           'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec'],
      WEEKDAYS: const [ 'Sunday', 'Monday', 'Tuesday', 'Wednesday', 'Thursday',
           'Friday', 'Saturday'],
      STANDALONEWEEKDAYS: const [ 'Sunday', 'Monday', 'Tuesday', 'Wednesday',
           'Thursday', 'Friday', 'Saturday'],
      SHORTWEEKDAYS: const [ 'Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat'],
      STANDALONESHORTWEEKDAYS: const [ 'Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri',
           'Sat'],
      NARROWWEEKDAYS: const [ 'S', 'M', 'T', 'W', 'T', 'F', 'S'],
      STANDALONENARROWWEEKDAYS: const [ 'S', 'M', 'T', 'W', 'T', 'F', 'S'],
      SHORTQUARTERS: const [ 'Q1', 'Q2', 'Q3', 'Q4'],
      QUARTERS: const [ '1st quarter', '2nd quarter', '3rd quarter',
           '4th quarter'],
      AMPMS: const [ 'AM', 'PM'],
      DATEFORMATS: const [ 'EEEE, d MMMM, y', 'd MMMM, y', 'd MMM, y',
           'd/M/yy'],
      TIMEFORMATS: const [ 'h:mm:ss a zzzz', 'h:mm:ss a z', 'h:mm:ss a',
           'h:mm a'],
      FIRSTDAYOFWEEK: 6,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 5),
  /**
   * Date/time formatting symbols for locale en_US.
   */
  /**
   * Date/time formatting symbols for locale en_US.
   */
  "en_US" : new DateSymbols(
      NAME: "en_US",
      ERAS: const [ 'BC', 'AD'],
      ERANAMES: const [ 'Before Christ', 'Anno Domini'],
      NARROWMONTHS: const [ 'J', 'F', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O',
           'N', 'D'],
      STANDALONENARROWMONTHS: const [ 'J', 'F', 'M', 'A', 'M', 'J', 'J', 'A',
           'S', 'O', 'N', 'D'],
      MONTHS: const [ 'January', 'February', 'March', 'April', 'May', 'June',
           'July', 'August', 'September', 'October', 'November', 'December'],
      STANDALONEMONTHS: const [ 'January', 'February', 'March', 'April', 'May',
           'June', 'July', 'August', 'September', 'October', 'November',
           'December'],
      SHORTMONTHS: const [ 'Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul',
           'Aug', 'Sep', 'Oct', 'Nov', 'Dec'],
      STANDALONESHORTMONTHS: const [ 'Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun',
           'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec'],
      WEEKDAYS: const [ 'Sunday', 'Monday', 'Tuesday', 'Wednesday', 'Thursday',
           'Friday', 'Saturday'],
      STANDALONEWEEKDAYS: const [ 'Sunday', 'Monday', 'Tuesday', 'Wednesday',
           'Thursday', 'Friday', 'Saturday'],
      SHORTWEEKDAYS: const [ 'Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat'],
      STANDALONESHORTWEEKDAYS: const [ 'Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri',
           'Sat'],
      NARROWWEEKDAYS: const [ 'S', 'M', 'T', 'W', 'T', 'F', 'S'],
      STANDALONENARROWWEEKDAYS: const [ 'S', 'M', 'T', 'W', 'T', 'F', 'S'],
      SHORTQUARTERS: const [ 'Q1', 'Q2', 'Q3', 'Q4'],
      QUARTERS: const [ '1st quarter', '2nd quarter', '3rd quarter',
           '4th quarter'],
      AMPMS: const [ 'AM', 'PM'],
      DATEFORMATS: const [ 'EEEE, MMMM d, y', 'MMMM d, y', 'MMM d, y',
           'M/d/yy'],
      TIMEFORMATS: const [ 'h:mm:ss a zzzz', 'h:mm:ss a z', 'h:mm:ss a',
           'h:mm a'],
      FIRSTDAYOFWEEK: 6,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 5),
  /**
   * Date/time formatting symbols for locale en_ZA.
   */
  "en_ZA" : new DateSymbols(
      NAME: "en_ZA",
      ERAS: const [ 'BC', 'AD'],
      ERANAMES: const [ 'Before Christ', 'Anno Domini'],
      NARROWMONTHS: const [ 'J', 'F', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O',
           'N', 'D'],
      STANDALONENARROWMONTHS: const [ 'J', 'F', 'M', 'A', 'M', 'J', 'J', 'A',
           'S', 'O', 'N', 'D'],
      MONTHS: const [ 'January', 'February', 'March', 'April', 'May', 'June',
           'July', 'August', 'September', 'October', 'November', 'December'],
      STANDALONEMONTHS: const [ 'January', 'February', 'March', 'April', 'May',
           'June', 'July', 'August', 'September', 'October', 'November',
           'December'],
      SHORTMONTHS: const [ 'Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul',
           'Aug', 'Sep', 'Oct', 'Nov', 'Dec'],
      STANDALONESHORTMONTHS: const [ 'Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun',
           'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec'],
      WEEKDAYS: const [ 'Sunday', 'Monday', 'Tuesday', 'Wednesday', 'Thursday',
           'Friday', 'Saturday'],
      STANDALONEWEEKDAYS: const [ 'Sunday', 'Monday', 'Tuesday', 'Wednesday',
           'Thursday', 'Friday', 'Saturday'],
      SHORTWEEKDAYS: const [ 'Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat'],
      STANDALONESHORTWEEKDAYS: const [ 'Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri',
           'Sat'],
      NARROWWEEKDAYS: const [ 'S', 'M', 'T', 'W', 'T', 'F', 'S'],
      STANDALONENARROWWEEKDAYS: const [ 'S', 'M', 'T', 'W', 'T', 'F', 'S'],
      SHORTQUARTERS: const [ 'Q1', 'Q2', 'Q3', 'Q4'],
      QUARTERS: const [ '1st quarter', '2nd quarter', '3rd quarter',
           '4th quarter'],
      AMPMS: const [ 'AM', 'PM'],
      DATEFORMATS: const [ 'EEEE dd MMMM y', 'dd MMMM y', 'dd MMM y',
           'yyyy/MM/dd'],
      TIMEFORMATS: const [ 'h:mm:ss a zzzz', 'h:mm:ss a z', 'h:mm:ss a',
           'h:mm a'],
      FIRSTDAYOFWEEK: 6,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 5),
  /**
   * Date/time formatting symbols for locale es.
   */
  "es" : new DateSymbols(
      NAME: "es",
      ERAS: const [ 'a.C.', 'd.C.'],
      ERANAMES: const [ 'antes de Cristo', 'anno Dómini'],
      NARROWMONTHS: const [ 'E', 'F', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O',
           'N', 'D'],
      STANDALONENARROWMONTHS: const [ 'E', 'F', 'M', 'A', 'M', 'J', 'J', 'A',
           'S', 'O', 'N', 'D'],
      MONTHS: const [ 'enero', 'febrero', 'marzo', 'abril', 'mayo', 'junio',
           'julio', 'agosto', 'septiembre', 'octubre', 'noviembre',
           'diciembre'],
      STANDALONEMONTHS: const [ 'enero', 'febrero', 'marzo', 'abril', 'mayo',
           'junio', 'julio', 'agosto', 'septiembre', 'octubre', 'noviembre',
           'diciembre'],
      SHORTMONTHS: const [ 'ene', 'feb', 'mar', 'abr', 'may', 'jun', 'jul',
           'ago', 'sep', 'oct', 'nov', 'dic'],
      STANDALONESHORTMONTHS: const [ 'ene', 'feb', 'mar', 'abr', 'mayo', 'jun',
           'jul', 'ago', 'sep', 'oct', 'nov', 'dic'],
      WEEKDAYS: const [ 'domingo', 'lunes', 'martes', 'miércoles', 'jueves',
           'viernes', 'sábado'],
      STANDALONEWEEKDAYS: const [ 'domingo', 'lunes', 'martes', 'miércoles',
           'jueves', 'viernes', 'sábado'],
      SHORTWEEKDAYS: const [ 'dom', 'lun', 'mar', 'mié', 'jue', 'vie', 'sáb'],
      STANDALONESHORTWEEKDAYS: const [ 'dom', 'lun', 'mar', 'mié', 'jue',
           'vie', 'sáb'],
      NARROWWEEKDAYS: const [ 'D', 'L', 'M', 'X', 'J', 'V', 'S'],
      STANDALONENARROWWEEKDAYS: const [ 'D', 'L', 'M', 'X', 'J', 'V', 'S'],
      SHORTQUARTERS: const [ 'T1', 'T2', 'T3', 'T4'],
      QUARTERS: const [ '1er trimestre', '2º trimestre', '3er trimestre',
           '4º trimestre'],
      AMPMS: const [ 'a.m.', 'p.m.'],
      DATEFORMATS: const [ 'EEEE, d \'de\' MMMM \'de\' y',
           'd \'de\' MMMM \'de\' y', 'dd/MM/yyyy', 'dd/MM/yy'],
      TIMEFORMATS: const [ 'HH:mm:ss zzzz', 'HH:mm:ss z', 'HH:mm:ss', 'HH:mm'],
      FIRSTDAYOFWEEK: 6,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 5),
  /**
   * Date/time formatting symbols for locale es_419.
   */
  "es_419" : new DateSymbols(
      NAME: "es_419",
      ERAS: const [ 'a.C.', 'd.C.'],
      ERANAMES: const [ 'antes de Cristo', 'anno Dómini'],
      NARROWMONTHS: const [ 'E', 'F', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O',
           'N', 'D'],
      STANDALONENARROWMONTHS: const [ 'E', 'F', 'M', 'A', 'M', 'J', 'J', 'A',
           'S', 'O', 'N', 'D'],
      MONTHS: const [ 'enero', 'febrero', 'marzo', 'abril', 'mayo', 'junio',
           'julio', 'agosto', 'septiembre', 'octubre', 'noviembre',
           'diciembre'],
      STANDALONEMONTHS: const [ 'enero', 'febrero', 'marzo', 'abril', 'mayo',
           'junio', 'julio', 'agosto', 'septiembre', 'octubre', 'noviembre',
           'diciembre'],
      SHORTMONTHS: const [ 'ene', 'feb', 'mar', 'abr', 'may', 'jun', 'jul',
           'ago', 'sep', 'oct', 'nov', 'dic'],
      STANDALONESHORTMONTHS: const [ 'ene', 'feb', 'mar', 'abr', 'mayo', 'jun',
           'jul', 'ago', 'sep', 'oct', 'nov', 'dic'],
      WEEKDAYS: const [ 'domingo', 'lunes', 'martes', 'miércoles', 'jueves',
           'viernes', 'sábado'],
      STANDALONEWEEKDAYS: const [ 'domingo', 'lunes', 'martes', 'miércoles',
           'jueves', 'viernes', 'sábado'],
      SHORTWEEKDAYS: const [ 'dom', 'lun', 'mar', 'mié', 'jue', 'vie', 'sáb'],
      STANDALONESHORTWEEKDAYS: const [ 'dom', 'lun', 'mar', 'mié', 'jue',
           'vie', 'sáb'],
      NARROWWEEKDAYS: const [ 'D', 'L', 'M', 'M', 'J', 'V', 'S'],
      STANDALONENARROWWEEKDAYS: const [ 'D', 'L', 'M', 'M', 'J', 'V', 'S'],
      SHORTQUARTERS: const [ 'T1', 'T2', 'T3', 'T4'],
      QUARTERS: const [ '1er trimestre', '2º trimestre', '3er trimestre',
           '4º trimestre'],
      AMPMS: const [ 'a.m.', 'p.m.'],
      DATEFORMATS: const [ 'EEEE, d \'de\' MMMM \'de\' y',
           'd \'de\' MMMM \'de\' y', 'dd/MM/yyyy', 'dd/MM/yy'],
      TIMEFORMATS: const [ 'HH:mm:ss zzzz', 'HH:mm:ss z', 'HH:mm:ss', 'HH:mm'],
      FIRSTDAYOFWEEK: 6,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 5),
  /**
   * Date/time formatting symbols for locale et.
   */
  "et" : new DateSymbols(
      NAME: "et",
      ERAS: const [ 'e.m.a.', 'm.a.j.'],
      ERANAMES: const [ 'enne meie aega', 'meie aja järgi'],
      NARROWMONTHS: const [ 'J', 'V', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O',
           'N', 'D'],
      STANDALONENARROWMONTHS: const [ 'J', 'V', 'M', 'A', 'M', 'J', 'J', 'A',
           'S', 'O', 'N', 'D'],
      MONTHS: const [ 'jaanuar', 'veebruar', 'märts', 'aprill', 'mai', 'juuni',
           'juuli', 'august', 'september', 'oktoober', 'november', 'detsember'],
      STANDALONEMONTHS: const [ 'jaanuar', 'veebruar', 'märts', 'aprill',
           'mai', 'juuni', 'juuli', 'august', 'september', 'oktoober',
           'november', 'detsember'],
      SHORTMONTHS: const [ 'jaan', 'veebr', 'märts', 'apr', 'mai', 'juuni',
           'juuli', 'aug', 'sept', 'okt', 'nov', 'dets'],
      STANDALONESHORTMONTHS: const [ 'jaan', 'veebr', 'märts', 'apr', 'mai',
           'juuni', 'juuli', 'aug', 'sept', 'okt', 'nov', 'dets'],
      WEEKDAYS: const [ 'pühapäev', 'esmaspäev', 'teisipäev', 'kolmapäev',
           'neljapäev', 'reede', 'laupäev'],
      STANDALONEWEEKDAYS: const [ 'pühapäev', 'esmaspäev', 'teisipäev',
           'kolmapäev', 'neljapäev', 'reede', 'laupäev'],
      SHORTWEEKDAYS: const [ 'P', 'E', 'T', 'K', 'N', 'R', 'L'],
      STANDALONESHORTWEEKDAYS: const [ 'P', 'E', 'T', 'K', 'N', 'R', 'L'],
      NARROWWEEKDAYS: const [ 'P', 'E', 'T', 'K', 'N', 'R', 'L'],
      STANDALONENARROWWEEKDAYS: const [ 'P', 'E', 'T', 'K', 'N', 'R', 'L'],
      SHORTQUARTERS: const [ 'K1', 'K2', 'K3', 'K4'],
      QUARTERS: const [ '1. kvartal', '2. kvartal', '3. kvartal', '4. kvartal'],
      AMPMS: const [ 'enne keskpäeva', 'pärast keskpäeva'],
      DATEFORMATS: const [ 'EEEE, d. MMMM y', 'd. MMMM y', 'dd.MM.yyyy',
           'dd.MM.yy'],
      TIMEFORMATS: const [ 'H:mm.ss zzzz', 'H:mm.ss z', 'H:mm.ss', 'H:mm'],
      FIRSTDAYOFWEEK: 0,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 3),
  /**
   * Date/time formatting symbols for locale eu.
   */
  "eu" : new DateSymbols(
      NAME: "eu",
      ERAS: const [ 'K.a.', 'K.o.'],
      ERANAMES: const [ 'K.a.', 'K.o.'],
      NARROWMONTHS: const [ 'U', 'O', 'M', 'A', 'M', 'E', 'U', 'A', 'I', 'U',
           'A', 'A'],
      STANDALONENARROWMONTHS: const [ 'U', 'O', 'M', 'A', 'M', 'E', 'U', 'A',
           'I', 'U', 'A', 'A'],
      MONTHS: const [ 'urtarrila', 'otsaila', 'martxoa', 'apirila', 'maiatza',
           'ekaina', 'uztaila', 'abuztua', 'iraila', 'urria', 'azaroa',
           'abendua'],
      STANDALONEMONTHS: const [ 'urtarrila', 'otsaila', 'martxoa', 'apirila',
           'maiatza', 'ekaina', 'uztaila', 'abuztua', 'iraila', 'urria',
           'azaroa', 'abendua'],
      SHORTMONTHS: const [ 'urt', 'ots', 'mar', 'api', 'mai', 'eka', 'uzt',
           'abu', 'ira', 'urr', 'aza', 'abe'],
      STANDALONESHORTMONTHS: const [ 'urt', 'ots', 'mar', 'api', 'mai', 'eka',
           'uzt', 'abu', 'ira', 'urr', 'aza', 'abe'],
      WEEKDAYS: const [ 'igandea', 'astelehena', 'asteartea', 'asteazkena',
           'osteguna', 'ostirala', 'larunbata'],
      STANDALONEWEEKDAYS: const [ 'igandea', 'astelehena', 'asteartea',
           'asteazkena', 'osteguna', 'ostirala', 'larunbata'],
      SHORTWEEKDAYS: const [ 'ig', 'al', 'as', 'az', 'og', 'or', 'lr'],
      STANDALONESHORTWEEKDAYS: const [ 'ig', 'al', 'as', 'az', 'og', 'or',
           'lr'],
      NARROWWEEKDAYS: const [ 'I', 'M', 'A', 'A', 'A', 'O', 'I'],
      STANDALONENARROWWEEKDAYS: const [ 'I', 'M', 'A', 'L', 'A', 'O', 'I'],
      SHORTQUARTERS: const [ '1Hh', '2Hh', '3Hh', '4Hh'],
      QUARTERS: const [ '1. hiruhilekoa', '2. hiruhilekoa', '3. hiruhilekoa',
           '4. hiruhilekoa'],
      AMPMS: const [ 'AM', 'PM'],
      DATEFORMATS: const [ 'EEEE, y\'eko\' MMMM\'ren\' dd\'a\'',
           'y\'eko\' MMM\'ren\' dd\'a\'', 'y MMM d', 'yyyy-MM-dd'],
      TIMEFORMATS: const [ 'HH:mm:ss zzzz', 'HH:mm:ss z', 'HH:mm:ss', 'HH:mm'],
      FIRSTDAYOFWEEK: 0,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 3),
  /**
   * Date/time formatting symbols for locale fa.
   */
  "fa" : new DateSymbols(
      NAME: "fa",
      ERAS: const [ 'ق.م.', 'م.'],
      ERANAMES: const [ 'قبل از میلاد', 'میلادی'],
      NARROWMONTHS: const [ 'ژ', 'ف', 'م', 'آ', 'م', 'ژ', 'ژ', 'ا',
           'س', 'ا', 'ن', 'د'],
      STANDALONENARROWMONTHS: const [ 'ژ', 'ف', 'م', 'آ', 'م', 'ژ', 'ژ',
           'ا', 'س', 'ا', 'ن', 'د'],
      MONTHS: const [ 'ژانویهٔ', 'فوریهٔ', 'مارس',
           'آوریل', 'مهٔ', 'ژوئن', 'ژوئیهٔ', 'اوت',
           'سپتامبر', 'اکتبر', 'نوامبر', 'دسامبر'],
      STANDALONEMONTHS: const [ 'ژانویه', 'فوریه', 'مارس',
           'آوریل', 'مه', 'ژوئن', 'ژوئیه', 'اوت',
           'سپتامبر', 'اکتبر', 'نوامبر', 'دسامبر'],
      SHORTMONTHS: const [ 'ژانویهٔ', 'فوریهٔ', 'مارس',
           'آوریل', 'مهٔ', 'ژوئن', 'ژوئیهٔ', 'اوت',
           'سپتامبر', 'اکتبر', 'نوامبر', 'دسامبر'],
      STANDALONESHORTMONTHS: const [ 'ژانویه', 'فوریه', 'مارس',
           'آوریل', 'مه', 'ژوئن', 'ژوئیه', 'اوت',
           'سپتامبر', 'اکتبر', 'نوامبر', 'دسامبر'],
      WEEKDAYS: const [ 'یکشنبه', 'دوشنبه', 'سه‌شنبه',
           'چهارشنبه', 'پنجشنبه', 'جمعه', 'شنبه'],
      STANDALONEWEEKDAYS: const [ 'یکشنبه', 'دوشنبه',
           'سه‌شنبه', 'چهارشنبه', 'پنجشنبه', 'جمعه',
           'شنبه'],
      SHORTWEEKDAYS: const [ 'یکشنبه', 'دوشنبه', 'سه‌شنبه',
           'چهارشنبه', 'پنجشنبه', 'جمعه', 'شنبه'],
      STANDALONESHORTWEEKDAYS: const [ 'یکشنبه', 'دوشنبه',
           'سه‌شنبه', 'چهارشنبه', 'پنجشنبه', 'جمعه',
           'شنبه'],
      NARROWWEEKDAYS: const [ 'ی', 'د', 'س', 'چ', 'پ', 'ج', 'ش'],
      STANDALONENARROWWEEKDAYS: const [ 'ی', 'د', 'س', 'چ', 'پ', 'ج',
           'ش'],
      SHORTQUARTERS: const [ 'س‌م۱', 'س‌م۲', 'س‌م۳',
           'س‌م۴'],
      QUARTERS: const [ 'سه‌ماههٔ اول', 'سه‌ماههٔ دوم',
           'سه‌ماههٔ سوم', 'سه‌ماههٔ چهارم'],
      AMPMS: const [ 'قبل‌ازظهر', 'بعدازظهر'],
      DATEFORMATS: const [ 'EEEE d MMMM y', 'd MMMM y', 'd MMM y', 'yyyy/M/d'],
      TIMEFORMATS: const [ 'H:mm:ss (zzzz)', 'H:mm:ss (z)', 'H:mm:ss', 'H:mm'],
      FIRSTDAYOFWEEK: 5,
      WEEKENDRANGE: const [3, 4],
      FIRSTWEEKCUTOFFDAY: 4),
  /**
   * Date/time formatting symbols for locale fi.
   */
  "fi" : new DateSymbols(
      NAME: "fi",
      ERAS: const [ 'eKr.', 'jKr.'],
      ERANAMES: const [ 'ennen Kristuksen syntymää',
           'jälkeen Kristuksen syntymän'],
      NARROWMONTHS: const [ 'T', 'H', 'M', 'H', 'T', 'K', 'H', 'E', 'S', 'L',
           'M', 'J'],
      STANDALONENARROWMONTHS: const [ 'T', 'H', 'M', 'H', 'T', 'K', 'H', 'E',
           'S', 'L', 'M', 'J'],
      MONTHS: const [ 'tammikuuta', 'helmikuuta', 'maaliskuuta', 'huhtikuuta',
           'toukokuuta', 'kesäkuuta', 'heinäkuuta', 'elokuuta', 'syyskuuta',
           'lokakuuta', 'marraskuuta', 'joulukuuta'],
      STANDALONEMONTHS: const [ 'tammikuu', 'helmikuu', 'maaliskuu', 'huhtikuu',
           'toukokuu', 'kesäkuu', 'heinäkuu', 'elokuu', 'syyskuu', 'lokakuu',
           'marraskuu', 'joulukuu'],
      SHORTMONTHS: const [ 'tammikuuta', 'helmikuuta', 'maaliskuuta',
           'huhtikuuta', 'toukokuuta', 'kesäkuuta', 'heinäkuuta', 'elokuuta',
           'syyskuuta', 'lokakuuta', 'marraskuuta', 'joulukuuta'],
      STANDALONESHORTMONTHS: const [ 'tammi', 'helmi', 'maalis', 'huhti',
           'touko', 'kesä', 'heinä', 'elo', 'syys', 'loka', 'marras',
           'joulu'],
      WEEKDAYS: const [ 'sunnuntaina', 'maanantaina', 'tiistaina',
           'keskiviikkona', 'torstaina', 'perjantaina', 'lauantaina'],
      STANDALONEWEEKDAYS: const [ 'sunnuntai', 'maanantai', 'tiistai',
           'keskiviikko', 'torstai', 'perjantai', 'lauantai'],
      SHORTWEEKDAYS: const [ 'su', 'ma', 'ti', 'ke', 'to', 'pe', 'la'],
      STANDALONESHORTWEEKDAYS: const [ 'su', 'ma', 'ti', 'ke', 'to', 'pe',
           'la'],
      NARROWWEEKDAYS: const [ 'S', 'M', 'T', 'K', 'T', 'P', 'L'],
      STANDALONENARROWWEEKDAYS: const [ 'S', 'M', 'T', 'K', 'T', 'P', 'L'],
      SHORTQUARTERS: const [ '1. nelj.', '2. nelj.', '3. nelj.', '4. nelj.'],
      QUARTERS: const [ '1. neljännes', '2. neljännes', '3. neljännes',
           '4. neljännes'],
      AMPMS: const [ 'ap.', 'ip.'],
      DATEFORMATS: const [ 'cccc, d. MMMM y', 'd. MMMM y', 'd.M.yyyy',
           'd.M.yyyy'],
      TIMEFORMATS: const [ 'H.mm.ss zzzz', 'H.mm.ss z', 'H.mm.ss', 'H.mm'],
      FIRSTDAYOFWEEK: 0,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 3),
  /**
   * Date/time formatting symbols for locale fil.
   */
  "fil" : new DateSymbols(
      NAME: "fil",
      ERAS: const [ 'BC', 'AD'],
      ERANAMES: const [ 'BC', 'AD'],
      NARROWMONTHS: const [ 'E', 'P', 'M', 'A', 'M', 'H', 'H', 'A', 'S', 'O',
           'N', 'D'],
      STANDALONENARROWMONTHS: const [ 'E', 'P', 'M', 'A', 'M', 'H', 'H', 'A',
           'S', 'O', 'N', 'D'],
      MONTHS: const [ 'Enero', 'Pebrero', 'Marso', 'Abril', 'Mayo', 'Hunyo',
           'Hulyo', 'Agosto', 'Setyembre', 'Oktubre', 'Nobyembre', 'Disyembre'],
      STANDALONEMONTHS: const [ 'Enero', 'Pebrero', 'Marso', 'Abril', 'Mayo',
           'Hunyo', 'Hulyo', 'Agosto', 'Setyembre', 'Oktubre', 'Nobyembre',
           'Disyembre'],
      SHORTMONTHS: const [ 'Ene', 'Peb', 'Mar', 'Abr', 'May', 'Hun', 'Hul',
           'Ago', 'Set', 'Okt', 'Nob', 'Dis'],
      STANDALONESHORTMONTHS: const [ 'Ene', 'Peb', 'Mar', 'Abr', 'May', 'Hun',
           'Hul', 'Ago', 'Set', 'Okt', 'Nob', 'Dis'],
      WEEKDAYS: const [ 'Linggo', 'Lunes', 'Martes', 'Miyerkules', 'Huwebes',
           'Biyernes', 'Sabado'],
      STANDALONEWEEKDAYS: const [ 'Linggo', 'Lunes', 'Martes', 'Miyerkules',
           'Huwebes', 'Biyernes', 'Sabado'],
      SHORTWEEKDAYS: const [ 'Lin', 'Lun', 'Mar', 'Mye', 'Huw', 'Bye', 'Sab'],
      STANDALONESHORTWEEKDAYS: const [ 'Lin', 'Lun', 'Mar', 'Miy', 'Huw', 'Biy',
           'Sab'],
      NARROWWEEKDAYS: const [ 'L', 'L', 'M', 'M', 'H', 'B', 'S'],
      STANDALONENARROWWEEKDAYS: const [ 'L', 'L', 'M', 'M', 'H', 'B', 'S'],
      SHORTQUARTERS: const [ 'Q1', 'Q2', 'Q3', 'Q4'],
      QUARTERS: const [ 'ika-1 sangkapat', 'ika-2 sangkapat', 'ika-3 quarter',
           'ika-4 na quarter'],
      AMPMS: const [ 'AM', 'PM'],
      DATEFORMATS: const [ 'EEEE, MMMM dd y', 'MMMM d, y', 'MMM d, y',
           'M/d/yy'],
      TIMEFORMATS: const [ 'HH:mm:ss zzzz', 'HH:mm:ss z', 'HH:mm:ss', 'HH:mm'],
      FIRSTDAYOFWEEK: 6,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 5),
  /**
   * Date/time formatting symbols for locale fr.
   */
  "fr" : new DateSymbols(
      NAME: "fr",
      ERAS: const [ 'av. J.-C.', 'ap. J.-C.'],
      ERANAMES: const [ 'avant Jésus-Christ', 'après Jésus-Christ'],
      NARROWMONTHS: const [ 'J', 'F', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O',
           'N', 'D'],
      STANDALONENARROWMONTHS: const [ 'J', 'F', 'M', 'A', 'M', 'J', 'J', 'A',
           'S', 'O', 'N', 'D'],
      MONTHS: const [ 'janvier', 'février', 'mars', 'avril', 'mai', 'juin',
           'juillet', 'août', 'septembre', 'octobre', 'novembre', 'décembre'],
      STANDALONEMONTHS: const [ 'janvier', 'février', 'mars', 'avril', 'mai',
           'juin', 'juillet', 'août', 'septembre', 'octobre', 'novembre',
           'décembre'],
      SHORTMONTHS: const [ 'janv.', 'févr.', 'mars', 'avr.', 'mai', 'juin',
           'juil.', 'août', 'sept.', 'oct.', 'nov.', 'déc.'],
      STANDALONESHORTMONTHS: const [ 'janv.', 'févr.', 'mars', 'avr.', 'mai',
           'juin', 'juil.', 'août', 'sept.', 'oct.', 'nov.', 'déc.'],
      WEEKDAYS: const [ 'dimanche', 'lundi', 'mardi', 'mercredi', 'jeudi',
           'vendredi', 'samedi'],
      STANDALONEWEEKDAYS: const [ 'dimanche', 'lundi', 'mardi', 'mercredi',
           'jeudi', 'vendredi', 'samedi'],
      SHORTWEEKDAYS: const [ 'dim.', 'lun.', 'mar.', 'mer.', 'jeu.', 'ven.',
           'sam.'],
      STANDALONESHORTWEEKDAYS: const [ 'dim.', 'lun.', 'mar.', 'mer.', 'jeu.',
           'ven.', 'sam.'],
      NARROWWEEKDAYS: const [ 'D', 'L', 'M', 'M', 'J', 'V', 'S'],
      STANDALONENARROWWEEKDAYS: const [ 'D', 'L', 'M', 'M', 'J', 'V', 'S'],
      SHORTQUARTERS: const [ 'T1', 'T2', 'T3', 'T4'],
      QUARTERS: const [ '1er trimestre', '2e trimestre', '3e trimestre',
           '4e trimestre'],
      AMPMS: const [ 'AM', 'PM'],
      DATEFORMATS: const [ 'EEEE d MMMM y', 'd MMMM y', 'd MMM y', 'dd/MM/yy'],
      TIMEFORMATS: const [ 'HH:mm:ss zzzz', 'HH:mm:ss z', 'HH:mm:ss', 'HH:mm'],
      FIRSTDAYOFWEEK: 0,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 3),
  /**
   * Date/time formatting symbols for locale fr_CA.
   */
  "fr_CA" : new DateSymbols(
      NAME: "fr_CA",
      ERAS: const [ 'av. J.-C.', 'ap. J.-C.'],
      ERANAMES: const [ 'avant Jésus-Christ', 'après Jésus-Christ'],
      NARROWMONTHS: const [ 'J', 'F', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O',
           'N', 'D'],
      STANDALONENARROWMONTHS: const [ 'J', 'F', 'M', 'A', 'M', 'J', 'J', 'A',
           'S', 'O', 'N', 'D'],
      MONTHS: const [ 'janvier', 'février', 'mars', 'avril', 'mai', 'juin',
           'juillet', 'août', 'septembre', 'octobre', 'novembre', 'décembre'],
      STANDALONEMONTHS: const [ 'janvier', 'février', 'mars', 'avril', 'mai',
           'juin', 'juillet', 'août', 'septembre', 'octobre', 'novembre',
           'décembre'],
      SHORTMONTHS: const [ 'janv.', 'févr.', 'mars', 'avr.', 'mai', 'juin',
           'juil.', 'août', 'sept.', 'oct.', 'nov.', 'déc.'],
      STANDALONESHORTMONTHS: const [ 'janv.', 'févr.', 'mars', 'avr.', 'mai',
           'juin', 'juil.', 'août', 'sept.', 'oct.', 'nov.', 'déc.'],
      WEEKDAYS: const [ 'dimanche', 'lundi', 'mardi', 'mercredi', 'jeudi',
           'vendredi', 'samedi'],
      STANDALONEWEEKDAYS: const [ 'dimanche', 'lundi', 'mardi', 'mercredi',
           'jeudi', 'vendredi', 'samedi'],
      SHORTWEEKDAYS: const [ 'dim.', 'lun.', 'mar.', 'mer.', 'jeu.', 'ven.',
           'sam.'],
      STANDALONESHORTWEEKDAYS: const [ 'dim.', 'lun.', 'mar.', 'mer.', 'jeu.',
           'ven.', 'sam.'],
      NARROWWEEKDAYS: const [ 'D', 'L', 'M', 'M', 'J', 'V', 'S'],
      STANDALONENARROWWEEKDAYS: const [ 'D', 'L', 'M', 'M', 'J', 'V', 'S'],
      SHORTQUARTERS: const [ 'T1', 'T2', 'T3', 'T4'],
      QUARTERS: const [ '1er trimestre', '2e trimestre', '3e trimestre',
           '4e trimestre'],
      AMPMS: const [ 'AM', 'PM'],
      DATEFORMATS: const [ 'EEEE d MMMM y', 'd MMMM y', 'yyyy-MM-dd',
           'yy-MM-dd'],
      TIMEFORMATS: const [ 'HH \'h\' mm \'min\' ss \'s\' zzzz', 'HH:mm:ss z',
           'HH:mm:ss', 'HH:mm'],
      FIRSTDAYOFWEEK: 6,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 5),
  /**
   * Date/time formatting symbols for locale gl.
   */
  "gl" : new DateSymbols(
      NAME: "gl",
      ERAS: const [ 'a.C.', 'd.C.'],
      ERANAMES: const [ 'antes de Cristo', 'despois de Cristo'],
      NARROWMONTHS: const [ 'X', 'F', 'M', 'A', 'M', 'X', 'X', 'A', 'S', 'O',
           'N', 'D'],
      STANDALONENARROWMONTHS: const [ 'X', 'F', 'M', 'A', 'M', 'X', 'X', 'A',
           'S', 'O', 'N', 'D'],
      MONTHS: const [ 'Xaneiro', 'Febreiro', 'Marzo', 'Abril', 'Maio', 'Xuño',
           'Xullo', 'Agosto', 'Setembro', 'Outubro', 'Novembro', 'Decembro'],
      STANDALONEMONTHS: const [ 'Xaneiro', 'Febreiro', 'Marzo', 'Abril', 'Maio',
           'Xuño', 'Xullo', 'Agosto', 'Setembro', 'Outubro', 'Novembro',
           'Decembro'],
      SHORTMONTHS: const [ 'Xan', 'Feb', 'Mar', 'Abr', 'Mai', 'Xuñ', 'Xul',
           'Ago', 'Set', 'Out', 'Nov', 'Dec'],
      STANDALONESHORTMONTHS: const [ 'Xan', 'Feb', 'Mar', 'Abr', 'Mai', 'Xuñ',
           'Xul', 'Ago', 'Set', 'Out', 'Nov', 'Dec'],
      WEEKDAYS: const [ 'Domingo', 'Luns', 'Martes', 'Mércores', 'Xoves',
           'Venres', 'Sábado'],
      STANDALONEWEEKDAYS: const [ 'Domingo', 'Luns', 'Martes', 'Mércores',
           'Xoves', 'Venres', 'Sábado'],
      SHORTWEEKDAYS: const [ 'Dom', 'Lun', 'Mar', 'Mér', 'Xov', 'Ven', 'Sáb'],
      STANDALONESHORTWEEKDAYS: const [ 'Dom', 'Lun', 'Mar', 'Mér', 'Xov',
           'Ven', 'Sáb'],
      NARROWWEEKDAYS: const [ 'D', 'L', 'M', 'M', 'X', 'V', 'S'],
      STANDALONENARROWWEEKDAYS: const [ 'D', 'L', 'M', 'M', 'X', 'V', 'S'],
      SHORTQUARTERS: const [ 'T1', 'T2', 'T3', 'T4'],
      QUARTERS: const [ '1o trimestre', '2o trimestre', '3o trimestre',
           '4o trimestre'],
      AMPMS: const [ 'a.m.', 'p.m.'],
      DATEFORMATS: const [ 'EEEE dd MMMM y', 'dd MMMM y', 'd MMM, y',
           'dd/MM/yy'],
      TIMEFORMATS: const [ 'HH:mm:ss zzzz', 'HH:mm:ss z', 'HH:mm:ss', 'HH:mm'],
      FIRSTDAYOFWEEK: 0,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 3),
  /**
   * Date/time formatting symbols for locale gsw.
   */
  "gsw" : new DateSymbols(
      NAME: "gsw",
      ERAS: const [ 'v. Chr.', 'n. Chr.'],
      ERANAMES: const [ 'v. Chr.', 'n. Chr.'],
      NARROWMONTHS: const [ 'J', 'F', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O',
           'N', 'D'],
      STANDALONENARROWMONTHS: const [ 'J', 'F', 'M', 'A', 'M', 'J', 'J', 'A',
           'S', 'O', 'N', 'D'],
      MONTHS: const [ 'Januar', 'Februar', 'März', 'April', 'Mai', 'Juni',
           'Juli', 'Auguscht', 'Septämber', 'Oktoober', 'Novämber',
           'Dezämber'],
      STANDALONEMONTHS: const [ 'Januar', 'Februar', 'März', 'April', 'Mai',
           'Juni', 'Juli', 'Auguscht', 'Septämber', 'Oktoober', 'Novämber',
           'Dezämber'],
      SHORTMONTHS: const [ 'Jan', 'Feb', 'Mär', 'Apr', 'Mai', 'Jun', 'Jul',
           'Aug', 'Sep', 'Okt', 'Nov', 'Dez'],
      STANDALONESHORTMONTHS: const [ 'Jan', 'Feb', 'Mär', 'Apr', 'Mai', 'Jun',
           'Jul', 'Aug', 'Sep', 'Okt', 'Nov', 'Dez'],
      WEEKDAYS: const [ 'Sunntig', 'Määntig', 'Ziischtig', 'Mittwuch',
           'Dunschtig', 'Friitig', 'Samschtig'],
      STANDALONEWEEKDAYS: const [ 'Sunntig', 'Määntig', 'Ziischtig',
           'Mittwuch', 'Dunschtig', 'Friitig', 'Samschtig'],
      SHORTWEEKDAYS: const [ 'Su.', 'Mä.', 'Zi.', 'Mi.', 'Du.', 'Fr.', 'Sa.'],
      STANDALONESHORTWEEKDAYS: const [ 'Su.', 'Mä.', 'Zi.', 'Mi.', 'Du.',
           'Fr.', 'Sa.'],
      NARROWWEEKDAYS: const [ 'S', 'M', 'D', 'M', 'D', 'F', 'S'],
      STANDALONENARROWWEEKDAYS: const [ 'S', 'M', 'D', 'M', 'D', 'F', 'S'],
      SHORTQUARTERS: const [ 'Q1', 'Q2', 'Q3', 'Q4'],
      QUARTERS: const [ '1. Quartal', '2. Quartal', '3. Quartal', '4. Quartal'],
      AMPMS: const [ 'vorm.', 'nam.'],
      DATEFORMATS: const [ 'EEEE, d. MMMM y', 'd. MMMM y', 'dd.MM.yyyy',
           'dd.MM.yy'],
      TIMEFORMATS: const [ 'HH:mm:ss zzzz', 'HH:mm:ss z', 'HH:mm:ss', 'HH:mm'],
      FIRSTDAYOFWEEK: 0,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 6),
  /**
   * Date/time formatting symbols for locale gu.
   */
  "gu" : new DateSymbols(
      NAME: "gu",
      ERAS: const [ 'ઈલુના જન્મ પહેસાં',
           'ઇસવીસન'],
      ERANAMES: const [ 'ઈસવીસન પૂર્વે',
           'ઇસવીસન'],
      NARROWMONTHS: const [ 'જા', 'ફે', 'મા', 'એ', 'મે',
           'જૂ', 'જુ', 'ઑ', 'સ', 'ઑ', 'ન', 'ડિ'],
      STANDALONENARROWMONTHS: const [ 'જા', 'ફે', 'મા', 'એ',
           'મે', 'જૂ', 'જુ', 'ઑ', 'સ', 'ઑ', 'ન', 'ડિ'],
      MONTHS: const [ 'જાન્યુઆરી',
           'ફેબ્રુઆરી', 'માર્ચ',
           'એપ્રિલ', 'મે', 'જૂન', 'જુલાઈ',
           'ઑગસ્ટ', 'સપ્ટેમ્બર',
           'ઑક્ટોબર', 'નવેમ્બર',
           'ડિસેમ્બર'],
      STANDALONEMONTHS: const [ 'જાન્યુઆરી',
           'ફેબ્રુઆરી', 'માર્ચ',
           'એપ્રિલ', 'મે', 'જૂન', 'જુલાઈ',
           'ઑગસ્ટ', 'સપ્ટેમ્બર',
           'ઑક્ટોબર', 'નવેમ્બર',
           'ડિસેમ્બર'],
      SHORTMONTHS: const [ 'જાન્યુ', 'ફેબ્રુ',
           'માર્ચ', 'એપ્રિલ', 'મે', 'જૂન',
           'જુલાઈ', 'ઑગસ્ટ', 'સપ્ટે',
           'ઑક્ટો', 'નવે', 'ડિસે'],
      STANDALONESHORTMONTHS: const [ 'જાન્યુ', 'ફેબ્રુ',
           'માર્ચ', 'એપ્રિલ', 'મે', 'જૂન',
           'જુલાઈ', 'ઑગસ્ટ', 'સપ્ટે',
           'ઑક્ટો', 'નવે', 'ડિસે'],
      WEEKDAYS: const [ 'રવિવાર', 'સોમવાર',
           'મંગળવાર', 'બુધવાર',
           'ગુરુવાર', 'શુક્રવાર',
           'શનિવાર'],
      STANDALONEWEEKDAYS: const [ 'રવિવાર', 'સોમવાર',
           'મંગળવાર', 'બુધવાર',
           'ગુરુવાર', 'શુક્રવાર',
           'શનિવાર'],
      SHORTWEEKDAYS: const [ 'રવિ', 'સોમ', 'મંગળ',
           'બુધ', 'ગુરુ', 'શુક્ર', 'શનિ'],
      STANDALONESHORTWEEKDAYS: const [ 'રવિ', 'સોમ', 'મંગળ',
           'બુધ', 'ગુરુ', 'શુક્ર', 'શનિ'],
      NARROWWEEKDAYS: const [ 'ર', 'સો', 'મં', 'બુ', 'ગુ',
           'શુ', 'શ'],
      STANDALONENARROWWEEKDAYS: const [ 'ર', 'સો', 'મં', 'બુ',
           'ગુ', 'શુ', 'શ'],
      SHORTQUARTERS: const [ 'પેહલા હંત 1', 'Q2', 'Q3',
           'ચૌતા હંત 4'],
      QUARTERS: const [ 'પેહલા હંત 1',
           'ડૂસઋા હંત 2', 'તીસઋા હંત 3',
           'ચૌતા હંત 4'],
      AMPMS: const [ 'am', 'pm'],
      DATEFORMATS: const [ 'EEEE, d MMMM, y', 'd MMMM, y', 'd MMM, y',
           'd-MM-yy'],
      TIMEFORMATS: const [ 'hh:mm:ss a zzzz', 'hh:mm:ss a z', 'hh:mm:ss a',
           'hh:mm a'],
      FIRSTDAYOFWEEK: 6,
      WEEKENDRANGE: const [6, 6],
      FIRSTWEEKCUTOFFDAY: 5),
  /**
   * Date/time formatting symbols for locale he.
   */
  "he" : new DateSymbols(
      NAME: "he",
      ERAS: const [ 'לפנה״ס', 'לסה״נ'],
      ERANAMES: const [ 'לפני הספירה', 'לספירה'],
      NARROWMONTHS: const [ '1', '2', '3', '4', '5', '6', '7', '8', '9', '10',
           '11', '12'],
      STANDALONENARROWMONTHS: const [ '1', '2', '3', '4', '5', '6', '7', '8',
           '9', '10', '11', '12'],
      MONTHS: const [ 'ינואר', 'פברואר', 'מרץ', 'אפריל',
           'מאי', 'יוני', 'יולי', 'אוגוסט', 'ספטמבר',
           'אוקטובר', 'נובמבר', 'דצמבר'],
      STANDALONEMONTHS: const [ 'ינואר', 'פברואר', 'מרץ',
           'אפריל', 'מאי', 'יוני', 'יולי', 'אוגוסט',
           'ספטמבר', 'אוקטובר', 'נובמבר', 'דצמבר'],
      SHORTMONTHS: const [ 'ינו', 'פבר', 'מרץ', 'אפר', 'מאי',
           'יונ', 'יול', 'אוג', 'ספט', 'אוק', 'נוב',
           'דצמ'],
      STANDALONESHORTMONTHS: const [ 'ינו׳', 'פבר׳', 'מרץ',
           'אפר׳', 'מאי', 'יונ׳', 'יול׳', 'אוג׳', 'ספט׳',
           'אוק׳', 'נוב׳', 'דצמ׳'],
      WEEKDAYS: const [ 'יום ראשון', 'יום שני',
           'יום שלישי', 'יום רביעי', 'יום חמישי',
           'יום שישי', 'יום שבת'],
      STANDALONEWEEKDAYS: const [ 'יום ראשון', 'יום שני',
           'יום שלישי', 'יום רביעי', 'יום חמישי',
           'יום שישי', 'יום שבת'],
      SHORTWEEKDAYS: const [ 'יום א׳', 'יום ב׳', 'יום ג׳',
           'יום ד׳', 'יום ה׳', 'יום ו׳', 'שבת'],
      STANDALONESHORTWEEKDAYS: const [ 'יום א׳', 'יום ב׳',
           'יום ג׳', 'יום ד׳', 'יום ה׳', 'יום ו׳',
           'שבת'],
      NARROWWEEKDAYS: const [ 'א', 'ב', 'ג', 'ד', 'ה', 'ו', 'ש'],
      STANDALONENARROWWEEKDAYS: const [ 'א', 'ב', 'ג', 'ד', 'ה', 'ו',
           'ש'],
      SHORTQUARTERS: const [ 'רבעון 1', 'רבעון 2', 'רבעון 3',
           'רבעון 4'],
      QUARTERS: const [ 'רבעון 1', 'רבעון 2', 'רבעון 3',
           'רבעון 4'],
      AMPMS: const [ 'לפנה״צ', 'אחה״צ'],
      DATEFORMATS: const [ 'EEEE, d בMMMM y', 'd בMMMM y', 'd בMMM yyyy',
           'dd/MM/yy'],
      TIMEFORMATS: const [ 'HH:mm:ss zzzz', 'HH:mm:ss z', 'HH:mm:ss', 'HH:mm'],
      FIRSTDAYOFWEEK: 6,
      WEEKENDRANGE: const [4, 5],
      FIRSTWEEKCUTOFFDAY: 5),
  /**
   * Date/time formatting symbols for locale hi.
   */
  "hi" : new DateSymbols(
      NAME: "hi",
      ERAS: const [ 'ईसापूर्व', 'सन'],
      ERANAMES: const [ 'ईसापूर्व', 'सन'],
      NARROWMONTHS: const [ 'ज', 'फ़', 'मा', 'अ', 'म', 'जू',
           'जु', 'अ', 'सि', 'अ', 'न', 'दि'],
      STANDALONENARROWMONTHS: const [ 'ज', 'फ़', 'मा', 'अ', 'म',
           'जू', 'जु', 'अ', 'सि', 'अ', 'न', 'दि'],
      MONTHS: const [ 'जनवरी', 'फरवरी', 'मार्च',
           'अप्रैल', 'मई', 'जून', 'जुलाई',
           'अगस्त', 'सितम्बर', 'अक्तूबर',
           'नवम्बर', 'दिसम्बर'],
      STANDALONEMONTHS: const [ 'जनवरी', 'फरवरी',
           'मार्च', 'अप्रैल', 'मई', 'जून',
           'जुलाई', 'अगस्त', 'सितम्बर',
           'अक्तूबर', 'नवम्बर',
           'दिसम्बर'],
      SHORTMONTHS: const [ 'जनवरी', 'फरवरी',
           'मार्च', 'अप्रैल', 'मई', 'जून',
           'जुलाई', 'अगस्त', 'सितम्बर',
           'अक्तूबर', 'नवम्बर',
           'दिसम्बर'],
      STANDALONESHORTMONTHS: const [ 'जनवरी', 'फरवरी',
           'मार्च', 'अप्रैल', 'मई', 'जून',
           'जुलाई', 'अगस्त', 'सितम्बर',
           'अक्तूबर', 'नवम्बर',
           'दिसम्बर'],
      WEEKDAYS: const [ 'रविवार', 'सोमवार',
           'मंगलवार', 'बुधवार',
           'बृहस्पतिवार', 'शुक्रवार',
           'शनिवार'],
      STANDALONEWEEKDAYS: const [ 'रविवार', 'सोमवार',
           'मंगलवार', 'बुधवार',
           'बृहस्पतिवार', 'शुक्रवार',
           'शनिवार'],
      SHORTWEEKDAYS: const [ 'रवि.', 'सोम.', 'मंगल.',
           'बुध.', 'बृह.', 'शुक्र.', 'शनि.'],
      STANDALONESHORTWEEKDAYS: const [ 'रवि.', 'सोम.',
           'मंगल.', 'बुध.', 'बृह.', 'शुक्र.',
           'शनि.'],
      NARROWWEEKDAYS: const [ 'र', 'सो', 'मं', 'बु', 'गु',
           'शु', 'श'],
      STANDALONENARROWWEEKDAYS: const [ 'र', 'सो', 'मं', 'बु',
           'गु', 'शु', 'श'],
      SHORTQUARTERS: const [ 'तिमाही',
           'दूसरी तिमाही',
           'तीसरी तिमाही',
           'चौथी तिमाही'],
      QUARTERS: const [ 'तिमाही',
           'दूसरी तिमाही',
           'तीसरी तिमाही',
           'चौथी तिमाही'],
      AMPMS: const [ 'am', 'pm'],
      DATEFORMATS: const [ 'EEEE, d MMMM y', 'd MMMM y', 'dd-MM-yyyy',
           'd-M-yy'],
      TIMEFORMATS: const [ 'h:mm:ss a zzzz', 'h:mm:ss a z', 'h:mm:ss a',
           'h:mm a'],
      FIRSTDAYOFWEEK: 6,
      WEEKENDRANGE: const [6, 6],
      FIRSTWEEKCUTOFFDAY: 5),
  /**
   * Date/time formatting symbols for locale hr.
   */
  "hr" : new DateSymbols(
      NAME: "hr",
      ERAS: const [ 'p. n. e.', 'A. D.'],
      ERANAMES: const [ 'Prije Krista', 'Poslije Krista'],
      NARROWMONTHS: const [ '1.', '2.', '3.', '4.', '5.', '6.', '7.', '8.',
           '9.', '10.', '11.', '12.'],
      STANDALONENARROWMONTHS: const [ '1.', '2.', '3.', '4.', '5.', '6.', '7.',
           '8.', '9.', '10.', '11.', '12.'],
      MONTHS: const [ 'siječnja', 'veljače', 'ožujka', 'travnja', 'svibnja',
           'lipnja', 'srpnja', 'kolovoza', 'rujna', 'listopada', 'studenoga',
           'prosinca'],
      STANDALONEMONTHS: const [ 'siječanj', 'veljača', 'ožujak', 'travanj',
           'svibanj', 'lipanj', 'srpanj', 'kolovoz', 'rujan', 'listopad',
           'studeni', 'prosinac'],
      SHORTMONTHS: const [ 'sij', 'velj', 'ožu', 'tra', 'svi', 'lip', 'srp',
           'kol', 'ruj', 'lis', 'stu', 'pro'],
      STANDALONESHORTMONTHS: const [ 'sij', 'velj', 'ožu', 'tra', 'svi', 'lip',
           'srp', 'kol', 'ruj', 'lis', 'stu', 'pro'],
      WEEKDAYS: const [ 'nedjelja', 'ponedjeljak', 'utorak', 'srijeda',
           'četvrtak', 'petak', 'subota'],
      STANDALONEWEEKDAYS: const [ 'nedjelja', 'ponedjeljak', 'utorak',
           'srijeda', 'četvrtak', 'petak', 'subota'],
      SHORTWEEKDAYS: const [ 'ned', 'pon', 'uto', 'sri', 'čet', 'pet', 'sub'],
      STANDALONESHORTWEEKDAYS: const [ 'ned', 'pon', 'uto', 'sri', 'čet',
           'pet', 'sub'],
      NARROWWEEKDAYS: const [ 'N', 'P', 'U', 'S', 'Č', 'P', 'S'],
      STANDALONENARROWWEEKDAYS: const [ 'n', 'p', 'u', 's', 'č', 'p', 's'],
      SHORTQUARTERS: const [ '1kv', '2kv', '3kv', '4kv'],
      QUARTERS: const [ '1. kvartal', '2. kvartal', '3. kvartal', '4. kvartal'],
      AMPMS: const [ 'AM', 'PM'],
      DATEFORMATS: const [ 'EEEE, d. MMMM y.', 'd. MMMM y.', 'd. M. y.',
           'd.M.y.'],
      TIMEFORMATS: const [ 'HH:mm:ss zzzz', 'HH:mm:ss z', 'HH:mm:ss', 'HH:mm'],
      FIRSTDAYOFWEEK: 0,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 6),
  /**
   * Date/time formatting symbols for locale hu.
   */
  "hu" : new DateSymbols(
      NAME: "hu",
      ERAS: const [ 'i. e.', 'i. sz.'],
      ERANAMES: const [ 'időszámításunk előtt',
           'időszámításunk szerint'],
      NARROWMONTHS: const [ 'J', 'F', 'M', 'Á', 'M', 'J', 'J', 'Á', 'Sz', 'O',
           'N', 'D'],
      STANDALONENARROWMONTHS: const [ 'J', 'F', 'M', 'Á', 'M', 'J', 'J', 'A',
           'Sz', 'O', 'N', 'D'],
      MONTHS: const [ 'január', 'február', 'március', 'április', 'május',
           'június', 'július', 'augusztus', 'szeptember', 'október',
           'november', 'december'],
      STANDALONEMONTHS: const [ 'január', 'február', 'március', 'április',
           'május', 'június', 'július', 'augusztus', 'szeptember',
           'október', 'november', 'december'],
      SHORTMONTHS: const [ 'jan.', 'febr.', 'márc.', 'ápr.', 'máj.', 'jún.',
           'júl.', 'aug.', 'szept.', 'okt.', 'nov.', 'dec.'],
      STANDALONESHORTMONTHS: const [ 'jan.', 'febr.', 'márc.', 'ápr.',
           'máj.', 'jún.', 'júl.', 'aug.', 'szept.', 'okt.', 'nov.', 'dec.'],
      WEEKDAYS: const [ 'vasárnap', 'hétfő', 'kedd', 'szerda',
           'csütörtök', 'péntek', 'szombat'],
      STANDALONEWEEKDAYS: const [ 'vasárnap', 'hétfő', 'kedd', 'szerda',
           'csütörtök', 'péntek', 'szombat'],
      SHORTWEEKDAYS: const [ 'V', 'H', 'K', 'Sze', 'Cs', 'P', 'Szo'],
      STANDALONESHORTWEEKDAYS: const [ 'V', 'H', 'K', 'Sze', 'Cs', 'P', 'Szo'],
      NARROWWEEKDAYS: const [ 'V', 'H', 'K', 'Sz', 'Cs', 'P', 'Sz'],
      STANDALONENARROWWEEKDAYS: const [ 'V', 'H', 'K', 'Sz', 'Cs', 'P', 'Sz'],
      SHORTQUARTERS: const [ 'N1', 'N2', 'N3', 'N4'],
      QUARTERS: const [ 'I. negyedév', 'II. negyedév', 'III. negyedév',
           'IV. negyedév'],
      AMPMS: const [ 'de.', 'du.'],
      DATEFORMATS: const [ 'y. MMMM d., EEEE', 'y. MMMM d.', 'yyyy.MM.dd.',
           'yyyy.MM.dd.'],
      TIMEFORMATS: const [ 'H:mm:ss zzzz', 'H:mm:ss z', 'H:mm:ss', 'H:mm'],
      FIRSTDAYOFWEEK: 0,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 6),
  /**
   * Date/time formatting symbols for locale id.
   */
  "id" : new DateSymbols(
      NAME: "id",
      ERAS: const [ 'SM', 'M'],
      ERANAMES: const [ 'SM', 'M'],
      NARROWMONTHS: const [ 'J', 'F', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O',
           'N', 'D'],
      STANDALONENARROWMONTHS: const [ 'J', 'F', 'M', 'A', 'M', 'J', 'J', 'A',
           'S', 'O', 'N', 'D'],
      MONTHS: const [ 'Januari', 'Februari', 'Maret', 'April', 'Mei', 'Juni',
           'Juli', 'Agustus', 'September', 'Oktober', 'November', 'Desember'],
      STANDALONEMONTHS: const [ 'Januari', 'Februari', 'Maret', 'April', 'Mei',
           'Juni', 'Juli', 'Agustus', 'September', 'Oktober', 'November',
           'Desember'],
      SHORTMONTHS: const [ 'Jan', 'Feb', 'Mar', 'Apr', 'Mei', 'Jun', 'Jul',
           'Agt', 'Sep', 'Okt', 'Nov', 'Des'],
      STANDALONESHORTMONTHS: const [ 'Jan', 'Feb', 'Mar', 'Apr', 'Mei', 'Jun',
           'Jul', 'Agt', 'Sep', 'Okt', 'Nov', 'Des'],
      WEEKDAYS: const [ 'Minggu', 'Senin', 'Selasa', 'Rabu', 'Kamis', 'Jumat',
           'Sabtu'],
      STANDALONEWEEKDAYS: const [ 'Minggu', 'Senin', 'Selasa', 'Rabu', 'Kamis',
           'Jumat', 'Sabtu'],
      SHORTWEEKDAYS: const [ 'Min', 'Sen', 'Sel', 'Rab', 'Kam', 'Jum', 'Sab'],
      STANDALONESHORTWEEKDAYS: const [ 'Min', 'Sen', 'Sel', 'Rab', 'Kam', 'Jum',
           'Sab'],
      NARROWWEEKDAYS: const [ 'M', 'S', 'S', 'R', 'K', 'J', 'S'],
      STANDALONENARROWWEEKDAYS: const [ 'M', 'S', 'S', 'R', 'K', 'J', 'S'],
      SHORTQUARTERS: const [ 'K1', 'K2', 'K3', 'K4'],
      QUARTERS: const [ 'kuartal pertama', 'kuartal kedua', 'kuartal ketiga',
           'kuartal keempat'],
      AMPMS: const [ 'AM', 'PM'],
      DATEFORMATS: const [ 'EEEE, dd MMMM yyyy', 'd MMMM yyyy', 'd MMM yyyy',
           'dd/MM/yy'],
      TIMEFORMATS: const [ 'H:mm:ss zzzz', 'HH:mm:ss z', 'HH:mm:ss', 'HH:mm'],
      FIRSTDAYOFWEEK: 6,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 5),
  /**
   * Date/time formatting symbols for locale in.
   */
  "in" : new DateSymbols(
      NAME: "in",
      ERAS: const [ 'SM', 'M'],
      ERANAMES: const [ 'SM', 'M'],
      NARROWMONTHS: const [ 'J', 'F', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O',
           'N', 'D'],
      STANDALONENARROWMONTHS: const [ 'J', 'F', 'M', 'A', 'M', 'J', 'J', 'A',
           'S', 'O', 'N', 'D'],
      MONTHS: const [ 'Januari', 'Februari', 'Maret', 'April', 'Mei', 'Juni',
           'Juli', 'Agustus', 'September', 'Oktober', 'November', 'Desember'],
      STANDALONEMONTHS: const [ 'Januari', 'Februari', 'Maret', 'April', 'Mei',
           'Juni', 'Juli', 'Agustus', 'September', 'Oktober', 'November',
           'Desember'],
      SHORTMONTHS: const [ 'Jan', 'Feb', 'Mar', 'Apr', 'Mei', 'Jun', 'Jul',
           'Agt', 'Sep', 'Okt', 'Nov', 'Des'],
      STANDALONESHORTMONTHS: const [ 'Jan', 'Feb', 'Mar', 'Apr', 'Mei', 'Jun',
           'Jul', 'Agt', 'Sep', 'Okt', 'Nov', 'Des'],
      WEEKDAYS: const [ 'Minggu', 'Senin', 'Selasa', 'Rabu', 'Kamis', 'Jumat',
           'Sabtu'],
      STANDALONEWEEKDAYS: const [ 'Minggu', 'Senin', 'Selasa', 'Rabu', 'Kamis',
           'Jumat', 'Sabtu'],
      SHORTWEEKDAYS: const [ 'Min', 'Sen', 'Sel', 'Rab', 'Kam', 'Jum', 'Sab'],
      STANDALONESHORTWEEKDAYS: const [ 'Min', 'Sen', 'Sel', 'Rab', 'Kam', 'Jum',
           'Sab'],
      NARROWWEEKDAYS: const [ 'M', 'S', 'S', 'R', 'K', 'J', 'S'],
      STANDALONENARROWWEEKDAYS: const [ 'M', 'S', 'S', 'R', 'K', 'J', 'S'],
      SHORTQUARTERS: const [ 'K1', 'K2', 'K3', 'K4'],
      QUARTERS: const [ 'kuartal pertama', 'kuartal kedua', 'kuartal ketiga',
           'kuartal keempat'],
      AMPMS: const [ 'AM', 'PM'],
      DATEFORMATS: const [ 'EEEE, dd MMMM yyyy', 'd MMMM yyyy', 'd MMM yyyy',
           'dd/MM/yy'],
      TIMEFORMATS: const [ 'H:mm:ss zzzz', 'HH:mm:ss z', 'HH:mm:ss', 'HH:mm'],
      FIRSTDAYOFWEEK: 6,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 5),
  /**
   * Date/time formatting symbols for locale is.
   */
  "is" : new DateSymbols(
      NAME: "is",
      ERAS: const [ 'fyrir Krist', 'eftir Krist'],
      ERANAMES: const [ 'fyrir Krist', 'eftir Krist'],
      NARROWMONTHS: const [ 'J', 'F', 'M', 'A', 'M', 'J', 'J', 'Á', 'L', 'O',
           'N', 'D'],
      STANDALONENARROWMONTHS: const [ 'j', 'f', 'm', 'a', 'm', 'j', 'j', 'á',
           's', 'o', 'n', 'd'],
      MONTHS: const [ 'janúar', 'febrúar', 'mars', 'apríl', 'maí', 'júní',
           'júlí', 'ágúst', 'september', 'október', 'nóvember',
           'desember'],
      STANDALONEMONTHS: const [ 'janúar', 'febrúar', 'mars', 'apríl', 'maí',
           'júní', 'júlí', 'ágúst', 'september', 'október', 'nóvember',
           'desember'],
      SHORTMONTHS: const [ 'jan', 'feb', 'mar', 'apr', 'maí', 'jún', 'júl',
           'ágú', 'sep', 'okt', 'nóv', 'des'],
      STANDALONESHORTMONTHS: const [ 'jan', 'feb', 'mar', 'apr', 'maí', 'jún',
           'júl', 'ágú', 'sep', 'okt', 'nóv', 'des'],
      WEEKDAYS: const [ 'sunnudagur', 'mánudagur', 'þriðjudagur',
           'miðvikudagur', 'fimmtudagur', 'föstudagur', 'laugardagur'],
      STANDALONEWEEKDAYS: const [ 'sunnudagur', 'mánudagur', 'þriðjudagur',
           'miðvikudagur', 'fimmtudagur', 'föstudagur', 'laugardagur'],
      SHORTWEEKDAYS: const [ 'sun', 'mán', 'þri', 'mið', 'fim', 'fös',
           'lau'],
      STANDALONESHORTWEEKDAYS: const [ 'sun', 'mán', 'þri', 'mið', 'fim',
           'fös', 'lau'],
      NARROWWEEKDAYS: const [ 'S', 'M', 'Þ', 'M', 'F', 'F', 'L'],
      STANDALONENARROWWEEKDAYS: const [ 's', 'm', 'þ', 'm', 'f', 'f', 'l'],
      SHORTQUARTERS: const [ 'F1', 'F2', 'F3', 'F4'],
      QUARTERS: const [ '1st fjórðungur', '2nd fjórðungur',
           '3rd fjórðungur', '4th fjórðungur'],
      AMPMS: const [ 'f.h.', 'e.h.'],
      DATEFORMATS: const [ 'EEEE, d. MMMM y', 'd. MMMM y', 'd.M.yyyy',
           'd.M.yyyy'],
      TIMEFORMATS: const [ 'HH:mm:ss zzzz', 'HH:mm:ss z', 'HH:mm:ss', 'HH:mm'],
      FIRSTDAYOFWEEK: 0,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 3),
  /**
   * Date/time formatting symbols for locale it.
   */
  "it" : new DateSymbols(
      NAME: "it",
      ERAS: const [ 'aC', 'dC'],
      ERANAMES: const [ 'a.C.', 'd.C'],
      NARROWMONTHS: const [ 'G', 'F', 'M', 'A', 'M', 'G', 'L', 'A', 'S', 'O',
           'N', 'D'],
      STANDALONENARROWMONTHS: const [ 'G', 'F', 'M', 'A', 'M', 'G', 'L', 'A',
           'S', 'O', 'N', 'D'],
      MONTHS: const [ 'gennaio', 'febbraio', 'marzo', 'aprile', 'maggio',
           'giugno', 'luglio', 'agosto', 'settembre', 'ottobre', 'novembre',
           'dicembre'],
      STANDALONEMONTHS: const [ 'Gennaio', 'Febbraio', 'Marzo', 'Aprile',
           'Maggio', 'Giugno', 'Luglio', 'Agosto', 'Settembre', 'Ottobre',
           'Novembre', 'Dicembre'],
      SHORTMONTHS: const [ 'gen', 'feb', 'mar', 'apr', 'mag', 'giu', 'lug',
           'ago', 'set', 'ott', 'nov', 'dic'],
      STANDALONESHORTMONTHS: const [ 'gen', 'feb', 'mar', 'apr', 'mag', 'giu',
           'lug', 'ago', 'set', 'ott', 'nov', 'dic'],
      WEEKDAYS: const [ 'domenica', 'lunedì', 'martedì', 'mercoledì',
           'giovedì', 'venerdì', 'sabato'],
      STANDALONEWEEKDAYS: const [ 'Domenica', 'Lunedì', 'Martedì',
           'Mercoledì', 'Giovedì', 'Venerdì', 'Sabato'],
      SHORTWEEKDAYS: const [ 'dom', 'lun', 'mar', 'mer', 'gio', 'ven', 'sab'],
      STANDALONESHORTWEEKDAYS: const [ 'dom', 'lun', 'mar', 'mer', 'gio', 'ven',
           'sab'],
      NARROWWEEKDAYS: const [ 'D', 'L', 'M', 'M', 'G', 'V', 'S'],
      STANDALONENARROWWEEKDAYS: const [ 'D', 'L', 'M', 'M', 'G', 'V', 'S'],
      SHORTQUARTERS: const [ 'T1', 'T2', 'T3', 'T4'],
      QUARTERS: const [ '1o trimestre', '2o trimestre', '3o trimestre',
           '4o trimestre'],
      AMPMS: const [ 'm.', 'p.'],
      DATEFORMATS: const [ 'EEEE d MMMM y', 'dd MMMM y', 'dd/MMM/y',
           'dd/MM/yy'],
      TIMEFORMATS: const [ 'HH:mm:ss zzzz', 'HH:mm:ss z', 'HH:mm:ss', 'HH:mm'],
      FIRSTDAYOFWEEK: 0,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 3),
  /**
   * Date/time formatting symbols for locale iw.
   */
  "iw" : new DateSymbols(
      NAME: "iw",
      ERAS: const [ 'לפנה״ס', 'לסה״נ'],
      ERANAMES: const [ 'לפני הספירה', 'לספירה'],
      NARROWMONTHS: const [ '1', '2', '3', '4', '5', '6', '7', '8', '9', '10',
           '11', '12'],
      STANDALONENARROWMONTHS: const [ '1', '2', '3', '4', '5', '6', '7', '8',
           '9', '10', '11', '12'],
      MONTHS: const [ 'ינואר', 'פברואר', 'מרץ', 'אפריל',
           'מאי', 'יוני', 'יולי', 'אוגוסט', 'ספטמבר',
           'אוקטובר', 'נובמבר', 'דצמבר'],
      STANDALONEMONTHS: const [ 'ינואר', 'פברואר', 'מרץ',
           'אפריל', 'מאי', 'יוני', 'יולי', 'אוגוסט',
           'ספטמבר', 'אוקטובר', 'נובמבר', 'דצמבר'],
      SHORTMONTHS: const [ 'ינו', 'פבר', 'מרץ', 'אפר', 'מאי',
           'יונ', 'יול', 'אוג', 'ספט', 'אוק', 'נוב',
           'דצמ'],
      STANDALONESHORTMONTHS: const [ 'ינו׳', 'פבר׳', 'מרץ',
           'אפר׳', 'מאי', 'יונ׳', 'יול׳', 'אוג׳', 'ספט׳',
           'אוק׳', 'נוב׳', 'דצמ׳'],
      WEEKDAYS: const [ 'יום ראשון', 'יום שני',
           'יום שלישי', 'יום רביעי', 'יום חמישי',
           'יום שישי', 'יום שבת'],
      STANDALONEWEEKDAYS: const [ 'יום ראשון', 'יום שני',
           'יום שלישי', 'יום רביעי', 'יום חמישי',
           'יום שישי', 'יום שבת'],
      SHORTWEEKDAYS: const [ 'יום א׳', 'יום ב׳', 'יום ג׳',
           'יום ד׳', 'יום ה׳', 'יום ו׳', 'שבת'],
      STANDALONESHORTWEEKDAYS: const [ 'יום א׳', 'יום ב׳',
           'יום ג׳', 'יום ד׳', 'יום ה׳', 'יום ו׳',
           'שבת'],
      NARROWWEEKDAYS: const [ 'א', 'ב', 'ג', 'ד', 'ה', 'ו', 'ש'],
      STANDALONENARROWWEEKDAYS: const [ 'א', 'ב', 'ג', 'ד', 'ה', 'ו',
           'ש'],
      SHORTQUARTERS: const [ 'רבעון 1', 'רבעון 2', 'רבעון 3',
           'רבעון 4'],
      QUARTERS: const [ 'רבעון 1', 'רבעון 2', 'רבעון 3',
           'רבעון 4'],
      AMPMS: const [ 'לפנה״צ', 'אחה״צ'],
      DATEFORMATS: const [ 'EEEE, d בMMMM y', 'd בMMMM y', 'd בMMM yyyy',
           'dd/MM/yy'],
      TIMEFORMATS: const [ 'HH:mm:ss zzzz', 'HH:mm:ss z', 'HH:mm:ss', 'HH:mm'],
      FIRSTDAYOFWEEK: 6,
      WEEKENDRANGE: const [4, 5],
      FIRSTWEEKCUTOFFDAY: 5),
  /**
   * Date/time formatting symbols for locale ja.
   */
  "ja" : new DateSymbols(
      NAME: "ja",
      ERAS: const [ 'BC', 'AD'],
      ERANAMES: const [ '紀元前', '西暦'],
      NARROWMONTHS: const [ '1', '2', '3', '4', '5', '6', '7', '8', '9', '10',
           '11', '12'],
      STANDALONENARROWMONTHS: const [ '1', '2', '3', '4', '5', '6', '7', '8',
           '9', '10', '11', '12'],
      MONTHS: const [ '1月', '2月', '3月', '4月', '5月', '6月', '7月',
           '8月', '9月', '10月', '11月', '12月'],
      STANDALONEMONTHS: const [ '1月', '2月', '3月', '4月', '5月', '6月',
           '7月', '8月', '9月', '10月', '11月', '12月'],
      SHORTMONTHS: const [ '1月', '2月', '3月', '4月', '5月', '6月',
           '7月', '8月', '9月', '10月', '11月', '12月'],
      STANDALONESHORTMONTHS: const [ '1月', '2月', '3月', '4月', '5月',
           '6月', '7月', '8月', '9月', '10月', '11月', '12月'],
      WEEKDAYS: const [ '日曜日', '月曜日', '火曜日', '水曜日',
           '木曜日', '金曜日', '土曜日'],
      STANDALONEWEEKDAYS: const [ '日曜日', '月曜日', '火曜日',
           '水曜日', '木曜日', '金曜日', '土曜日'],
      SHORTWEEKDAYS: const [ '日', '月', '火', '水', '木', '金', '土'],
      STANDALONESHORTWEEKDAYS: const [ '日', '月', '火', '水', '木', '金',
           '土'],
      NARROWWEEKDAYS: const [ '日', '月', '火', '水', '木', '金', '土'],
      STANDALONENARROWWEEKDAYS: const [ '日', '月', '火', '水', '木',
           '金', '土'],
      SHORTQUARTERS: const [ 'Q1', 'Q2', 'Q3', 'Q4'],
      QUARTERS: const [ '第1四半期', '第2四半期', '第3四半期',
           '第4四半期'],
      AMPMS: const [ '午前', '午後'],
      DATEFORMATS: const [ 'y年M月d日EEEE', 'y年M月d日', 'yyyy/MM/dd',
           'yyyy/MM/dd'],
      TIMEFORMATS: const [ 'H時mm分ss秒 zzzz', 'H:mm:ss z', 'H:mm:ss',
           'H:mm'],
      FIRSTDAYOFWEEK: 6,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 5),
  /**
   * Date/time formatting symbols for locale kn.
   */
  "kn" : new DateSymbols(
      NAME: "kn",
      ERAS: const [ 'ಕ್ರಿ.ಪೂ', 'ಜಾಹೀ'],
      ERANAMES: const [ 'ಈಸಪೂವ೯.', 'ಕ್ರಿಸ್ತ ಶಕ'],
      NARROWMONTHS: const [ 'ಜ', 'ಫೆ', 'ಮಾ', 'ಎ', 'ಮೇ',
           'ಜೂ', 'ಜು', 'ಆ', 'ಸೆ', 'ಅ', 'ನ', 'ಡಿ'],
      STANDALONENARROWMONTHS: const [ 'ಜ', 'ಫೆ', 'ಮಾ', 'ಎ',
           'ಮೇ', 'ಜೂ', 'ಜು', 'ಆ', 'ಸೆ', 'ಅ', 'ನ',
           'ಡಿ'],
      MONTHS: const [ 'ಜನವರೀ', 'ಫೆಬ್ರವರೀ',
           'ಮಾರ್ಚ್', 'ಎಪ್ರಿಲ್', 'ಮೆ',
           'ಜೂನ್', 'ಜುಲೈ', 'ಆಗಸ್ಟ್',
           'ಸಪ್ಟೆಂಬರ್', 'ಅಕ್ಟೋಬರ್',
           'ನವೆಂಬರ್', 'ಡಿಸೆಂಬರ್'],
      STANDALONEMONTHS: const [ 'ಜನವರೀ', 'ಫೆಬ್ರವರೀ',
           'ಮಾರ್ಚ್', 'ಎಪ್ರಿಲ್', 'ಮೆ',
           'ಜೂನ್', 'ಜುಲೈ', 'ಆಗಸ್ಟ್',
           'ಸಪ್ಟೆಂಬರ್', 'ಅಕ್ಟೋಬರ್',
           'ನವೆಂಬರ್', 'ಡಿಸೆಂಬರ್'],
      SHORTMONTHS: const [ 'ಜನವರೀ', 'ಫೆಬ್ರವರೀ',
           'ಮಾರ್ಚ್', 'ಎಪ್ರಿಲ್', 'ಮೆ',
           'ಜೂನ್', 'ಜುಲೈ', 'ಆಗಸ್ಟ್',
           'ಸಪ್ಟೆಂಬರ್', 'ಅಕ್ಟೋಬರ್',
           'ನವೆಂಬರ್', 'ಡಿಸೆಂಬರ್'],
      STANDALONESHORTMONTHS: const [ 'ಜನವರೀ',
           'ಫೆಬ್ರವರೀ', 'ಮಾರ್ಚ್',
           'ಎಪ್ರಿಲ್', 'ಮೆ', 'ಜೂನ್', 'ಜುಲೈ',
           'ಆಗಸ್ಟ್', 'ಸಪ್ಟೆಂಬರ್',
           'ಅಕ್ಟೋಬರ್', 'ನವೆಂಬರ್',
           'ಡಿಸೆಂಬರ್'],
      WEEKDAYS: const [ 'ರವಿವಾರ', 'ಸೋಮವಾರ',
           'ಮಂಗಳವಾರ', 'ಬುಧವಾರ',
           'ಗುರುವಾರ', 'ಶುಕ್ರವಾರ',
           'ಶನಿವಾರ'],
      STANDALONEWEEKDAYS: const [ 'ರವಿವಾರ', 'ಸೋಮವಾರ',
           'ಮಂಗಳವಾರ', 'ಬುಧವಾರ',
           'ಗುರುವಾರ', 'ಶುಕ್ರವಾರ',
           'ಶನಿವಾರ'],
      SHORTWEEKDAYS: const [ 'ರ.', 'ಸೋ.', 'ಮಂ.', 'ಬು.', 'ಗು.',
           'ಶು.', 'ಶನಿ.'],
      STANDALONESHORTWEEKDAYS: const [ 'ರ.', 'ಸೋ.', 'ಮಂ.', 'ಬು.',
           'ಗು.', 'ಶು.', 'ಶನಿ.'],
      NARROWWEEKDAYS: const [ 'ರ', 'ಸೋ', 'ಮಂ', 'ಬು', 'ಗು',
           'ಶು', 'ಶ'],
      STANDALONENARROWWEEKDAYS: const [ 'ರ', 'ಸೋ', 'ಮಂ', 'ಬು',
           'ಗು', 'ಶು', 'ಶ'],
      SHORTQUARTERS: const [ 'ಒಂದು 1', 'ಎರಡು 2',
           'ಮೂರು 3', 'ನಾಲೃಕ 4'],
      QUARTERS: const [ 'ಒಂದು 1', 'ಎರಡು 2', 'ಮೂರು 3',
           'ನಾಲೃಕ 4'],
      AMPMS: const [ 'am', 'pm'],
      DATEFORMATS: const [ 'EEEE d MMMM y', 'd MMMM y', 'd MMM y', 'd-M-yy'],
      TIMEFORMATS: const [ 'hh:mm:ss a zzzz', 'hh:mm:ss a z', 'hh:mm:ss a',
           'hh:mm a'],
      FIRSTDAYOFWEEK: 6,
      WEEKENDRANGE: const [6, 6],
      FIRSTWEEKCUTOFFDAY: 5),
  /**
   * Date/time formatting symbols for locale ko.
   */
  "ko" : new DateSymbols(
      NAME: "ko",
      ERAS: const [ '기원전', '서기'],
      ERANAMES: const [ '서력기원전', '서력기원'],
      NARROWMONTHS: const [ '1월', '2월', '3월', '4월', '5월', '6월',
           '7월', '8월', '9월', '10월', '11월', '12월'],
      STANDALONENARROWMONTHS: const [ '1월', '2월', '3월', '4월', '5월',
           '6월', '7월', '8월', '9월', '10월', '11월', '12월'],
      MONTHS: const [ '1월', '2월', '3월', '4월', '5월', '6월', '7월',
           '8월', '9월', '10월', '11월', '12월'],
      STANDALONEMONTHS: const [ '1월', '2월', '3월', '4월', '5월', '6월',
           '7월', '8월', '9월', '10월', '11월', '12월'],
      SHORTMONTHS: const [ '1월', '2월', '3월', '4월', '5월', '6월',
           '7월', '8월', '9월', '10월', '11월', '12월'],
      STANDALONESHORTMONTHS: const [ '1월', '2월', '3월', '4월', '5월',
           '6월', '7월', '8월', '9월', '10월', '11월', '12월'],
      WEEKDAYS: const [ '일요일', '월요일', '화요일', '수요일',
           '목요일', '금요일', '토요일'],
      STANDALONEWEEKDAYS: const [ '일요일', '월요일', '화요일',
           '수요일', '목요일', '금요일', '토요일'],
      SHORTWEEKDAYS: const [ '일', '월', '화', '수', '목', '금', '토'],
      STANDALONESHORTWEEKDAYS: const [ '일', '월', '화', '수', '목', '금',
           '토'],
      NARROWWEEKDAYS: const [ '일', '월', '화', '수', '목', '금', '토'],
      STANDALONENARROWWEEKDAYS: const [ '일', '월', '화', '수', '목',
           '금', '토'],
      SHORTQUARTERS: const [ '1분기', '2분기', '3분기', '4분기'],
      QUARTERS: const [ '제 1/4분기', '제 2/4분기', '제 3/4분기',
           '제 4/4분기'],
      AMPMS: const [ '오전', '오후'],
      DATEFORMATS: const [ 'y년 M월 d일 EEEE', 'y년 M월 d일',
           'yyyy. M. d.', 'yy. M. d.'],
      TIMEFORMATS: const [ 'a h시 m분 s초 zzzz', 'a h시 m분 s초 z',
           'a h:mm:ss', 'a h:mm'],
      FIRSTDAYOFWEEK: 6,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 5),
  /**
   * Date/time formatting symbols for locale ln.
   */
  "ln" : new DateSymbols(
      NAME: "ln",
      ERAS: const [ 'libóso ya', 'nsima ya Y'],
      ERANAMES: const [ 'Yambo ya Yézu Krís', 'Nsima ya Yézu Krís'],
      NARROWMONTHS: const [ 'y', 'f', 'm', 'a', 'm', 'y', 'y', 'a', 's', 'ɔ',
           'n', 'd'],
      STANDALONENARROWMONTHS: const [ 'y', 'f', 'm', 'a', 'm', 'y', 'y', 'a',
           's', 'ɔ', 'n', 'd'],
      MONTHS: const [ 'sánzá ya yambo', 'sánzá ya míbalé',
           'sánzá ya mísáto', 'sánzá ya mínei', 'sánzá ya mítáno',
           'sánzá ya motóbá', 'sánzá ya nsambo', 'sánzá ya mwambe',
           'sánzá ya libwa', 'sánzá ya zómi',
           'sánzá ya zómi na mɔ̌kɔ́', 'sánzá ya zómi na míbalé'],
      STANDALONEMONTHS: const [ 'sánzá ya yambo', 'sánzá ya míbalé',
           'sánzá ya mísáto', 'sánzá ya mínei', 'sánzá ya mítáno',
           'sánzá ya motóbá', 'sánzá ya nsambo', 'sánzá ya mwambe',
           'sánzá ya libwa', 'sánzá ya zómi',
           'sánzá ya zómi na mɔ̌kɔ́', 'sánzá ya zómi na míbalé'],
      SHORTMONTHS: const [ 'yan', 'fbl', 'msi', 'apl', 'mai', 'yun', 'yul',
           'agt', 'stb', 'ɔtb', 'nvb', 'dsb'],
      STANDALONESHORTMONTHS: const [ 'yan', 'fbl', 'msi', 'apl', 'mai', 'yun',
           'yul', 'agt', 'stb', 'ɔtb', 'nvb', 'dsb'],
      WEEKDAYS: const [ 'eyenga', 'mokɔlɔ mwa yambo', 'mokɔlɔ mwa míbalé',
           'mokɔlɔ mwa mísáto', 'mokɔlɔ ya mínéi',
           'mokɔlɔ ya mítáno', 'mpɔ́sɔ'],
      STANDALONEWEEKDAYS: const [ 'eyenga', 'mokɔlɔ mwa yambo',
           'mokɔlɔ mwa míbalé', 'mokɔlɔ mwa mísáto',
           'mokɔlɔ ya mínéi', 'mokɔlɔ ya mítáno', 'mpɔ́sɔ'],
      SHORTWEEKDAYS: const [ 'eye', 'ybo', 'mbl', 'mst', 'min', 'mtn', 'mps'],
      STANDALONESHORTWEEKDAYS: const [ 'eye', 'ybo', 'mbl', 'mst', 'min', 'mtn',
           'mps'],
      NARROWWEEKDAYS: const [ 'e', 'y', 'm', 'm', 'm', 'm', 'p'],
      STANDALONENARROWWEEKDAYS: const [ 'e', 'y', 'm', 'm', 'm', 'm', 'p'],
      SHORTQUARTERS: const [ 'SM1', 'SM2', 'SM3', 'SM4'],
      QUARTERS: const [ 'sánzá mísáto ya yambo',
           'sánzá mísáto ya míbalé', 'sánzá mísáto ya mísáto',
           'sánzá mísáto ya mínei'],
      AMPMS: const [ 'ntɔ́ngɔ́', 'mpókwa'],
      DATEFORMATS: const [ 'EEEE d MMMM y', 'd MMMM y', 'd MMM y', 'd/M/yyyy'],
      TIMEFORMATS: const [ 'HH:mm:ss zzzz', 'HH:mm:ss z', 'HH:mm:ss', 'HH:mm'],
      FIRSTDAYOFWEEK: 0,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 6),
  /**
   * Date/time formatting symbols for locale lt.
   */
  "lt" : new DateSymbols(
      NAME: "lt",
      ERAS: const [ 'pr. Kr.', 'po Kr.'],
      ERANAMES: const [ 'prieš Kristų', 'po Kristaus'],
      NARROWMONTHS: const [ 'S', 'V', 'K', 'B', 'G', 'B', 'L', 'R', 'R', 'S',
           'L', 'G'],
      STANDALONENARROWMONTHS: const [ 'S', 'V', 'K', 'B', 'G', 'B', 'L', 'R',
           'R', 'S', 'L', 'G'],
      MONTHS: const [ 'sausio', 'vasaris', 'kovas', 'balandis', 'gegužė',
           'birželis', 'liepa', 'rugpjūtis', 'rugsėjis', 'spalis',
           'lapkritis', 'gruodis'],
      STANDALONEMONTHS: const [ 'Sausis', 'Vasaris', 'Kovas', 'Balandis',
           'Gegužė', 'Birželis', 'Liepa', 'Rugpjūtis', 'Rugsėjis',
           'Spalis', 'Lapkritis', 'Gruodis'],
      SHORTMONTHS: const [ 'Saus.', 'Vas', 'Kov.', 'Bal.', 'Geg.', 'Bir.',
           'Liep.', 'Rugp.', 'Rugs.', 'Spal.', 'Lapkr.', 'Gruod.'],
      STANDALONESHORTMONTHS: const [ 'Saus.', 'Vas.', 'Kov.', 'Bal.', 'Geg.',
           'Bir.', 'Liep.', 'Rugp.', 'Rugs.', 'Spal.', 'Lapkr.', 'Gruod.'],
      WEEKDAYS: const [ 'sekmadienis', 'pirmadienis', 'antradienis',
           'trečiadienis', 'ketvirtadienis', 'penktadienis', 'šeštadienis'],
      STANDALONEWEEKDAYS: const [ 'sekmadienis', 'pirmadienis', 'antradienis',
           'trečiadienis', 'ketvirtadienis', 'penktadienis', 'šeštadienis'],
      SHORTWEEKDAYS: const [ 'Sk', 'Pr', 'An', 'Tr', 'Kt', 'Pn', 'Št'],
      STANDALONESHORTWEEKDAYS: const [ 'Sk', 'Pr', 'An', 'Tr', 'Kt', 'Pn',
           'Št'],
      NARROWWEEKDAYS: const [ 'S', 'P', 'A', 'T', 'K', 'P', 'Š'],
      STANDALONENARROWWEEKDAYS: const [ 'S', 'P', 'A', 'T', 'K', 'P', 'Š'],
      SHORTQUARTERS: const [ 'I k.', 'II k.', 'III k.', 'IV ketv.'],
      QUARTERS: const [ 'I ketvirtis', 'II ketvirtis', 'III ketvirtis',
           'IV ketvirtis'],
      AMPMS: const [ 'priešpiet', 'popiet'],
      DATEFORMATS: const [ 'y \'m\'. MMMM d \'d\'., EEEE',
           'y \'m\'. MMMM d \'d\'.', 'y MMM d', 'yyyy-MM-dd'],
      TIMEFORMATS: const [ 'HH:mm:ss zzzz', 'HH:mm:ss z', 'HH:mm:ss', 'HH:mm'],
      FIRSTDAYOFWEEK: 0,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 3),
  /**
   * Date/time formatting symbols for locale lv.
   */
  "lv" : new DateSymbols(
      NAME: "lv",
      ERAS: const [ 'p.m.ē.', 'm.ē.'],
      ERANAMES: const [ 'pirms mūsu ēras', 'mūsu ērā'],
      NARROWMONTHS: const [ 'J', 'F', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O',
           'N', 'D'],
      STANDALONENARROWMONTHS: const [ 'J', 'F', 'M', 'A', 'M', 'J', 'J', 'A',
           'S', 'O', 'N', 'D'],
      MONTHS: const [ 'janvāris', 'februāris', 'marts', 'aprīlis', 'maijs',
           'jūnijs', 'jūlijs', 'augusts', 'septembris', 'oktobris',
           'novembris', 'decembris'],
      STANDALONEMONTHS: const [ 'janvāris', 'februāris', 'marts', 'aprīlis',
           'maijs', 'jūnijs', 'jūlijs', 'augusts', 'septembris', 'oktobris',
           'novembris', 'decembris'],
      SHORTMONTHS: const [ 'janv.', 'febr.', 'marts', 'apr.', 'maijs', 'jūn.',
           'jūl.', 'aug.', 'sept.', 'okt.', 'nov.', 'dec.'],
      STANDALONESHORTMONTHS: const [ 'janv.', 'febr.', 'marts', 'apr.', 'maijs',
           'jūn.', 'jūl.', 'aug.', 'sept.', 'okt.', 'nov.', 'dec.'],
      WEEKDAYS: const [ 'svētdiena', 'pirmdiena', 'otrdiena', 'trešdiena',
           'ceturtdiena', 'piektdiena', 'sestdiena'],
      STANDALONEWEEKDAYS: const [ 'svētdiena', 'pirmdiena', 'otrdiena',
           'trešdiena', 'ceturtdiena', 'piektdiena', 'sestdiena'],
      SHORTWEEKDAYS: const [ 'Sv', 'Pr', 'Ot', 'Tr', 'Ce', 'Pk', 'Se'],
      STANDALONESHORTWEEKDAYS: const [ 'Sv', 'Pr', 'Ot', 'Tr', 'Ce', 'Pk',
           'Se'],
      NARROWWEEKDAYS: const [ 'S', 'P', 'O', 'T', 'C', 'P', 'S'],
      STANDALONENARROWWEEKDAYS: const [ 'S', 'P', 'O', 'T', 'C', 'P', 'S'],
      SHORTQUARTERS: const [ 'C1', 'C2', 'C3', 'C4'],
      QUARTERS: const [ '1. ceturksnis', '2. ceturksnis', '3. ceturksnis',
           '4. ceturksnis'],
      AMPMS: const [ 'priekšpusdienā', 'pēcpusdienā'],
      DATEFORMATS: const [ 'EEEE, y. \'gada\' d. MMMM', 'y. \'gada\' d. MMMM',
           'y. \'gada\' d. MMM', 'dd.MM.yy'],
      TIMEFORMATS: const [ 'HH:mm:ss zzzz', 'HH:mm:ss z', 'HH:mm:ss', 'HH:mm'],
      FIRSTDAYOFWEEK: 0,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 6),
  /**
   * Date/time formatting symbols for locale ml.
   */
  "ml" : new DateSymbols(
      NAME: "ml",
      ERAS: const [ 'ക്രി.മൂ', 'ക്രി.പി.'],
      ERANAMES: const [
           'ക്രിസ്തുവിനു് മുമ്പ്‌',
           'ക്രിസ്തുവിന് പിന്‍പ്'],
      NARROWMONTHS: const [ 'ജ', 'ഫെ', 'മാ', 'ഏ', 'മേ',
           'ജൂ', 'ജൂ', 'ഓ', 'സെ', 'ഒ', 'ന', 'ഡി'],
      STANDALONENARROWMONTHS: const [ 'ജ', 'ഫെ', 'മാ', 'ഏ',
           'മേ', 'ജൂ', 'ജൂ', 'ഓ', 'സെ', 'ഒ', 'ന',
           'ഡി'],
      MONTHS: const [ 'ജനുവരി', 'ഫെബ്രുവരി',
           'മാര്‍ച്ച്', 'ഏപ്രില്‍',
           'മേയ്', 'ജൂണ്‍', 'ജൂലൈ',
           'ആഗസ്റ്റ്', 'സെപ്റ്റംബര്‍',
           'ഒക്ടോബര്‍', 'നവംബര്‍',
           'ഡിസംബര്‍'],
      STANDALONEMONTHS: const [ 'ജനുവരി',
           'ഫെബ്രുവരി', 'മാര്‍ച്ച്',
           'ഏപ്രില്‍', 'മേയ്', 'ജൂണ്‍',
           'ജൂലൈ', 'ആഗസ്റ്റ്',
           'സെപ്റ്റംബര്‍',
           'ഒക്ടോബര്‍', 'നവംബര്‍',
           'ഡിസംബര്‍'],
      SHORTMONTHS: const [ 'ജനു', 'ഫെബ്രു', 'മാര്‍',
           'ഏപ്രി', 'മേയ്', 'ജൂണ്‍', 'ജൂലൈ',
           'ഓഗ', 'സെപ്റ്റം', 'ഒക്ടോ', 'നവം',
           'ഡിസം'],
      STANDALONESHORTMONTHS: const [ 'ജനു', 'ഫെബ്രു',
           'മാര്‍', 'ഏപ്രി', 'മേയ്',
           'ജൂണ്‍', 'ജൂലൈ', 'ഓഗ',
           'സെപ്റ്റം', 'ഒക്ടോ', 'നവം',
           'ഡിസം'],
      WEEKDAYS: const [ 'ഞായറാഴ്ച',
           'തിങ്കളാഴ്ച', 'ചൊവ്വാഴ്ച',
           'ബുധനാഴ്ച', 'വ്യാഴാഴ്ച',
           'വെള്ളിയാഴ്ച', 'ശനിയാഴ്ച'],
      STANDALONEWEEKDAYS: const [ 'ഞായറാഴ്ച',
           'തിങ്കളാഴ്ച', 'ചൊവ്വാഴ്ച',
           'ബുധനാഴ്ച', 'വ്യാഴാഴ്ച',
           'വെള്ളിയാഴ്ച', 'ശനിയാഴ്ച'],
      SHORTWEEKDAYS: const [ 'ഞായര്‍', 'തിങ്കള്‍',
           'ചൊവ്വ', 'ബുധന്‍', 'വ്യാഴം',
           'വെള്ളി', 'ശനി'],
      STANDALONESHORTWEEKDAYS: const [ 'ഞായര്‍',
           'തിങ്കള്‍', 'ചൊവ്വ', 'ബുധന്‍',
           'വ്യാഴം', 'വെള്ളി', 'ശനി'],
      NARROWWEEKDAYS: const [ 'ഞാ', 'തി', 'ചൊ', 'ബു',
           'വ്യാ', 'വെ', 'ശ'],
      STANDALONENARROWWEEKDAYS: const [ 'ഞാ', 'തി', 'ചൊ', 'ബു',
           'വ്യാ', 'വെ', 'ശ'],
      SHORTQUARTERS: const [ 'Q1', 'Q2', 'Q3', 'Q4'],
      QUARTERS: const [ 'ഒന്നാം പാദം',
           'രണ്ടാം പാദം',
           'മൂന്നാം പാദം',
           'നാലാം പാദം'],
      AMPMS: const [ 'am', 'pm'],
      DATEFORMATS: const [ 'y, MMMM d, EEEE', 'y, MMMM d', 'y, MMM d',
           'dd/MM/yy'],
      TIMEFORMATS: const [ 'h:mm:ss a zzzz', 'h:mm:ss a z', 'h:mm:ss a',
           'h:mm a'],
      FIRSTDAYOFWEEK: 6,
      WEEKENDRANGE: const [6, 6],
      FIRSTWEEKCUTOFFDAY: 5),
  /**
   * Date/time formatting symbols for locale mr.
   */
  "mr" : new DateSymbols(
      NAME: "mr",
      ERAS: const [ 'ईसापूर्व', 'सन'],
      ERANAMES: const [ 'ईसवीसनपूर्व',
           'ईसवीसन'],
      NARROWMONTHS: const [ 'जा', 'फे', 'मा', 'ए', 'मे',
           'जू', 'जु', 'ऑ', 'स', 'ऑ', 'नो', 'डि'],
      STANDALONENARROWMONTHS: const [ 'जा', 'फे', 'मा', 'ए',
           'मे', 'जू', 'जु', 'ऑ', 'स', 'ऑ', 'नो',
           'डि'],
      MONTHS: const [ 'जानेवारी',
           'फेब्रुवारी', 'मार्च',
           'एप्रिल', 'मे', 'जून', 'जुलै',
           'ऑगस्ट', 'सप्टेंबर',
           'ऑक्टोबर', 'नोव्हेंबर',
           'डिसेंबर'],
      STANDALONEMONTHS: const [ 'जानेवारी',
           'फेब्रुवारी', 'मार्च',
           'एप्रिल', 'मे', 'जून', 'जुलै',
           'ऑगस्ट', 'सप्टेंबर',
           'ऑक्टोबर', 'नोव्हेंबर',
           'डिसेंबर'],
      SHORTMONTHS: const [ 'जाने', 'फेब्रु',
           'मार्च', 'एप्रि', 'मे', 'जून',
           'जुलै', 'ऑग', 'सेप्टें',
           'ऑक्टोबर', 'नोव्हें', 'डिसें'],
      STANDALONESHORTMONTHS: const [ 'जाने', 'फेब्रु',
           'मार्च', 'एप्रि', 'मे', 'जून',
           'जुलै', 'ऑग', 'सेप्टें',
           'ऑक्टोबर', 'नोव्हें', 'डिसें'],
      WEEKDAYS: const [ 'रविवार', 'सोमवार',
           'मंगळवार', 'बुधवार',
           'गुरुवार', 'शुक्रवार',
           'शनिवार'],
      STANDALONEWEEKDAYS: const [ 'रविवार', 'सोमवार',
           'मंगळवार', 'बुधवार',
           'गुरुवार', 'शुक्रवार',
           'शनिवार'],
      SHORTWEEKDAYS: const [ 'रवि', 'सोम', 'मंगळ',
           'बुध', 'गुरु', 'शुक्र', 'शनि'],
      STANDALONESHORTWEEKDAYS: const [ 'रवि', 'सोम', 'मंगळ',
           'बुध', 'गुरु', 'शुक्र', 'शनि'],
      NARROWWEEKDAYS: const [ 'र', 'सो', 'मं', 'बु', 'गु',
           'शु', 'श'],
      STANDALONENARROWWEEKDAYS: const [ 'र', 'सो', 'मं', 'बु',
           'गु', 'शु', 'श'],
      SHORTQUARTERS: const [ 'ति 1', '2 री तिमाही',
           'ति 3', 'ति 4'],
      QUARTERS: const [ 'प्रथम तिमाही',
           'द्वितीय तिमाही',
           'तृतीय तिमाही',
           'चतुर्थ तिमाही'],
      AMPMS: const [ 'am', 'pm'],
      DATEFORMATS: const [ 'EEEE d MMMM y', 'd MMMM y', 'd MMM y', 'd-M-yy'],
      TIMEFORMATS: const [ 'h-mm-ss a zzzz', 'h-mm-ss a z', 'h-mm-ss a',
           'h-mm a'],
      FIRSTDAYOFWEEK: 6,
      WEEKENDRANGE: const [6, 6],
      FIRSTWEEKCUTOFFDAY: 5),
  /**
   * Date/time formatting symbols for locale ms.
   */
  "ms" : new DateSymbols(
      NAME: "ms",
      ERAS: const [ 'S.M.', 'TM'],
      ERANAMES: const [ 'S.M.', 'TM'],
      NARROWMONTHS: const [ 'J', 'F', 'M', 'A', 'M', 'J', 'J', 'O', 'S', 'O',
           'N', 'D'],
      STANDALONENARROWMONTHS: const [ 'J', 'F', 'M', 'A', 'M', 'J', 'J', 'O',
           'S', 'O', 'N', 'D'],
      MONTHS: const [ 'Januari', 'Februari', 'Mac', 'April', 'Mei', 'Jun',
           'Julai', 'Ogos', 'September', 'Oktober', 'November', 'Disember'],
      STANDALONEMONTHS: const [ 'Januari', 'Februari', 'Mac', 'April', 'Mei',
           'Jun', 'Julai', 'Ogos', 'September', 'Oktober', 'November',
           'Disember'],
      SHORTMONTHS: const [ 'Jan', 'Feb', 'Mac', 'Apr', 'Mei', 'Jun', 'Jul',
           'Ogos', 'Sep', 'Okt', 'Nov', 'Dis'],
      STANDALONESHORTMONTHS: const [ 'Jan', 'Feb', 'Mac', 'Apr', 'Mei', 'Jun',
           'Jul', 'Ogos', 'Sep', 'Okt', 'Nov', 'Dis'],
      WEEKDAYS: const [ 'Ahad', 'Isnin', 'Selasa', 'Rabu', 'Khamis', 'Jumaat',
           'Sabtu'],
      STANDALONEWEEKDAYS: const [ 'Ahad', 'Isnin', 'Selasa', 'Rabu', 'Khamis',
           'Jumaat', 'Sabtu'],
      SHORTWEEKDAYS: const [ 'Ahd', 'Isn', 'Sel', 'Rab', 'Kha', 'Jum', 'Sab'],
      STANDALONESHORTWEEKDAYS: const [ 'Ahd', 'Isn', 'Sel', 'Rab', 'Kha', 'Jum',
           'Sab'],
      NARROWWEEKDAYS: const [ 'A', 'I', 'S', 'R', 'K', 'J', 'S'],
      STANDALONENARROWWEEKDAYS: const [ 'A', 'I', 'S', 'R', 'K', 'J', 'S'],
      SHORTQUARTERS: const [ 'Suku 1', 'Suku Ke-2', 'Suku Ke-3', 'Suku Ke-4'],
      QUARTERS: const [ 'Suku pertama', 'Suku Ke-2', 'Suku Ke-3', 'Suku Ke-4'],
      AMPMS: const [ 'PG', 'PTG'],
      DATEFORMATS: const [ 'EEEE, d MMMM y', 'd MMMM y', 'dd/MM/yyyy',
           'd/MM/yy'],
      TIMEFORMATS: const [ 'h:mm:ss a zzzz', 'h:mm:ss a z', 'h:mm:ss a',
           'h:mm a'],
      FIRSTDAYOFWEEK: 0,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 6),
  /**
   * Date/time formatting symbols for locale mt.
   */
  "mt" : new DateSymbols(
      NAME: "mt",
      ERAS: const [ 'QK', 'WK'],
      ERANAMES: const [ 'Qabel Kristu', 'Wara Kristu'],
      NARROWMONTHS: const [ 'J', 'F', 'M', 'A', 'M', 'Ġ', 'L', 'A', 'S', 'O',
           'N', 'D'],
      STANDALONENARROWMONTHS: const [ 'J', 'F', 'M', 'A', 'M', 'Ġ', 'L', 'A',
           'S', 'O', 'N', 'D'],
      MONTHS: const [ 'Jannar', 'Frar', 'Marzu', 'April', 'Mejju', 'Ġunju',
           'Lulju', 'Awwissu', 'Settembru', 'Ottubru', 'Novembru', 'Diċembru'],
      STANDALONEMONTHS: const [ 'Jannar', 'Frar', 'Marzu', 'April', 'Mejju',
           'Ġunju', 'Lulju', 'Awwissu', 'Settembru', 'Ottubru', 'Novembru',
           'Diċembru'],
      SHORTMONTHS: const [ 'Jan', 'Fra', 'Mar', 'Apr', 'Mej', 'Ġun', 'Lul',
           'Aww', 'Set', 'Ott', 'Nov', 'Diċ'],
      STANDALONESHORTMONTHS: const [ 'Jan', 'Fra', 'Mar', 'Apr', 'Mej', 'Ġun',
           'Lul', 'Aww', 'Set', 'Ott', 'Nov', 'Diċ'],
      WEEKDAYS: const [ 'Il-Ħadd', 'It-Tnejn', 'It-Tlieta', 'L-Erbgħa',
           'Il-Ħamis', 'Il-Ġimgħa', 'Is-Sibt'],
      STANDALONEWEEKDAYS: const [ 'Il-Ħadd', 'It-Tnejn', 'It-Tlieta',
           'L-Erbgħa', 'Il-Ħamis', 'Il-Ġimgħa', 'Is-Sibt'],
      SHORTWEEKDAYS: const [ 'Ħad', 'Tne', 'Tli', 'Erb', 'Ħam', 'Ġim',
           'Sib'],
      STANDALONESHORTWEEKDAYS: const [ 'Ħad', 'Tne', 'Tli', 'Erb', 'Ħam',
           'Ġim', 'Sib'],
      NARROWWEEKDAYS: const [ 'Ħ', 'T', 'T', 'E', 'Ħ', 'Ġ', 'S'],
      STANDALONENARROWWEEKDAYS: const [ 'Ħ', 'T', 'T', 'E', 'Ħ', 'Ġ', 'S'],
      SHORTQUARTERS: const [ 'K1', 'K2', 'K3', 'K4'],
      QUARTERS: const [ 'K1', 'K2', 'K3', 'K4'],
      AMPMS: const [ 'QN', 'WN'],
      DATEFORMATS: const [ 'EEEE, d \'ta\'’ MMMM y', 'd \'ta\'’ MMMM y',
           'dd MMM y', 'dd/MM/yyyy'],
      TIMEFORMATS: const [ 'HH:mm:ss zzzz', 'HH:mm:ss z', 'HH:mm:ss', 'HH:mm'],
      FIRSTDAYOFWEEK: 6,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 5),
  /**
   * Date/time formatting symbols for locale nl.
   */
  "nl" : new DateSymbols(
      NAME: "nl",
      ERAS: const [ 'v. Chr.', 'n. Chr.'],
      ERANAMES: const [ 'Voor Christus', 'na Christus'],
      NARROWMONTHS: const [ 'J', 'F', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O',
           'N', 'D'],
      STANDALONENARROWMONTHS: const [ 'J', 'F', 'M', 'A', 'M', 'J', 'J', 'A',
           'S', 'O', 'N', 'D'],
      MONTHS: const [ 'januari', 'februari', 'maart', 'april', 'mei', 'juni',
           'juli', 'augustus', 'september', 'oktober', 'november', 'december'],
      STANDALONEMONTHS: const [ 'januari', 'februari', 'maart', 'april', 'mei',
           'juni', 'juli', 'augustus', 'september', 'oktober', 'november',
           'december'],
      SHORTMONTHS: const [ 'jan.', 'feb.', 'mrt.', 'apr.', 'mei', 'jun.',
           'jul.', 'aug.', 'sep.', 'okt.', 'nov.', 'dec.'],
      STANDALONESHORTMONTHS: const [ 'jan', 'feb', 'mrt', 'apr', 'mei', 'jun',
           'jul', 'aug', 'sep', 'okt', 'nov', 'dec'],
      WEEKDAYS: const [ 'zondag', 'maandag', 'dinsdag', 'woensdag', 'donderdag',
           'vrijdag', 'zaterdag'],
      STANDALONEWEEKDAYS: const [ 'zondag', 'maandag', 'dinsdag', 'woensdag',
           'donderdag', 'vrijdag', 'zaterdag'],
      SHORTWEEKDAYS: const [ 'zo', 'ma', 'di', 'wo', 'do', 'vr', 'za'],
      STANDALONESHORTWEEKDAYS: const [ 'zo', 'ma', 'di', 'wo', 'do', 'vr',
           'za'],
      NARROWWEEKDAYS: const [ 'Z', 'M', 'D', 'W', 'D', 'V', 'Z'],
      STANDALONENARROWWEEKDAYS: const [ 'Z', 'M', 'D', 'W', 'D', 'V', 'Z'],
      SHORTQUARTERS: const [ 'K1', 'K2', 'K3', 'K4'],
      QUARTERS: const [ '1e kwartaal', '2e kwartaal', '3e kwartaal',
           '4e kwartaal'],
      AMPMS: const [ 'AM', 'PM'],
      DATEFORMATS: const [ 'EEEE d MMMM y', 'd MMMM y', 'd MMM y', 'dd-MM-yy'],
      TIMEFORMATS: const [ 'HH:mm:ss zzzz', 'HH:mm:ss z', 'HH:mm:ss', 'HH:mm'],
      FIRSTDAYOFWEEK: 0,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 3),
  /**
   * Date/time formatting symbols for locale no.
   */
  "no" : new DateSymbols(
      NAME: "no",
      ERAS: const [ 'f.Kr.', 'e.Kr.'],
      ERANAMES: const [ 'f.Kr.', 'e.Kr.'],
      NARROWMONTHS: const [ 'J', 'F', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O',
           'N', 'D'],
      STANDALONENARROWMONTHS: const [ 'J', 'F', 'M', 'A', 'M', 'J', 'J', 'A',
           'S', 'O', 'N', 'D'],
      MONTHS: const [ 'januar', 'februar', 'mars', 'april', 'mai', 'juni',
           'juli', 'august', 'september', 'oktober', 'november', 'desember'],
      STANDALONEMONTHS: const [ 'januar', 'februar', 'mars', 'april', 'mai',
           'juni', 'juli', 'august', 'september', 'oktober', 'november',
           'desember'],
      SHORTMONTHS: const [ 'jan.', 'feb.', 'mars', 'apr.', 'mai', 'juni',
           'juli', 'aug.', 'sep.', 'okt.', 'nov.', 'des.'],
      STANDALONESHORTMONTHS: const [ 'jan', 'feb', 'mar', 'apr', 'mai', 'jun',
           'jul', 'aug', 'sep', 'okt', 'nov', 'des'],
      WEEKDAYS: const [ 'søndag', 'mandag', 'tirsdag', 'onsdag', 'torsdag',
           'fredag', 'lørdag'],
      STANDALONEWEEKDAYS: const [ 'søndag', 'mandag', 'tirsdag', 'onsdag',
           'torsdag', 'fredag', 'lørdag'],
      SHORTWEEKDAYS: const [ 'søn.', 'man.', 'tir.', 'ons.', 'tor.', 'fre.',
           'lør.'],
      STANDALONESHORTWEEKDAYS: const [ 'sø.', 'ma.', 'ti.', 'on.', 'to.',
           'fr.', 'lø.'],
      NARROWWEEKDAYS: const [ 'S', 'M', 'T', 'O', 'T', 'F', 'L'],
      STANDALONENARROWWEEKDAYS: const [ 'S', 'M', 'T', 'O', 'T', 'F', 'L'],
      SHORTQUARTERS: const [ 'K1', 'K2', 'K3', 'K4'],
      QUARTERS: const [ '1. kvartal', '2. kvartal', '3. kvartal', '4. kvartal'],
      AMPMS: const [ 'AM', 'PM'],
      DATEFORMATS: const [ 'EEEE d. MMMM y', 'd. MMMM y', 'd. MMM y',
           'dd.MM.yy'],
      TIMEFORMATS: const [ '\'kl\'. HH:mm:ss zzzz', 'HH:mm:ss z', 'HH:mm:ss',
           'HH:mm'],
      FIRSTDAYOFWEEK: 0,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 3),
  /**
   * Date/time formatting symbols for locale or.
   */
  "or" : new DateSymbols(
      NAME: "or",
      ERAS: const [ 'BCE', 'CE'],
      ERANAMES: const [ 'BCE', 'CE'],
      NARROWMONTHS: const [ 'ଜା', 'ଫେ', 'ମା', 'ଅ', 'ମେ',
           'ଜୁ', 'ଜୁ', 'ଅ', 'ସେ', 'ଅ', 'ନ', 'ଡି'],
      STANDALONENARROWMONTHS: const [ 'ଜା', 'ଫେ', 'ମା', 'ଅ',
           'ମେ', 'ଜୁ', 'ଜୁ', 'ଅ', 'ସେ', 'ଅ', 'ନ',
           'ଡି'],
      MONTHS: const [ 'ଜାନୁଆରୀ', 'ଫେବ୍ରୁୟାରୀ',
           'ମାର୍ଚ୍ଚ', 'ଅପ୍ରେଲ', 'ମେ', 'ଜୁନ',
           'ଜୁଲାଇ', 'ଅଗଷ୍ଟ',
           'ସେପ୍ଟେମ୍ବର', 'ଅକ୍ଟୋବର',
           'ନଭେମ୍ବର', 'ଡିସେମ୍ବର'],
      STANDALONEMONTHS: const [ 'ଜାନୁଆରୀ',
           'ଫେବ୍ରୁୟାରୀ', 'ମାର୍ଚ୍ଚ',
           'ଅପ୍ରେଲ', 'ମେ', 'ଜୁନ', 'ଜୁଲାଇ',
           'ଅଗଷ୍ଟ', 'ସେପ୍ଟେମ୍ବର',
           'ଅକ୍ଟୋବର', 'ନଭେମ୍ବର',
           'ଡିସେମ୍ବର'],
      SHORTMONTHS: const [ 'ଜାନୁଆରୀ',
           'ଫେବ୍ରୁୟାରୀ', 'ମାର୍ଚ୍ଚ',
           'ଅପ୍ରେଲ', 'ମେ', 'ଜୁନ', 'ଜୁଲାଇ',
           'ଅଗଷ୍ଟ', 'ସେପ୍ଟେମ୍ବର',
           'ଅକ୍ଟୋବର', 'ନଭେମ୍ବର',
           'ଡିସେମ୍ବର'],
      STANDALONESHORTMONTHS: const [ 'ଜାନୁଆରୀ',
           'ଫେବ୍ରୁୟାରୀ', 'ମାର୍ଚ୍ଚ',
           'ଅପ୍ରେଲ', 'ମେ', 'ଜୁନ', 'ଜୁଲାଇ',
           'ଅଗଷ୍ଟ', 'ସେପ୍ଟେମ୍ବର',
           'ଅକ୍ଟୋବର', 'ନଭେମ୍ବର',
           'ଡିସେମ୍ବର'],
      WEEKDAYS: const [ 'ରବିବାର', 'ସୋମବାର',
           'ମଙ୍ଗଳବାର', 'ବୁଧବାର',
           'ଗୁରୁବାର', 'ଶୁକ୍ରବାର',
           'ଶନିବାର'],
      STANDALONEWEEKDAYS: const [ 'ରବିବାର', 'ସୋମବାର',
           'ମଙ୍ଗଳବାର', 'ବୁଧବାର',
           'ଗୁରୁବାର', 'ଶୁକ୍ରବାର',
           'ଶନିବାର'],
      SHORTWEEKDAYS: const [ 'ରବି', 'ସୋମ', 'ମଙ୍ଗଳ',
           'ବୁଧ', 'ଗୁରୁ', 'ଶୁକ୍ର', 'ଶନି'],
      STANDALONESHORTWEEKDAYS: const [ 'ରବି', 'ସୋମ',
           'ମଙ୍ଗଳ', 'ବୁଧ', 'ଗୁରୁ', 'ଶୁକ୍ର',
           'ଶନି'],
      NARROWWEEKDAYS: const [ 'ର', 'ସୋ', 'ମ', 'ବୁ', 'ଗୁ',
           'ଶୁ', 'ଶ'],
      STANDALONENARROWWEEKDAYS: const [ 'ର', 'ସୋ', 'ମ', 'ବୁ',
           'ଗୁ', 'ଶୁ', 'ଶ'],
      SHORTQUARTERS: const [ 'Q1', 'Q2', 'Q3', 'Q4'],
      QUARTERS: const [ 'Q1', 'Q2', 'Q3', 'Q4'],
      AMPMS: const [ 'am', 'pm'],
      DATEFORMATS: const [ 'EEEE, d MMMM y', 'd MMMM y', 'd MMM y', 'd-M-yy'],
      TIMEFORMATS: const [ 'h:mm:ss a zzzz', 'h:mm:ss a z', 'h:mm:ss a',
           'h:mm a'],
      FIRSTDAYOFWEEK: 6,
      WEEKENDRANGE: const [6, 6],
      FIRSTWEEKCUTOFFDAY: 5),
  /**
   * Date/time formatting symbols for locale pl.
   */
  "pl" : new DateSymbols(
      NAME: "pl",
      ERAS: const [ 'p.n.e.', 'n.e.'],
      ERANAMES: const [ 'p.n.e.', 'n.e.'],
      NARROWMONTHS: const [ 's', 'l', 'm', 'k', 'm', 'c', 'l', 's', 'w', 'p',
           'l', 'g'],
      STANDALONENARROWMONTHS: const [ 's', 'l', 'm', 'k', 'm', 'c', 'l', 's',
           'w', 'p', 'l', 'g'],
      MONTHS: const [ 'stycznia', 'lutego', 'marca', 'kwietnia', 'maja',
           'czerwca', 'lipca', 'sierpnia', 'września', 'października',
           'listopada', 'grudnia'],
      STANDALONEMONTHS: const [ 'styczeń', 'luty', 'marzec', 'kwiecień',
           'maj', 'czerwiec', 'lipiec', 'sierpień', 'wrzesień',
           'październik', 'listopad', 'grudzień'],
      SHORTMONTHS: const [ 'sty', 'lut', 'mar', 'kwi', 'maj', 'cze', 'lip',
           'sie', 'wrz', 'paź', 'lis', 'gru'],
      STANDALONESHORTMONTHS: const [ 'sty', 'lut', 'mar', 'kwi', 'maj', 'cze',
           'lip', 'sie', 'wrz', 'paź', 'lis', 'gru'],
      WEEKDAYS: const [ 'niedziela', 'poniedziałek', 'wtorek', 'środa',
           'czwartek', 'piątek', 'sobota'],
      STANDALONEWEEKDAYS: const [ 'niedziela', 'poniedziałek', 'wtorek',
           'środa', 'czwartek', 'piątek', 'sobota'],
      SHORTWEEKDAYS: const [ 'niedz.', 'pon.', 'wt.', 'śr.', 'czw.', 'pt.',
           'sob.'],
      STANDALONESHORTWEEKDAYS: const [ 'niedz.', 'pon.', 'wt.', 'śr.', 'czw.',
           'pt.', 'sob.'],
      NARROWWEEKDAYS: const [ 'N', 'P', 'W', 'Ś', 'C', 'P', 'S'],
      STANDALONENARROWWEEKDAYS: const [ 'N', 'P', 'W', 'Ś', 'C', 'P', 'S'],
      SHORTQUARTERS: const [ 'K1', 'K2', 'K3', 'K4'],
      QUARTERS: const [ 'I kwartał', 'II kwartał', 'III kwartał',
           'IV kwartał'],
      AMPMS: const [ 'AM', 'PM'],
      DATEFORMATS: const [ 'EEEE, d MMMM y', 'd MMMM y', 'd MMM y',
           'dd.MM.yyyy'],
      TIMEFORMATS: const [ 'HH:mm:ss zzzz', 'HH:mm:ss z', 'HH:mm:ss', 'HH:mm'],
      FIRSTDAYOFWEEK: 0,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 3),
  /**
   * Date/time formatting symbols for locale pt.
   */
  "pt" : new DateSymbols(
      NAME: "pt",
      ERAS: const [ 'a.C.', 'd.C.'],
      ERANAMES: const [ 'Antes de Cristo', 'Ano do Senhor'],
      NARROWMONTHS: const [ 'J', 'F', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O',
           'N', 'D'],
      STANDALONENARROWMONTHS: const [ 'J', 'F', 'M', 'A', 'M', 'J', 'J', 'A',
           'S', 'O', 'N', 'D'],
      MONTHS: const [ 'janeiro', 'fevereiro', 'março', 'abril', 'maio',
           'junho', 'julho', 'agosto', 'setembro', 'outubro', 'novembro',
           'dezembro'],
      STANDALONEMONTHS: const [ 'janeiro', 'fevereiro', 'março', 'abril',
           'maio', 'junho', 'julho', 'agosto', 'setembro', 'outubro',
           'novembro', 'dezembro'],
      SHORTMONTHS: const [ 'jan', 'fev', 'mar', 'abr', 'mai', 'jun', 'jul',
           'ago', 'set', 'out', 'nov', 'dez'],
      STANDALONESHORTMONTHS: const [ 'jan', 'fev', 'mar', 'abr', 'mai', 'jun',
           'jul', 'ago', 'set', 'out', 'nov', 'dez'],
      WEEKDAYS: const [ 'domingo', 'segunda-feira', 'terça-feira',
           'quarta-feira', 'quinta-feira', 'sexta-feira', 'sábado'],
      STANDALONEWEEKDAYS: const [ 'domingo', 'segunda-feira', 'terça-feira',
           'quarta-feira', 'quinta-feira', 'sexta-feira', 'sábado'],
      SHORTWEEKDAYS: const [ 'dom', 'seg', 'ter', 'qua', 'qui', 'sex', 'sáb'],
      STANDALONESHORTWEEKDAYS: const [ 'dom', 'seg', 'ter', 'qua', 'qui', 'sex',
           'sáb'],
      NARROWWEEKDAYS: const [ 'D', 'S', 'T', 'Q', 'Q', 'S', 'S'],
      STANDALONENARROWWEEKDAYS: const [ 'D', 'S', 'T', 'Q', 'Q', 'S', 'S'],
      SHORTQUARTERS: const [ 'T1', 'T2', 'T3', 'T4'],
      QUARTERS: const [ '1º trimestre', '2º trimestre', '3º trimestre',
           '4º trimestre'],
      AMPMS: const [ 'AM', 'PM'],
      DATEFORMATS: const [ 'EEEE, d \'de\' MMMM \'de\' y',
           'd \'de\' MMMM \'de\' y', 'dd/MM/yyyy', 'dd/MM/yy'],
      TIMEFORMATS: const [ 'HH\'h\'mm\'min\'ss\'s\' zzzz',
           'HH\'h\'mm\'min\'ss\'s\' z', 'HH:mm:ss', 'HH:mm'],
      FIRSTDAYOFWEEK: 6,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 5),
  /**
   * Date/time formatting symbols for locale pt_BR.
   */
  /**
   * Date/time formatting symbols for locale pt_BR.
   */
  "pt_BR" : new DateSymbols(
      NAME: "pt_BR",
      ERAS: const [ 'a.C.', 'd.C.'],
      ERANAMES: const [ 'Antes de Cristo', 'Ano do Senhor'],
      NARROWMONTHS: const [ 'J', 'F', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O',
           'N', 'D'],
      STANDALONENARROWMONTHS: const [ 'J', 'F', 'M', 'A', 'M', 'J', 'J', 'A',
           'S', 'O', 'N', 'D'],
      MONTHS: const [ 'janeiro', 'fevereiro', 'março', 'abril', 'maio',
           'junho', 'julho', 'agosto', 'setembro', 'outubro', 'novembro',
           'dezembro'],
      STANDALONEMONTHS: const [ 'janeiro', 'fevereiro', 'março', 'abril',
           'maio', 'junho', 'julho', 'agosto', 'setembro', 'outubro',
           'novembro', 'dezembro'],
      SHORTMONTHS: const [ 'jan', 'fev', 'mar', 'abr', 'mai', 'jun', 'jul',
           'ago', 'set', 'out', 'nov', 'dez'],
      STANDALONESHORTMONTHS: const [ 'jan', 'fev', 'mar', 'abr', 'mai', 'jun',
           'jul', 'ago', 'set', 'out', 'nov', 'dez'],
      WEEKDAYS: const [ 'domingo', 'segunda-feira', 'terça-feira',
           'quarta-feira', 'quinta-feira', 'sexta-feira', 'sábado'],
      STANDALONEWEEKDAYS: const [ 'domingo', 'segunda-feira', 'terça-feira',
           'quarta-feira', 'quinta-feira', 'sexta-feira', 'sábado'],
      SHORTWEEKDAYS: const [ 'dom', 'seg', 'ter', 'qua', 'qui', 'sex', 'sáb'],
      STANDALONESHORTWEEKDAYS: const [ 'dom', 'seg', 'ter', 'qua', 'qui', 'sex',
           'sáb'],
      NARROWWEEKDAYS: const [ 'D', 'S', 'T', 'Q', 'Q', 'S', 'S'],
      STANDALONENARROWWEEKDAYS: const [ 'D', 'S', 'T', 'Q', 'Q', 'S', 'S'],
      SHORTQUARTERS: const [ 'T1', 'T2', 'T3', 'T4'],
      QUARTERS: const [ '1º trimestre', '2º trimestre', '3º trimestre',
           '4º trimestre'],
      AMPMS: const [ 'AM', 'PM'],
      DATEFORMATS: const [ 'EEEE, d \'de\' MMMM \'de\' y',
           'd \'de\' MMMM \'de\' y', 'dd/MM/yyyy', 'dd/MM/yy'],
      TIMEFORMATS: const [ 'HH\'h\'mm\'min\'ss\'s\' zzzz',
           'HH\'h\'mm\'min\'ss\'s\' z', 'HH:mm:ss', 'HH:mm'],
      FIRSTDAYOFWEEK: 6,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 5),
  /**
   * Date/time formatting symbols for locale pt_PT.
   */
  "pt_PT" : new DateSymbols(
      NAME: "pt_PT",
      ERAS: const [ 'a.C.', 'd.C.'],
      ERANAMES: const [ 'Antes de Cristo', 'Ano do Senhor'],
      NARROWMONTHS: const [ 'J', 'F', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O',
           'N', 'D'],
      STANDALONENARROWMONTHS: const [ 'J', 'F', 'M', 'A', 'M', 'J', 'J', 'A',
           'S', 'O', 'N', 'D'],
      MONTHS: const [ 'Janeiro', 'Fevereiro', 'Março', 'Abril', 'Maio',
           'Junho', 'Julho', 'Agosto', 'Setembro', 'Outubro', 'Novembro',
           'Dezembro'],
      STANDALONEMONTHS: const [ 'Janeiro', 'Fevereiro', 'Março', 'Abril',
           'Maio', 'Junho', 'Julho', 'Agosto', 'Setembro', 'Outubro',
           'Novembro', 'Dezembro'],
      SHORTMONTHS: const [ 'Jan', 'Fev', 'Mar', 'Abr', 'Mai', 'Jun', 'Jul',
           'Ago', 'Set', 'Out', 'Nov', 'Dez'],
      STANDALONESHORTMONTHS: const [ 'Jan', 'Fev', 'Mar', 'Abr', 'Mai', 'Jun',
           'Jul', 'Ago', 'Set', 'Out', 'Nov', 'Dez'],
      WEEKDAYS: const [ 'Domingo', 'Segunda-feira', 'Terça-feira',
           'Quarta-feira', 'Quinta-feira', 'Sexta-feira', 'Sábado'],
      STANDALONEWEEKDAYS: const [ 'Domingo', 'Segunda-feira', 'Terça-feira',
           'Quarta-feira', 'Quinta-feira', 'Sexta-feira', 'Sábado'],
      SHORTWEEKDAYS: const [ 'dom', 'seg', 'ter', 'qua', 'qui', 'sex', 'sáb'],
      STANDALONESHORTWEEKDAYS: const [ 'dom', 'seg', 'ter', 'qua', 'qui', 'sex',
           'sáb'],
      NARROWWEEKDAYS: const [ 'D', 'S', 'T', 'Q', 'Q', 'S', 'S'],
      STANDALONENARROWWEEKDAYS: const [ 'D', 'S', 'T', 'Q', 'Q', 'S', 'S'],
      SHORTQUARTERS: const [ 'T1', 'T2', 'T3', 'T4'],
      QUARTERS: const [ '1.º trimestre', '2.º trimestre', '3.º trimestre',
           '4.º trimestre'],
      AMPMS: const [ 'a.m.', 'p.m.'],
      DATEFORMATS: const [ 'EEEE, d \'de\' MMMM \'de\' y',
           'd \'de\' MMMM \'de\' y', 'dd/MM/yyyy', 'dd/MM/yy'],
      TIMEFORMATS: const [ 'H:mm:ss zzzz', 'H:mm:ss z', 'HH:mm:ss', 'HH:mm'],
      FIRSTDAYOFWEEK: 0,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 3),
  /**
   * Date/time formatting symbols for locale ro.
   */
  "ro" : new DateSymbols(
      NAME: "ro",
      ERAS: const [ 'î.Hr.', 'd.Hr.'],
      ERANAMES: const [ 'înainte de Hristos', 'după Hristos'],
      NARROWMONTHS: const [ 'I', 'F', 'M', 'A', 'M', 'I', 'I', 'A', 'S', 'O',
           'N', 'D'],
      STANDALONENARROWMONTHS: const [ 'I', 'F', 'M', 'A', 'M', 'I', 'I', 'A',
           'S', 'O', 'N', 'D'],
      MONTHS: const [ 'ianuarie', 'februarie', 'martie', 'aprilie', 'mai',
           'iunie', 'iulie', 'august', 'septembrie', 'octombrie', 'noiembrie',
           'decembrie'],
      STANDALONEMONTHS: const [ 'ianuarie', 'februarie', 'martie', 'aprilie',
           'mai', 'iunie', 'iulie', 'august', 'septembrie', 'octombrie',
           'noiembrie', 'decembrie'],
      SHORTMONTHS: const [ 'ian.', 'feb.', 'mar.', 'apr.', 'mai', 'iun.',
           'iul.', 'aug.', 'sept.', 'oct.', 'nov.', 'dec.'],
      STANDALONESHORTMONTHS: const [ 'ian.', 'feb.', 'mar.', 'apr.', 'mai',
           'iun.', 'iul.', 'aug.', 'sept.', 'oct.', 'nov.', 'dec.'],
      WEEKDAYS: const [ 'duminică', 'luni', 'marți', 'miercuri', 'joi',
           'vineri', 'sâmbătă'],
      STANDALONEWEEKDAYS: const [ 'duminică', 'luni', 'marți', 'miercuri',
           'joi', 'vineri', 'sâmbătă'],
      SHORTWEEKDAYS: const [ 'Du', 'Lu', 'Ma', 'Mi', 'Jo', 'Vi', 'Sâ'],
      STANDALONESHORTWEEKDAYS: const [ 'Du', 'Lu', 'Ma', 'Mi', 'Jo', 'Vi',
           'Sâ'],
      NARROWWEEKDAYS: const [ 'D', 'L', 'M', 'M', 'J', 'V', 'S'],
      STANDALONENARROWWEEKDAYS: const [ 'D', 'L', 'M', 'M', 'J', 'V', 'S'],
      SHORTQUARTERS: const [ 'trim. I', 'trim. II', 'trim. III', 'trim. IV'],
      QUARTERS: const [ 'trimestrul I', 'trimestrul al II-lea',
           'trimestrul al III-lea', 'trimestrul al IV-lea'],
      AMPMS: const [ 'AM', 'PM'],
      DATEFORMATS: const [ 'EEEE, d MMMM y', 'd MMMM y', 'dd.MM.yyyy',
           'dd.MM.yyyy'],
      TIMEFORMATS: const [ 'HH:mm:ss zzzz', 'HH:mm:ss z', 'HH:mm:ss', 'HH:mm'],
      FIRSTDAYOFWEEK: 0,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 6),
  /**
   * Date/time formatting symbols for locale ru.
   */
  "ru" : new DateSymbols(
      NAME: "ru",
      ERAS: const [ 'до н.э.', 'н.э.'],
      ERANAMES: const [ 'до н.э.', 'н.э.'],
      NARROWMONTHS: const [ 'Я', 'Ф', 'М', 'А', 'М', 'И', 'И', 'А',
           'С', 'О', 'Н', 'Д'],
      STANDALONENARROWMONTHS: const [ 'Я', 'Ф', 'М', 'А', 'М', 'И', 'И',
           'А', 'С', 'О', 'Н', 'Д'],
      MONTHS: const [ 'января', 'февраля', 'марта',
           'апреля', 'мая', 'июня', 'июля', 'августа',
           'сентября', 'октября', 'ноября',
           'декабря'],
      STANDALONEMONTHS: const [ 'Январь', 'Февраль', 'Март',
           'Апрель', 'Май', 'Июнь', 'Июль', 'Август',
           'Сентябрь', 'Октябрь', 'Ноябрь',
           'Декабрь'],
      SHORTMONTHS: const [ 'янв.', 'февр.', 'марта', 'апр.',
           'мая', 'июня', 'июля', 'авг.', 'сент.', 'окт.',
           'нояб.', 'дек.'],
      STANDALONESHORTMONTHS: const [ 'Янв.', 'Февр.', 'Март',
           'Апр.', 'Май', 'Июнь', 'Июль', 'Авг.', 'Сент.',
           'Окт.', 'Нояб.', 'Дек.'],
      WEEKDAYS: const [ 'воскресенье', 'понедельник',
           'вторник', 'среда', 'четверг', 'пятница',
           'суббота'],
      STANDALONEWEEKDAYS: const [ 'Воскресенье',
           'Понедельник', 'Вторник', 'Среда',
           'Четверг', 'Пятница', 'Суббота'],
      SHORTWEEKDAYS: const [ 'вс', 'пн', 'вт', 'ср', 'чт', 'пт',
           'сб'],
      STANDALONESHORTWEEKDAYS: const [ 'Вс', 'Пн', 'Вт', 'Ср', 'Чт',
           'Пт', 'Сб'],
      NARROWWEEKDAYS: const [ 'В', 'Пн', 'Вт', 'С', 'Ч', 'П', 'С'],
      STANDALONENARROWWEEKDAYS: const [ 'В', 'П', 'В', 'С', 'Ч', 'П',
           'С'],
      SHORTQUARTERS: const [ '1-й кв.', '2-й кв.', '3-й кв.',
           '4-й кв.'],
      QUARTERS: const [ '1-й квартал', '2-й квартал',
           '3-й квартал', '4-й квартал'],
      AMPMS: const [ 'до полудня', 'после полудня'],
      DATEFORMATS: const [ 'EEEE, d MMMM y \'г\'.', 'd MMMM y \'г\'.',
           'dd.MM.yyyy', 'dd.MM.yy'],
      TIMEFORMATS: const [ 'H:mm:ss zzzz', 'H:mm:ss z', 'H:mm:ss', 'H:mm'],
      FIRSTDAYOFWEEK: 0,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 6),
  /**
   * Date/time formatting symbols for locale sk.
   */
  "sk" : new DateSymbols(
      NAME: "sk",
      ERAS: const [ 'pred n.l.', 'n.l.'],
      ERANAMES: const [ 'pred n.l.', 'n.l.'],
      NARROWMONTHS: const [ 'j', 'f', 'm', 'a', 'm', 'j', 'j', 'a', 's', 'o',
           'n', 'd'],
      STANDALONENARROWMONTHS: const [ 'j', 'f', 'm', 'a', 'm', 'j', 'j', 'a',
           's', 'o', 'n', 'd'],
      MONTHS: const [ 'januára', 'februára', 'marca', 'apríla', 'mája',
           'júna', 'júla', 'augusta', 'septembra', 'októbra', 'novembra',
           'decembra'],
      STANDALONEMONTHS: const [ 'január', 'február', 'marec', 'apríl',
           'máj', 'jún', 'júl', 'august', 'september', 'október',
           'november', 'december'],
      SHORTMONTHS: const [ 'jan', 'feb', 'mar', 'apr', 'máj', 'jún', 'júl',
           'aug', 'sep', 'okt', 'nov', 'dec'],
      STANDALONESHORTMONTHS: const [ 'jan', 'feb', 'mar', 'apr', 'máj', 'jún',
           'júl', 'aug', 'sep', 'okt', 'nov', 'dec'],
      WEEKDAYS: const [ 'nedeľa', 'pondelok', 'utorok', 'streda', 'štvrtok',
           'piatok', 'sobota'],
      STANDALONEWEEKDAYS: const [ 'nedeľa', 'pondelok', 'utorok', 'streda',
           'štvrtok', 'piatok', 'sobota'],
      SHORTWEEKDAYS: const [ 'ne', 'po', 'ut', 'st', 'št', 'pi', 'so'],
      STANDALONESHORTWEEKDAYS: const [ 'ne', 'po', 'ut', 'st', 'št', 'pi',
           'so'],
      NARROWWEEKDAYS: const [ 'N', 'P', 'U', 'S', 'Š', 'P', 'S'],
      STANDALONENARROWWEEKDAYS: const [ 'N', 'P', 'U', 'S', 'Š', 'P', 'S'],
      SHORTQUARTERS: const [ 'Q1', 'Q2', 'Q3', 'Q4'],
      QUARTERS: const [ '1. štvrťrok', '2. štvrťrok', '3. štvrťrok',
           '4. štvrťrok'],
      AMPMS: const [ 'dopoludnia', 'popoludní'],
      DATEFORMATS: const [ 'EEEE, d. MMMM y', 'd. MMMM y', 'd.M.yyyy',
           'd.M.yyyy'],
      TIMEFORMATS: const [ 'H:mm:ss zzzz', 'H:mm:ss z', 'H:mm:ss', 'H:mm'],
      FIRSTDAYOFWEEK: 0,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 3),
  /**
   * Date/time formatting symbols for locale sl.
   */
  "sl" : new DateSymbols(
      NAME: "sl",
      ERAS: const [ 'pr. n. št.', 'po Kr.'],
      ERANAMES: const [ 'pred našim štetjem', 'naše štetje'],
      NARROWMONTHS: const [ 'j', 'f', 'm', 'a', 'm', 'j', 'j', 'a', 's', 'o',
           'n', 'd'],
      STANDALONENARROWMONTHS: const [ 'j', 'f', 'm', 'a', 'm', 'j', 'j', 'a',
           's', 'o', 'n', 'd'],
      MONTHS: const [ 'januar', 'februar', 'marec', 'april', 'maj', 'junij',
           'julij', 'avgust', 'september', 'oktober', 'november', 'december'],
      STANDALONEMONTHS: const [ 'januar', 'februar', 'marec', 'april', 'maj',
           'junij', 'julij', 'avgust', 'september', 'oktober', 'november',
           'december'],
      SHORTMONTHS: const [ 'jan.', 'feb.', 'mar.', 'apr.', 'maj', 'jun.',
           'jul.', 'avg.', 'sep.', 'okt.', 'nov.', 'dec.'],
      STANDALONESHORTMONTHS: const [ 'jan', 'feb', 'mar', 'apr', 'maj', 'jun',
           'jul', 'avg', 'sep', 'okt', 'nov', 'dec'],
      WEEKDAYS: const [ 'nedelja', 'ponedeljek', 'torek', 'sreda', 'četrtek',
           'petek', 'sobota'],
      STANDALONEWEEKDAYS: const [ 'nedelja', 'ponedeljek', 'torek', 'sreda',
           'četrtek', 'petek', 'sobota'],
      SHORTWEEKDAYS: const [ 'ned.', 'pon.', 'tor.', 'sre.', 'čet.', 'pet.',
           'sob.'],
      STANDALONESHORTWEEKDAYS: const [ 'ned', 'pon', 'tor', 'sre', 'čet',
           'pet', 'sob'],
      NARROWWEEKDAYS: const [ 'n', 'p', 't', 's', 'č', 'p', 's'],
      STANDALONENARROWWEEKDAYS: const [ 'n', 'p', 't', 's', 'č', 'p', 's'],
      SHORTQUARTERS: const [ 'Q1', 'Q2', 'Q3', 'Q4'],
      QUARTERS: const [ '1. četrtletje', '2. četrtletje', '3. četrtletje',
           '4. četrtletje'],
      AMPMS: const [ 'dop.', 'pop.'],
      DATEFORMATS: const [ 'EEEE, dd. MMMM y', 'dd. MMMM y', 'd. MMM yyyy',
           'd. MM. yy'],
      TIMEFORMATS: const [ 'HH:mm:ss zzzz', 'HH:mm:ss z', 'HH:mm:ss', 'HH:mm'],
      FIRSTDAYOFWEEK: 0,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 6),
  /**
   * Date/time formatting symbols for locale sq.
   */
  "sq" : new DateSymbols(
      NAME: "sq",
      ERAS: const [ 'p.e.r.', 'n.e.r.'],
      ERANAMES: const [ 'p.e.r.', 'n.e.r.'],
      NARROWMONTHS: const [ 'J', 'S', 'M', 'P', 'M', 'Q', 'K', 'G', 'S', 'T',
           'N', 'D'],
      STANDALONENARROWMONTHS: const [ 'J', 'S', 'M', 'P', 'M', 'Q', 'K', 'G',
           'S', 'T', 'N', 'D'],
      MONTHS: const [ 'janar', 'shkurt', 'mars', 'prill', 'maj', 'qershor',
           'korrik', 'gusht', 'shtator', 'tetor', 'nëntor', 'dhjetor'],
      STANDALONEMONTHS: const [ 'janar', 'shkurt', 'mars', 'prill', 'maj',
           'qershor', 'korrik', 'gusht', 'shtator', 'tetor', 'nëntor',
           'dhjetor'],
      SHORTMONTHS: const [ 'Jan', 'Shk', 'Mar', 'Pri', 'Maj', 'Qer', 'Kor',
           'Gsh', 'Sht', 'Tet', 'Nën', 'Dhj'],
      STANDALONESHORTMONTHS: const [ 'Jan', 'Shk', 'Mar', 'Pri', 'Maj', 'Qer',
           'Kor', 'Gsh', 'Sht', 'Tet', 'Nën', 'Dhj'],
      WEEKDAYS: const [ 'e diel', 'e hënë', 'e martë', 'e mërkurë',
           'e enjte', 'e premte', 'e shtunë'],
      STANDALONEWEEKDAYS: const [ 'e diel', 'e hënë', 'e martë',
           'e mërkurë', 'e enjte', 'e premte', 'e shtunë'],
      SHORTWEEKDAYS: const [ 'Die', 'Hën', 'Mar', 'Mër', 'Enj', 'Pre', 'Sht'],
      STANDALONESHORTWEEKDAYS: const [ 'Die', 'Hën', 'Mar', 'Mër', 'Enj',
           'Pre', 'Sht'],
      NARROWWEEKDAYS: const [ 'D', 'H', 'M', 'M', 'E', 'P', 'S'],
      STANDALONENARROWWEEKDAYS: const [ 'D', 'H', 'M', 'M', 'E', 'P', 'S'],
      SHORTQUARTERS: const [ 'Q1', 'Q2', 'Q3', 'Q4'],
      QUARTERS: const [ 'Q1', 'Q2', 'Q3', 'Q4'],
      AMPMS: const [ 'PD', 'MD'],
      DATEFORMATS: const [ 'EEEE, dd MMMM y', 'dd MMMM y', 'yyyy-MM-dd',
           'yy-MM-dd'],
      TIMEFORMATS: const [ 'h.mm.ss.a zzzz', 'h.mm.ss.a z', 'h.mm.ss.a',
           'h.mm.a'],
      FIRSTDAYOFWEEK: 0,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 6),
  /**
   * Date/time formatting symbols for locale sr.
   */
  "sr" : new DateSymbols(
      NAME: "sr",
      ERAS: const [ 'п. н. е.', 'н. е.'],
      ERANAMES: const [ 'Пре нове ере', 'Нове ере'],
      NARROWMONTHS: const [ 'ј', 'ф', 'м', 'а', 'м', 'ј', 'ј', 'а',
           'с', 'о', 'н', 'д'],
      STANDALONENARROWMONTHS: const [ 'ј', 'ф', 'м', 'а', 'м', 'ј', 'ј',
           'а', 'с', 'о', 'н', 'д'],
      MONTHS: const [ 'јануар', 'фебруар', 'март',
           'април', 'мај', 'јун', 'јул', 'август',
           'септембар', 'октобар', 'новембар',
           'децембар'],
      STANDALONEMONTHS: const [ 'јануар', 'фебруар', 'март',
           'април', 'мај', 'јун', 'јул', 'август',
           'септембар', 'октобар', 'новембар',
           'децембар'],
      SHORTMONTHS: const [ 'јан', 'феб', 'мар', 'апр', 'мај',
           'јун', 'јул', 'авг', 'сеп', 'окт', 'нов',
           'дец'],
      STANDALONESHORTMONTHS: const [ 'јан', 'феб', 'мар', 'апр',
           'мај', 'јун', 'јул', 'авг', 'сеп', 'окт', 'нов',
           'дец'],
      WEEKDAYS: const [ 'недеља', 'понедељак', 'уторак',
           'среда', 'четвртак', 'петак', 'субота'],
      STANDALONEWEEKDAYS: const [ 'недеља', 'понедељак',
           'уторак', 'среда', 'четвртак', 'петак',
           'субота'],
      SHORTWEEKDAYS: const [ 'нед', 'пон', 'уто', 'сре', 'чет',
           'пет', 'суб'],
      STANDALONESHORTWEEKDAYS: const [ 'нед', 'пон', 'уто', 'сре',
           'чет', 'пет', 'суб'],
      NARROWWEEKDAYS: const [ 'н', 'п', 'у', 'с', 'ч', 'п', 'с'],
      STANDALONENARROWWEEKDAYS: const [ 'н', 'п', 'у', 'с', 'ч', 'п',
           'с'],
      SHORTQUARTERS: const [ 'К1', 'К2', 'К3', 'К4'],
      QUARTERS: const [ 'Прво тромесечје',
           'Друго тромесечје', 'Треће тромесечје',
           'Четврто тромесечје'],
      AMPMS: const [ 'пре подне', 'поподне'],
      DATEFORMATS: const [ 'EEEE, dd. MMMM y.', 'dd. MMMM y.', 'dd.MM.y.',
           'd.M.yy.'],
      TIMEFORMATS: const [ 'HH.mm.ss zzzz', 'HH.mm.ss z', 'HH.mm.ss', 'HH.mm'],
      FIRSTDAYOFWEEK: 0,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 6),
  /**
   * Date/time formatting symbols for locale sv.
   */
  "sv" : new DateSymbols(
      NAME: "sv",
      ERAS: const [ 'f.Kr.', 'e.Kr.'],
      ERANAMES: const [ 'före Kristus', 'efter Kristus'],
      NARROWMONTHS: const [ 'J', 'F', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O',
           'N', 'D'],
      STANDALONENARROWMONTHS: const [ 'J', 'F', 'M', 'A', 'M', 'J', 'J', 'A',
           'S', 'O', 'N', 'D'],
      MONTHS: const [ 'januari', 'februari', 'mars', 'april', 'maj', 'juni',
           'juli', 'augusti', 'september', 'oktober', 'november', 'december'],
      STANDALONEMONTHS: const [ 'januari', 'februari', 'mars', 'april', 'maj',
           'juni', 'juli', 'augusti', 'september', 'oktober', 'november',
           'december'],
      SHORTMONTHS: const [ 'jan', 'feb', 'mar', 'apr', 'maj', 'jun', 'jul',
           'aug', 'sep', 'okt', 'nov', 'dec'],
      STANDALONESHORTMONTHS: const [ 'jan', 'feb', 'mar', 'apr', 'maj', 'jun',
           'jul', 'aug', 'sep', 'okt', 'nov', 'dec'],
      WEEKDAYS: const [ 'söndag', 'måndag', 'tisdag', 'onsdag', 'torsdag',
           'fredag', 'lördag'],
      STANDALONEWEEKDAYS: const [ 'söndag', 'måndag', 'tisdag', 'onsdag',
           'torsdag', 'fredag', 'lördag'],
      SHORTWEEKDAYS: const [ 'sön', 'mån', 'tis', 'ons', 'tors', 'fre',
           'lör'],
      STANDALONESHORTWEEKDAYS: const [ 'sön', 'mån', 'tis', 'ons', 'tor',
           'fre', 'lör'],
      NARROWWEEKDAYS: const [ 'S', 'M', 'T', 'O', 'T', 'F', 'L'],
      STANDALONENARROWWEEKDAYS: const [ 'S', 'M', 'T', 'O', 'T', 'F', 'L'],
      SHORTQUARTERS: const [ 'K1', 'K2', 'K3', 'K4'],
      QUARTERS: const [ '1:a kvartalet', '2:a kvartalet', '3:e kvartalet',
           '4:e kvartalet'],
      AMPMS: const [ 'fm', 'em'],
      DATEFORMATS: const [ 'EEEE\'en\' \'den\' d:\'e\' MMMM y', 'd MMMM y',
           'd MMM y', 'yyyy-MM-dd'],
      TIMEFORMATS: const [ '\'kl\'. HH:mm:ss zzzz', 'HH:mm:ss z', 'HH:mm:ss',
           'HH:mm'],
      FIRSTDAYOFWEEK: 0,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 3),
  /**
   * Date/time formatting symbols for locale sw.
   */
  "sw" : new DateSymbols(
      NAME: "sw",
      ERAS: const [ 'KK', 'BK'],
      ERANAMES: const [ 'Kabla ya Kristo', 'Baada ya Kristo'],
      NARROWMONTHS: const [ 'J', 'F', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O',
           'N', 'D'],
      STANDALONENARROWMONTHS: const [ 'J', 'F', 'M', 'A', 'M', 'J', 'J', 'A',
           'S', 'O', 'N', 'D'],
      MONTHS: const [ 'Januari', 'Februari', 'Machi', 'Aprili', 'Mei', 'Juni',
           'Julai', 'Agosti', 'Septemba', 'Oktoba', 'Novemba', 'Desemba'],
      STANDALONEMONTHS: const [ 'Januari', 'Februari', 'Machi', 'Aprili', 'Mei',
           'Juni', 'Julai', 'Agosti', 'Septemba', 'Oktoba', 'Novemba',
           'Desemba'],
      SHORTMONTHS: const [ 'Jan', 'Feb', 'Mac', 'Apr', 'Mei', 'Jun', 'Jul',
           'Ago', 'Sep', 'Okt', 'Nov', 'Des'],
      STANDALONESHORTMONTHS: const [ 'Jan', 'Feb', 'Mac', 'Apr', 'Mei', 'Jun',
           'Jul', 'Ago', 'Sep', 'Okt', 'Nov', 'Des'],
      WEEKDAYS: const [ 'Jumapili', 'Jumatatu', 'Jumanne', 'Jumatano',
           'Alhamisi', 'Ijumaa', 'Jumamosi'],
      STANDALONEWEEKDAYS: const [ 'Jumapili', 'Jumatatu', 'Jumanne', 'Jumatano',
           'Alhamisi', 'Ijumaa', 'Jumamosi'],
      SHORTWEEKDAYS: const [ 'J2', 'J3', 'J4', 'J5', 'Alh', 'Ij', 'J1'],
      STANDALONESHORTWEEKDAYS: const [ 'J2', 'J3', 'J4', 'J5', 'Alh', 'Ij',
           'J1'],
      NARROWWEEKDAYS: const [ '2', '3', '4', '5', 'A', 'I', '1'],
      STANDALONENARROWWEEKDAYS: const [ '2', '3', '4', '5', 'A', 'I', '1'],
      SHORTQUARTERS: const [ 'R1', 'R2', 'R3', 'R4'],
      QUARTERS: const [ 'Robo 1', 'Robo 2', 'Robo 3', 'Robo 4'],
      AMPMS: const [ 'asubuhi', 'alasiri'],
      DATEFORMATS: const [ 'EEEE, d MMMM y', 'd MMMM y', 'd MMM y',
           'dd/MM/yyyy'],
      TIMEFORMATS: const [ 'h:mm:ss a zzzz', 'h:mm:ss a z', 'h:mm:ss a',
           'h:mm a'],
      FIRSTDAYOFWEEK: 0,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 6),
  /**
   * Date/time formatting symbols for locale ta.
   */
  "ta" : new DateSymbols(
      NAME: "ta",
      ERAS: const [ 'கி.மு.', 'கி.பி.'],
      ERANAMES: const [
           'கிறிஸ்துவுக்கு முன்',
           'அனோ டோமினி'],
      NARROWMONTHS: const [ 'ஜ', 'பி', 'மா', 'ஏ', 'மே',
           'ஜூ', 'ஜூ', 'ஆ', 'செ', 'அ', 'ந', 'டி'],
      STANDALONENARROWMONTHS: const [ 'ஜ', 'பி', 'மா', 'ஏ',
           'மே', 'ஜூ', 'ஜூ', 'ஆ', 'செ', 'அ', 'ந',
           'டி'],
      MONTHS: const [ 'ஜனவரி', 'பிப்ரவரி',
           'மார்ச்', 'ஏப்ரல்', 'மே', 'ஜூன்',
           'ஜூலை', 'ஆகஸ்ட்',
           'செப்டம்பர்', 'அக்டோபர்',
           'நவம்பர்', 'டிசம்பர்'],
      STANDALONEMONTHS: const [ 'ஜனவரி', 'பிப்ரவரி',
           'மார்ச்', 'ஏப்ரல்', 'மே', 'ஜூன்',
           'ஜூலை', 'ஆகஸ்டு',
           'செப்டம்பர்', 'அக்டோபர்',
           'நவம்பர்', 'டிசம்பர்'],
      SHORTMONTHS: const [ 'ஜன.', 'பிப்.', 'மார்.',
           'ஏப்.', 'மே', 'ஜூன்', 'ஜூலை', 'ஆக.',
           'செப்.', 'அக்.', 'நவ.', 'டிச.'],
      STANDALONESHORTMONTHS: const [ 'ஜன.', 'பிப்.',
           'மார்.', 'ஏப்.', 'மே', 'ஜூன்',
           'ஜூலை', 'ஆக.', 'செப்.', 'அக்.', 'நவ.',
           'டிச.'],
      WEEKDAYS: const [ 'ஞாயிறு', 'திங்கள்',
           'செவ்வாய்', 'புதன்',
           'வியாழன்', 'வெள்ளி', 'சனி'],
      STANDALONEWEEKDAYS: const [ 'ஞாயிறு', 'திங்கள்',
           'செவ்வாய்', 'புதன்',
           'வியாழன்', 'வெள்ளி', 'சனி'],
      SHORTWEEKDAYS: const [ 'ஞா', 'தி', 'செ', 'பு', 'வி',
           'வெ', 'ச'],
      STANDALONESHORTWEEKDAYS: const [ 'ஞா', 'தி', 'செ', 'பு',
           'வி', 'வெ', 'ச'],
      NARROWWEEKDAYS: const [ 'ஞா', 'தி', 'செ', 'பு', 'வி',
           'வெ', 'ச'],
      STANDALONENARROWWEEKDAYS: const [ 'ஞா', 'தி', 'செ', 'பு',
           'வி', 'வெ', 'ச'],
      SHORTQUARTERS: const [ 'காலாண்டு1',
           'காலாண்டு2', 'காலாண்டு3',
           'காலாண்டு4'],
      QUARTERS: const [ 'முதல் காலாண்டு',
           'இரண்டாம் காலாண்டு',
           'மூன்றாம் காலாண்டு',
           'நான்காம் காலாண்டு'],
      AMPMS: const [ 'am', 'pm'],
      DATEFORMATS: const [ 'EEEE, d MMMM, y', 'd MMMM, y', 'd MMM, y',
           'd-M-yy'],
      TIMEFORMATS: const [ 'h:mm:ss a zzzz', 'h:mm:ss a z', 'h:mm:ss a',
           'h:mm a'],
      FIRSTDAYOFWEEK: 6,
      WEEKENDRANGE: const [6, 6],
      FIRSTWEEKCUTOFFDAY: 5),
  /**
   * Date/time formatting symbols for locale te.
   */
  "te" : new DateSymbols(
      NAME: "te",
      ERAS: const [ 'ఈసాపూర్వ.', 'సన్.'],
      ERANAMES: const [ 'ఈసాపూర్వ.', 'సన్.'],
      NARROWMONTHS: const [ 'జ', 'ఫి', 'మా', 'ఏ', 'మె',
           'జు', 'జు', 'ఆ', 'సె', 'అ', 'న', 'డి'],
      STANDALONENARROWMONTHS: const [ 'జ', 'ఫి', 'మ', 'ఎ', 'మె',
           'జు', 'జు', 'ఆ', 'సె', 'అ', 'న', 'డి'],
      MONTHS: const [ 'జనవరి', 'ఫిబ్రవరి',
           'మార్చి', 'ఎప్రిల్', 'మే',
           'జూన్', 'జూలై', 'ఆగస్టు',
           'సెప్టెంబర్', 'అక్టోబర్',
           'నవంబర్', 'డిసెంబర్'],
      STANDALONEMONTHS: const [ 'జనవరి', 'ఫిబ్రవరి',
           'మార్చి', 'ఎప్రిల్', 'మే',
           'జూన్', 'జూలై', 'ఆగస్టు',
           'సెప్టెంబర్', 'అక్టోబర్',
           'నవంబర్', 'డిసెంబర్'],
      SHORTMONTHS: const [ 'జన', 'ఫిబ్ర', 'మార్చి',
           'ఏప్రి', 'మే', 'జూన్', 'జూలై',
           'ఆగస్టు', 'సెప్టెంబర్',
           'అక్టోబర్', 'నవంబర్',
           'డిసెంబర్'],
      STANDALONESHORTMONTHS: const [ 'జన', 'ఫిబ్ర',
           'మార్చి', 'ఏప్రి', 'మే', 'జూన్',
           'జూలై', 'ఆగస్టు',
           'సెప్టెంబర్', 'అక్టోబర్',
           'నవంబర్', 'డిసెంబర్'],
      WEEKDAYS: const [ 'ఆదివారం', 'సోమవారం',
           'మంగళవారం', 'బుధవారం',
           'గురువారం', 'శుక్రవారం',
           'శనివారం'],
      STANDALONEWEEKDAYS: const [ 'ఆదివారం',
           'సోమవారం', 'మంగళవారం',
           'బుధవారం', 'గురువారం',
           'శుక్రవారం', 'శనివారం'],
      SHORTWEEKDAYS: const [ 'ఆది', 'సోమ', 'మంగళ',
           'బుధ', 'గురు', 'శుక్ర', 'శని'],
      STANDALONESHORTWEEKDAYS: const [ 'ఆది', 'సోమ', 'మంగళ',
           'బుధ', 'గురు', 'శుక్ర', 'శని'],
      NARROWWEEKDAYS: const [ 'ఆ', 'సో', 'మ', 'బు', 'గు',
           'శు', 'శ'],
      STANDALONENARROWWEEKDAYS: const [ 'ఆ', 'సో', 'మ', 'బు',
           'గు', 'శు', 'శ'],
      SHORTQUARTERS: const [ 'ఒకటి 1', 'రెండు 2',
           'మూడు 3', 'నాలుగు 4'],
      QUARTERS: const [ 'ఒకటి 1', 'రెండు 2', 'మూడు 3',
           'నాలుగు 4'],
      AMPMS: const [ 'am', 'pm'],
      DATEFORMATS: const [ 'EEEE d MMMM y', 'd MMMM y', 'd MMM y', 'dd-MM-yy'],
      TIMEFORMATS: const [ 'h:mm:ss a zzzz', 'h:mm:ss a z', 'h:mm:ss a',
           'h:mm a'],
      FIRSTDAYOFWEEK: 6,
      WEEKENDRANGE: const [6, 6],
      FIRSTWEEKCUTOFFDAY: 5),
  /**
   * Date/time formatting symbols for locale th.
   */
  "th" : new DateSymbols(
      NAME: "th",
      ERAS: const [ 'ปีก่อน ค.ศ.', 'ค.ศ.'],
      ERANAMES: const [
           'ปีก่อนคริสต์ศักราช',
           'คริสต์ศักราช'],
      NARROWMONTHS: const [ 'ม.ค.', 'ก.พ.', 'มี.ค.',
           'เม.ย.', 'พ.ค.', 'มิ.ย', 'ก.ค.', 'ส.ค.',
           'ก.ย.', 'ต.ค.', 'พ.ย.', 'ธ.ค.'],
      STANDALONENARROWMONTHS: const [ 'ม.ค.', 'ก.พ.', 'มี.ค.',
           'เม.ย.', 'พ.ค.', 'มิ.ย.', 'ก.ค.', 'ส.ค.',
           'ก.ย.', 'ต.ค.', 'พ.ย.', 'ธ.ค.'],
      MONTHS: const [ 'มกราคม', 'กุมภาพันธ์',
           'มีนาคม', 'เมษายน', 'พฤษภาคม',
           'มิถุนายน', 'กรกฎาคม',
           'สิงหาคม', 'กันยายน',
           'ตุลาคม', 'พฤศจิกายน',
           'ธันวาคม'],
      STANDALONEMONTHS: const [ 'มกราคม',
           'กุมภาพันธ์', 'มีนาคม',
           'เมษายน', 'พฤษภาคม',
           'มิถุนายน', 'กรกฎาคม',
           'สิงหาคม', 'กันยายน',
           'ตุลาคม', 'พฤศจิกายน',
           'ธันวาคม'],
      SHORTMONTHS: const [ 'ม.ค.', 'ก.พ.', 'มี.ค.', 'เม.ย.',
           'พ.ค.', 'มิ.ย.', 'ก.ค.', 'ส.ค.', 'ก.ย.',
           'ต.ค.', 'พ.ย.', 'ธ.ค.'],
      STANDALONESHORTMONTHS: const [ 'ม.ค.', 'ก.พ.', 'มี.ค.',
           'เม.ย.', 'พ.ค.', 'มิ.ย.', 'ก.ค.', 'ส.ค.',
           'ก.ย.', 'ต.ค.', 'พ.ย.', 'ธ.ค.'],
      WEEKDAYS: const [ 'วันอาทิตย์',
           'วันจันทร์', 'วันอังคาร',
           'วันพุธ', 'วันพฤหัสบดี',
           'วันศุกร์', 'วันเสาร์'],
      STANDALONEWEEKDAYS: const [ 'วันอาทิตย์',
           'วันจันทร์', 'วันอังคาร',
           'วันพุธ', 'วันพฤหัสบดี',
           'วันศุกร์', 'วันเสาร์'],
      SHORTWEEKDAYS: const [ 'อา.', 'จ.', 'อ.', 'พ.', 'พฤ.',
           'ศ.', 'ส.'],
      STANDALONESHORTWEEKDAYS: const [ 'อา.', 'จ.', 'อ.', 'พ.',
           'พฤ.', 'ศ.', 'ส.'],
      NARROWWEEKDAYS: const [ 'อ', 'จ', 'อ', 'พ', 'พ', 'ศ', 'ส'],
      STANDALONENARROWWEEKDAYS: const [ 'อ', 'จ', 'อ', 'พ', 'พ',
           'ศ', 'ส'],
      SHORTQUARTERS: const [ 'Q1', 'Q2', 'Q3', 'Q4'],
      QUARTERS: const [ 'ไตรมาส 1', 'ไตรมาส 2',
           'ไตรมาส 3', 'ไตรมาส 4'],
      AMPMS: const [ 'ก่อนเที่ยง',
           'หลังเที่ยง'],
      DATEFORMATS: const [ 'EEEEที่ d MMMM G y', 'd MMMM y', 'd MMM y',
           'd/M/yyyy'],
      TIMEFORMATS: const [
           'H นาฬิกา m นาที ss วินาที zzzz',
           'H นาฬิกา m นาที ss วินาที z',
           'H:mm:ss', 'H:mm'],
      FIRSTDAYOFWEEK: 6,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 5),
  /**
   * Date/time formatting symbols for locale tl.
   */
  "tl" : new DateSymbols(
      NAME: "tl",
      ERAS: const [ 'BC', 'AD'],
      ERANAMES: const [ 'BC', 'AD'],
      NARROWMONTHS: const [ 'E', 'P', 'M', 'A', 'M', 'H', 'H', 'A', 'S', 'O',
           'N', 'D'],
      STANDALONENARROWMONTHS: const [ 'E', 'P', 'M', 'A', 'M', 'H', 'H', 'A',
           'S', 'O', 'N', 'D'],
      MONTHS: const [ 'Enero', 'Pebrero', 'Marso', 'Abril', 'Mayo', 'Hunyo',
           'Hulyo', 'Agosto', 'Setyembre', 'Oktubre', 'Nobyembre', 'Disyembre'],
      STANDALONEMONTHS: const [ 'Enero', 'Pebrero', 'Marso', 'Abril', 'Mayo',
           'Hunyo', 'Hulyo', 'Agosto', 'Setyembre', 'Oktubre', 'Nobyembre',
           'Disyembre'],
      SHORTMONTHS: const [ 'Ene', 'Peb', 'Mar', 'Abr', 'May', 'Hun', 'Hul',
           'Ago', 'Set', 'Okt', 'Nob', 'Dis'],
      STANDALONESHORTMONTHS: const [ 'Ene', 'Peb', 'Mar', 'Abr', 'May', 'Hun',
           'Hul', 'Ago', 'Set', 'Okt', 'Nob', 'Dis'],
      WEEKDAYS: const [ 'Linggo', 'Lunes', 'Martes', 'Miyerkules', 'Huwebes',
           'Biyernes', 'Sabado'],
      STANDALONEWEEKDAYS: const [ 'Linggo', 'Lunes', 'Martes', 'Miyerkules',
           'Huwebes', 'Biyernes', 'Sabado'],
      SHORTWEEKDAYS: const [ 'Lin', 'Lun', 'Mar', 'Mye', 'Huw', 'Bye', 'Sab'],
      STANDALONESHORTWEEKDAYS: const [ 'Lin', 'Lun', 'Mar', 'Miy', 'Huw', 'Biy',
           'Sab'],
      NARROWWEEKDAYS: const [ 'L', 'L', 'M', 'M', 'H', 'B', 'S'],
      STANDALONENARROWWEEKDAYS: const [ 'L', 'L', 'M', 'M', 'H', 'B', 'S'],
      SHORTQUARTERS: const [ 'Q1', 'Q2', 'Q3', 'Q4'],
      QUARTERS: const [ 'ika-1 sangkapat', 'ika-2 sangkapat', 'ika-3 quarter',
           'ika-4 na quarter'],
      AMPMS: const [ 'AM', 'PM'],
      DATEFORMATS: const [ 'EEEE, MMMM dd y', 'MMMM d, y', 'MMM d, y',
           'M/d/yy'],
      TIMEFORMATS: const [ 'HH:mm:ss zzzz', 'HH:mm:ss z', 'HH:mm:ss', 'HH:mm'],
      FIRSTDAYOFWEEK: 6,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 5),
  /**
   * Date/time formatting symbols for locale tr.
   */
  "tr" : new DateSymbols(
      NAME: "tr",
      ERAS: const [ 'MÖ', 'MS'],
      ERANAMES: const [ 'Milattan Önce', 'Milattan Sonra'],
      NARROWMONTHS: const [ 'O', 'Ş', 'M', 'N', 'M', 'H', 'T', 'A', 'E', 'E',
           'K', 'A'],
      STANDALONENARROWMONTHS: const [ 'O', 'Ş', 'M', 'N', 'M', 'H', 'T', 'A',
           'E', 'E', 'K', 'A'],
      MONTHS: const [ 'Ocak', 'Şubat', 'Mart', 'Nisan', 'Mayıs', 'Haziran',
           'Temmuz', 'Ağustos', 'Eylül', 'Ekim', 'Kasım', 'Aralık'],
      STANDALONEMONTHS: const [ 'Ocak', 'Şubat', 'Mart', 'Nisan', 'Mayıs',
           'Haziran', 'Temmuz', 'Ağustos', 'Eylül', 'Ekim', 'Kasım',
           'Aralık'],
      SHORTMONTHS: const [ 'Oca', 'Şub', 'Mar', 'Nis', 'May', 'Haz', 'Tem',
           'Ağu', 'Eyl', 'Eki', 'Kas', 'Ara'],
      STANDALONESHORTMONTHS: const [ 'Oca', 'Şub', 'Mar', 'Nis', 'May', 'Haz',
           'Tem', 'Ağu', 'Eyl', 'Eki', 'Kas', 'Ara'],
      WEEKDAYS: const [ 'Pazar', 'Pazartesi', 'Salı', 'Çarşamba',
           'Perşembe', 'Cuma', 'Cumartesi'],
      STANDALONEWEEKDAYS: const [ 'Pazar', 'Pazartesi', 'Salı', 'Çarşamba',
           'Perşembe', 'Cuma', 'Cumartesi'],
      SHORTWEEKDAYS: const [ 'Paz', 'Pzt', 'Sal', 'Çar', 'Per', 'Cum', 'Cmt'],
      STANDALONESHORTWEEKDAYS: const [ 'Paz', 'Pzt', 'Sal', 'Çar', 'Per',
           'Cum', 'Cmt'],
      NARROWWEEKDAYS: const [ 'P', 'P', 'S', 'Ç', 'P', 'C', 'C'],
      STANDALONENARROWWEEKDAYS: const [ 'P', 'P', 'S', 'Ç', 'P', 'C', 'C'],
      SHORTQUARTERS: const [ 'Ç1', 'Ç2', 'Ç3', 'Ç4'],
      QUARTERS: const [ '1. çeyrek', '2. çeyrek', '3. çeyrek', '4. çeyrek'],
      AMPMS: const [ 'AM', 'PM'],
      DATEFORMATS: const [ 'd MMMM y EEEE', 'd MMMM y', 'd MMM y',
           'dd MM yyyy'],
      TIMEFORMATS: const [ 'HH:mm:ss zzzz', 'HH:mm:ss z', 'HH:mm:ss', 'HH:mm'],
      FIRSTDAYOFWEEK: 0,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 6),
  /**
   * Date/time formatting symbols for locale uk.
   */
  "uk" : new DateSymbols(
      NAME: "uk",
      ERAS: const [ 'до н.е.', 'н.е.'],
      ERANAMES: const [ 'до нашої ери', 'нашої ери'],
      NARROWMONTHS: const [ 'С', 'Л', 'Б', 'К', 'Т', 'Ч', 'Л', 'С',
           'В', 'Ж', 'Л', 'Г'],
      STANDALONENARROWMONTHS: const [ 'С', 'Л', 'Б', 'К', 'Т', 'Ч', 'Л',
           'С', 'В', 'Ж', 'Л', 'Г'],
      MONTHS: const [ 'січня', 'лютого', 'березня',
           'квітня', 'травня', 'червня', 'липня',
           'серпня', 'вересня', 'жовтня',
           'листопада', 'грудня'],
      STANDALONEMONTHS: const [ 'Січень', 'Лютий',
           'Березень', 'Квітень', 'Травень',
           'Червень', 'Липень', 'Серпень',
           'Вересень', 'Жовтень', 'Листопад',
           'Грудень'],
      SHORTMONTHS: const [ 'січ.', 'лют.', 'бер.', 'квіт.',
           'трав.', 'черв.', 'лип.', 'серп.', 'вер.',
           'жовт.', 'лист.', 'груд.'],
      STANDALONESHORTMONTHS: const [ 'Січ', 'Лют', 'Бер', 'Кві',
           'Тра', 'Чер', 'Лип', 'Сер', 'Вер', 'Жов', 'Лис',
           'Гру'],
      WEEKDAYS: const [ 'Неділя', 'Понеділок',
           'Вівторок', 'Середа', 'Четвер',
           'Пʼятниця', 'Субота'],
      STANDALONEWEEKDAYS: const [ 'Неділя', 'Понеділок',
           'Вівторок', 'Середа', 'Четвер',
           'Пʼятниця', 'Субота'],
      SHORTWEEKDAYS: const [ 'Нд', 'Пн', 'Вт', 'Ср', 'Чт', 'Пт',
           'Сб'],
      STANDALONESHORTWEEKDAYS: const [ 'Нд', 'Пн', 'Вт', 'Ср', 'Чт',
           'Пт', 'Сб'],
      NARROWWEEKDAYS: const [ 'Н', 'П', 'В', 'С', 'Ч', 'П', 'С'],
      STANDALONENARROWWEEKDAYS: const [ 'Н', 'П', 'В', 'С', 'Ч', 'П',
           'С'],
      SHORTQUARTERS: const [ 'I кв.', 'II кв.', 'III кв.', 'IV кв.'],
      QUARTERS: const [ 'I квартал', 'II квартал',
           'III квартал', 'IV квартал'],
      AMPMS: const [ 'дп', 'пп'],
      DATEFORMATS: const [ 'EEEE, d MMMM y \'р\'.', 'd MMMM y \'р\'.',
           'd MMM y', 'dd.MM.yy'],
      TIMEFORMATS: const [ 'HH:mm:ss zzzz', 'HH:mm:ss z', 'HH:mm:ss', 'HH:mm'],
      FIRSTDAYOFWEEK: 0,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 6),
  /**
   * Date/time formatting symbols for locale ur.
   */
  "ur" : new DateSymbols(
      NAME: "ur",
      ERAS: const [ 'ق م', 'عيسوی سن'],
      ERANAMES: const [ 'قبل مسيح', 'عيسوی سن'],
      NARROWMONTHS: const [ '1', '2', '3', '4', '5', '6', '7', '8', '9', '10',
           '11', '12'],
      STANDALONENARROWMONTHS: const [ '1', '2', '3', '4', '5', '6', '7', '8',
           '9', '10', '11', '12'],
      MONTHS: const [ 'جنوری', 'فروری', 'مارچ', 'اپريل',
           'مئ', 'جون', 'جولائ', 'اگست', 'ستمبر',
           'اکتوبر', 'نومبر', 'دسمبر'],
      STANDALONEMONTHS: const [ 'جنوری', 'فروری', 'مارچ',
           'اپريل', 'مئ', 'جون', 'جولائ', 'اگست',
           'ستمبر', 'اکتوبر', 'نومبر', 'دسمبر'],
      SHORTMONTHS: const [ 'جنوری', 'فروری', 'مارچ', 'اپريل',
           'مئ', 'جون', 'جولائ', 'اگست', 'ستمبر',
           'اکتوبر', 'نومبر', 'دسمبر'],
      STANDALONESHORTMONTHS: const [ 'جنوری', 'فروری', 'مارچ',
           'اپريل', 'مئ', 'جون', 'جولائ', 'اگست',
           'ستمبر', 'اکتوبر', 'نومبر', 'دسمبر'],
      WEEKDAYS: const [ 'اتوار', 'پير', 'منگل', 'بده',
           'جمعرات', 'جمعہ', 'ہفتہ'],
      STANDALONEWEEKDAYS: const [ 'اتوار', 'پير', 'منگل', 'بده',
           'جمعرات', 'جمعہ', 'ہفتہ'],
      SHORTWEEKDAYS: const [ 'اتوار', 'پير', 'منگل', 'بده',
           'جمعرات', 'جمعہ', 'ہفتہ'],
      STANDALONESHORTWEEKDAYS: const [ 'اتوار', 'پير', 'منگل',
           'بده', 'جمعرات', 'جمعہ', 'ہفتہ'],
      NARROWWEEKDAYS: const [ '1', '2', '3', '4', '5', '6', '7'],
      STANDALONENARROWWEEKDAYS: const [ '1', '2', '3', '4', '5', '6', '7'],
      SHORTQUARTERS: const [ 'پہلی سہ ماہی',
           'دوسری سہ ماہی', 'تيسری سہ ماہی',
           'چوتهی سہ ماہی'],
      QUARTERS: const [ 'پہلی سہ ماہی', 'دوسری سہ ماہی',
           'تيسری سہ ماہی', 'چوتهی سہ ماہی'],
      AMPMS: const [ 'دن', 'رات'],
      DATEFORMATS: const [ 'EEEE؍ d؍ MMMM y', 'd؍ MMMM y', 'd؍ MMM y',
           'd/M/yy'],
      TIMEFORMATS: const [ 'h:mm:ss a zzzz', 'h:mm:ss a z', 'h:mm:ss a',
           'h:mm a'],
      FIRSTDAYOFWEEK: 6,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 5),
  /**
   * Date/time formatting symbols for locale vi.
   */
  "vi" : new DateSymbols(
      NAME: "vi",
      ERAS: const [ 'tr. CN', 'sau CN'],
      ERANAMES: const [ 'tr. CN', 'sau CN'],
      NARROWMONTHS: const [ '1', '2', '3', '4', '5', '6', '7', '8', '9', '10',
           '11', '12'],
      STANDALONENARROWMONTHS: const [ '1', '2', '3', '4', '5', '6', '7', '8',
           '9', '10', '11', '12'],
      MONTHS: const [ 'tháng một', 'tháng hai', 'tháng ba', 'tháng tư',
           'tháng năm', 'tháng sáu', 'tháng bảy', 'tháng tám',
           'tháng chín', 'tháng mười', 'tháng mười một',
           'tháng mười hai'],
      STANDALONEMONTHS: const [ 'tháng một', 'tháng hai', 'tháng ba',
           'tháng tư', 'tháng năm', 'tháng sáu', 'tháng bảy',
           'tháng tám', 'tháng chín', 'tháng mười',
           'tháng mười một', 'tháng mười hai'],
      SHORTMONTHS: const [ 'thg 1', 'thg 2', 'thg 3', 'thg 4', 'thg 5', 'thg 6',
           'thg 7', 'thg 8', 'thg 9', 'thg 10', 'thg 11', 'thg 12'],
      STANDALONESHORTMONTHS: const [ 'thg 1', 'thg 2', 'thg 3', 'thg 4',
           'thg 5', 'thg 6', 'thg 7', 'thg 8', 'thg 9', 'thg 10', 'thg 11',
           'thg 12'],
      WEEKDAYS: const [ 'Chủ nhật', 'Thứ hai', 'Thứ ba', 'Thứ tư',
           'Thứ năm', 'Thứ sáu', 'Thứ bảy'],
      STANDALONEWEEKDAYS: const [ 'Chủ nhật', 'Thứ hai', 'Thứ ba',
           'Thứ tư', 'Thứ năm', 'Thứ sáu', 'Thứ bảy'],
      SHORTWEEKDAYS: const [ 'CN', 'Th 2', 'Th 3', 'Th 4', 'Th 5', 'Th 6',
           'Th 7'],
      STANDALONESHORTWEEKDAYS: const [ 'CN', 'Th 2', 'Th 3', 'Th 4', 'Th 5',
           'Th 6', 'Th 7'],
      NARROWWEEKDAYS: const [ 'CN', 'T2', 'T3', 'T4', 'T5', 'T6', 'T7'],
      STANDALONENARROWWEEKDAYS: const [ 'CN', 'T2', 'T3', 'T4', 'T5', 'T6',
           'T7'],
      SHORTQUARTERS: const [ 'Q1', 'Q2', 'Q3', 'Q4'],
      QUARTERS: const [ 'Quý 1', 'Quý 2', 'Quý 3', 'Quý 4'],
      AMPMS: const [ 'SA', 'CH'],
      DATEFORMATS: const [ 'EEEE, \'ngày\' dd MMMM \'năm\' y',
           '\'Ngày\' dd \'tháng\' M \'năm\' y', 'dd-MM-yyyy', 'dd/MM/yyyy'],
      TIMEFORMATS: const [ 'HH:mm:ss zzzz', 'HH:mm:ss z', 'HH:mm:ss', 'HH:mm'],
      FIRSTDAYOFWEEK: 0,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 6),
  /**
   * Date/time formatting symbols for locale zh.
   */
  "zh" : new DateSymbols(
      NAME: "zh",
      ERAS: const [ '公元前', '公元'],
      ERANAMES: const [ '公元前', '公元'],
      NARROWMONTHS: const [ '1', '2', '3', '4', '5', '6', '7', '8', '9', '10',
           '11', '12'],
      STANDALONENARROWMONTHS: const [ '1月', '2月', '3月', '4月', '5月',
           '6月', '7月', '8月', '9月', '10月', '11月', '12月'],
      MONTHS: const [ '1月', '2月', '3月', '4月', '5月', '6月', '7月',
           '8月', '9月', '10月', '11月', '12月'],
      STANDALONEMONTHS: const [ '一月', '二月', '三月', '四月',
           '五月', '六月', '七月', '八月', '九月', '十月',
           '十一月', '十二月'],
      SHORTMONTHS: const [ '1月', '2月', '3月', '4月', '5月', '6月',
           '7月', '8月', '9月', '10月', '11月', '12月'],
      STANDALONESHORTMONTHS: const [ '一月', '二月', '三月', '四月',
           '五月', '六月', '七月', '八月', '九月', '十月',
           '十一月', '十二月'],
      WEEKDAYS: const [ '星期日', '星期一', '星期二', '星期三',
           '星期四', '星期五', '星期六'],
      STANDALONEWEEKDAYS: const [ '星期日', '星期一', '星期二',
           '星期三', '星期四', '星期五', '星期六'],
      SHORTWEEKDAYS: const [ '周日', '周一', '周二', '周三', '周四',
           '周五', '周六'],
      STANDALONESHORTWEEKDAYS: const [ '周日', '周一', '周二', '周三',
           '周四', '周五', '周六'],
      NARROWWEEKDAYS: const [ '日', '一', '二', '三', '四', '五', '六'],
      STANDALONENARROWWEEKDAYS: const [ '日', '一', '二', '三', '四',
           '五', '六'],
      SHORTQUARTERS: const [ '1季', '2季', '3季', '4季'],
      QUARTERS: const [ '第1季度', '第2季度', '第3季度', '第4季度'],
      AMPMS: const [ '上午', '下午'],
      DATEFORMATS: const [ 'y年M月d日EEEE', 'y年M月d日', 'yyyy-M-d',
           'yy-M-d'],
      TIMEFORMATS: const [ 'zzzzah时mm分ss秒', 'zah时mm分ss秒',
           'ah:mm:ss', 'ah:mm'],
      FIRSTDAYOFWEEK: 6,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 5),
  /**
   * Date/time formatting symbols for locale zh_CN.
   */
  /**
   * Date/time formatting symbols for locale zh_CN.
   */
  "zh_CN" : new DateSymbols(
      NAME: "zh_CN",
      ERAS: const [ '公元前', '公元'],
      ERANAMES: const [ '公元前', '公元'],
      NARROWMONTHS: const [ '1', '2', '3', '4', '5', '6', '7', '8', '9', '10',
           '11', '12'],
      STANDALONENARROWMONTHS: const [ '1月', '2月', '3月', '4月', '5月',
           '6月', '7月', '8月', '9月', '10月', '11月', '12月'],
      MONTHS: const [ '1月', '2月', '3月', '4月', '5月', '6月', '7月',
           '8月', '9月', '10月', '11月', '12月'],
      STANDALONEMONTHS: const [ '一月', '二月', '三月', '四月',
           '五月', '六月', '七月', '八月', '九月', '十月',
           '十一月', '十二月'],
      SHORTMONTHS: const [ '1月', '2月', '3月', '4月', '5月', '6月',
           '7月', '8月', '9月', '10月', '11月', '12月'],
      STANDALONESHORTMONTHS: const [ '一月', '二月', '三月', '四月',
           '五月', '六月', '七月', '八月', '九月', '十月',
           '十一月', '十二月'],
      WEEKDAYS: const [ '星期日', '星期一', '星期二', '星期三',
           '星期四', '星期五', '星期六'],
      STANDALONEWEEKDAYS: const [ '星期日', '星期一', '星期二',
           '星期三', '星期四', '星期五', '星期六'],
      SHORTWEEKDAYS: const [ '周日', '周一', '周二', '周三', '周四',
           '周五', '周六'],
      STANDALONESHORTWEEKDAYS: const [ '周日', '周一', '周二', '周三',
           '周四', '周五', '周六'],
      NARROWWEEKDAYS: const [ '日', '一', '二', '三', '四', '五', '六'],
      STANDALONENARROWWEEKDAYS: const [ '日', '一', '二', '三', '四',
           '五', '六'],
      SHORTQUARTERS: const [ '1季', '2季', '3季', '4季'],
      QUARTERS: const [ '第1季度', '第2季度', '第3季度', '第4季度'],
      AMPMS: const [ '上午', '下午'],
      DATEFORMATS: const [ 'y年M月d日EEEE', 'y年M月d日', 'yyyy-M-d',
           'yy-M-d'],
      TIMEFORMATS: const [ 'zzzzah时mm分ss秒', 'zah时mm分ss秒',
           'ah:mm:ss', 'ah:mm'],
      FIRSTDAYOFWEEK: 6,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 5),
  /**
   * Date/time formatting symbols for locale zh_HK.
   */
  "zh_HK" : new DateSymbols(
      NAME: "zh_HK",
      ERAS: const [ '西元前', '西元'],
      ERANAMES: const [ '西元前', '西元'],
      NARROWMONTHS: const [ '1', '2', '3', '4', '5', '6', '7', '8', '9', '10',
           '11', '12'],
      STANDALONENARROWMONTHS: const [ '1', '2', '3', '4', '5', '6', '7', '8',
           '9', '10', '11', '12'],
      MONTHS: const [ '1月', '2月', '3月', '4月', '5月', '6月', '7月',
           '8月', '9月', '10月', '11月', '12月'],
      STANDALONEMONTHS: const [ '一月', '二月', '三月', '四月',
           '五月', '六月', '七月', '八月', '九月', '十月',
           '十一月', '十二月'],
      SHORTMONTHS: const [ '1月', '2月', '3月', '4月', '5月', '6月',
           '7月', '8月', '9月', '10月', '11月', '12月'],
      STANDALONESHORTMONTHS: const [ '1月', '2月', '3月', '4月', '5月',
           '6月', '7月', '8月', '9月', '10月', '11月', '12月'],
      WEEKDAYS: const [ '星期日', '星期一', '星期二', '星期三',
           '星期四', '星期五', '星期六'],
      STANDALONEWEEKDAYS: const [ '星期日', '星期一', '星期二',
           '星期三', '星期四', '星期五', '星期六'],
      SHORTWEEKDAYS: const [ '週日', '週一', '週二', '週三', '週四',
           '週五', '週六'],
      STANDALONESHORTWEEKDAYS: const [ '周日', '周一', '周二', '周三',
           '周四', '周五', '周六'],
      NARROWWEEKDAYS: const [ '日', '一', '二', '三', '四', '五', '六'],
      STANDALONENARROWWEEKDAYS: const [ '日', '一', '二', '三', '四',
           '五', '六'],
      SHORTQUARTERS: const [ '1季', '2季', '3季', '4季'],
      QUARTERS: const [ '第1季', '第2季', '第3季', '第4季'],
      AMPMS: const [ '上午', '下午'],
      DATEFORMATS: const [ 'y年M月d日EEEE', 'y年M月d日', 'y年M月d日',
           'yy年M月d日'],
      TIMEFORMATS: const [ 'ah:mm:ss [zzzz]', 'ah:mm:ss [z]', 'ahh:mm:ss',
           'ah:mm'],
      FIRSTDAYOFWEEK: 6,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 5),
  /**
   * Date/time formatting symbols for locale zh_TW.
   */
  "zh_TW" : new DateSymbols(
      NAME: "zh_TW",
      ERAS: const [ '西元前', '西元'],
      ERANAMES: const [ '西元前', '西元'],
      NARROWMONTHS: const [ '1', '2', '3', '4', '5', '6', '7', '8', '9', '10',
           '11', '12'],
      STANDALONENARROWMONTHS: const [ '1', '2', '3', '4', '5', '6', '7', '8',
           '9', '10', '11', '12'],
      MONTHS: const [ '1月', '2月', '3月', '4月', '5月', '6月', '7月',
           '8月', '9月', '10月', '11月', '12月'],
      STANDALONEMONTHS: const [ '一月', '二月', '三月', '四月',
           '五月', '六月', '七月', '八月', '九月', '十月',
           '十一月', '十二月'],
      SHORTMONTHS: const [ '1月', '2月', '3月', '4月', '5月', '6月',
           '7月', '8月', '9月', '10月', '11月', '12月'],
      STANDALONESHORTMONTHS: const [ '1月', '2月', '3月', '4月', '5月',
           '6月', '7月', '8月', '9月', '10月', '11月', '12月'],
      WEEKDAYS: const [ '星期日', '星期一', '星期二', '星期三',
           '星期四', '星期五', '星期六'],
      STANDALONEWEEKDAYS: const [ '星期日', '星期一', '星期二',
           '星期三', '星期四', '星期五', '星期六'],
      SHORTWEEKDAYS: const [ '週日', '週一', '週二', '週三', '週四',
           '週五', '週六'],
      STANDALONESHORTWEEKDAYS: const [ '周日', '周一', '周二', '周三',
           '周四', '周五', '周六'],
      NARROWWEEKDAYS: const [ '日', '一', '二', '三', '四', '五', '六'],
      STANDALONENARROWWEEKDAYS: const [ '日', '一', '二', '三', '四',
           '五', '六'],
      SHORTQUARTERS: const [ '1季', '2季', '3季', '4季'],
      QUARTERS: const [ '第1季', '第2季', '第3季', '第4季'],
      AMPMS: const [ '上午', '下午'],
      DATEFORMATS: const [ 'y年M月d日EEEE', 'y年M月d日', 'yyyy/M/d',
           'y/M/d'],
      TIMEFORMATS: const [ 'zzzzah時mm分ss秒', 'zah時mm分ss秒',
           'ah:mm:ss', 'ah:mm'],
      FIRSTDAYOFWEEK: 6,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 5),
  /**
   * Date/time formatting symbols for locale zu.
   */
  "zu" : new DateSymbols(
      NAME: "zu",
      ERAS: const [ 'BC', 'AD'],
      ERANAMES: const [ 'BC', 'AD'],
      NARROWMONTHS: const [ 'J', 'F', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O',
           'N', 'D'],
      STANDALONENARROWMONTHS: const [ 'J', 'F', 'M', 'A', 'M', 'J', 'J', 'A',
           'S', 'O', 'N', 'D'],
      MONTHS: const [ 'Januwari', 'Februwari', 'Mashi', 'Apreli', 'Meyi',
           'Juni', 'Julayi', 'Agasti', 'Septhemba', 'Okthoba', 'Novemba',
           'Disemba'],
      STANDALONEMONTHS: const [ 'uJanuwari', 'uFebruwari', 'uMashi', 'u-Apreli',
           'uMeyi', 'uJuni', 'uJulayi', 'uAgasti', 'uSepthemba', 'u-Okthoba',
           'uNovemba', 'uDisemba'],
      SHORTMONTHS: const [ 'Jan', 'Feb', 'Mas', 'Apr', 'Mey', 'Jun', 'Jul',
           'Aga', 'Sep', 'Okt', 'Nov', 'Dis'],
      STANDALONESHORTMONTHS: const [ 'Jan', 'Feb', 'Mas', 'Apr', 'Mey', 'Jun',
           'Jul', 'Aga', 'Sep', 'Okt', 'Nov', 'Dis'],
      WEEKDAYS: const [ 'Sonto', 'Msombuluko', 'Lwesibili', 'Lwesithathu',
           'uLwesine', 'Lwesihlanu', 'Mgqibelo'],
      STANDALONEWEEKDAYS: const [ 'Sonto', 'Msombuluko', 'Lwesibili',
           'Lwesithathu', 'uLwesine', 'Lwesihlanu', 'Mgqibelo'],
      SHORTWEEKDAYS: const [ 'Son', 'Mso', 'Bil', 'Tha', 'Sin', 'Hla', 'Mgq'],
      STANDALONESHORTWEEKDAYS: const [ 'Son', 'Mso', 'Bil', 'Tha', 'Sin', 'Hla',
           'Mgq'],
      NARROWWEEKDAYS: const [ 'S', 'M', 'B', 'T', 'S', 'H', 'M'],
      STANDALONENARROWWEEKDAYS: const [ 'S', 'M', 'B', 'T', 'S', 'H', 'M'],
      SHORTQUARTERS: const [ 'Q1', 'Q2', 'Q3', 'Q4'],
      QUARTERS: const [ 'ikota yoku-1', 'ikota yesi-2', 'ikota yesi-3',
           'ikota yesi-4'],
      AMPMS: const [ 'AM', 'PM'],
      DATEFORMATS: const [ 'EEEE dd MMMM y', 'd MMMM y', 'd MMM y',
           'yyyy-MM-dd'],
      TIMEFORMATS: const [ 'h:mm:ss a zzzz', 'h:mm:ss a z', 'h:mm:ss a',
           'h:mm a'],
      FIRSTDAYOFWEEK: 6,
      WEEKENDRANGE: const [5, 6],
      FIRSTWEEKCUTOFFDAY: 5)
};
